package com.unis.transaction.common.constant;

import org.apache.commons.lang3.StringUtils;

/**
 * 
 * @Description: 储备粮轮换常量
 * @author 王帅
 * @date 2019年7月31日
 * @version V1.0
 */
public class StandingGrainConstant {

	/**
	 * 价格类型
	 */
	public static final String SELL_PRICE = "1"; // 销售价格

	public static final String PROCUREMENT_PRICE = "2"; // 采购价格

	/**
	 * 轮换协议状态-已撤回 执行申请-驳回
	 */
	public static final String HAS_WITHDRAWN = "0";

	/**
	 * 轮换协议状态-暂存 执行申请-待提交
	 */
	public static final String TEMPORARY_STORAGE = "1";

	/**
	 * 轮换协议状态-公司待盖章 执行申请-待批复（批复中）
	 */
	public static final String TO_BE_SEALED = "2";

	/**
	 * 轮换协议状态-公司已确认(企业端待确认) 执行申请-同意
	 */
	public static final String CONFIRMED = "3";

	/**
	 * 轮换协议状态-双方已确认(企业端已确认)
	 */
	public static final String BOTH_PARTIES_HAVE_CONFIRMED = "4";

	/**
	 * 轮换协议企业端状态-待确认
	 */
	public static final String NO_CONFIRMED = "待确认";

	/**
	 * 轮换协议企业端-已确认
	 */
	public static final String CONFIRMED_YET = "已确认";

	/**
	 * 执行申请-批复中
	 */
	public static final String IN_THE_REPLY = "批复中";

	/**
	 * 
	 * @Description: 申请状态值
	 * @param @param code
	 * @param @param isEnterprise
	 * @param @return 参数
	 * @return String 返回类型
	 */
	public static String getApplyStatusName(String code) {
		String codeName = "";

		if (StringUtils.isEmpty(code)) {
			return codeName;
		}

		switch (code) {
		case HAS_WITHDRAWN:
			codeName = "驳回";
			break;
		case TEMPORARY_STORAGE:
			codeName = "待提交";
			break;
		case TO_BE_SEALED:
			codeName = "待批复";
			break;
		case CONFIRMED:
			codeName = "同意";
			break;
		default:
			codeName = "批复中";
			break;
		}

		return codeName;
	}

	/**
	 * 
	 * @Description: 获取协议状态
	 * @param @param code
	 * @param @return 参数
	 * @return String 返回类型
	 */
	public static String getProtocolStatus(String code) {
		String codeName = "";

		if (StringUtils.isEmpty(code)) {
			return codeName;
		}

		switch (code) {
		case HAS_WITHDRAWN:
			codeName = "已撤回";
			break;
		case TEMPORARY_STORAGE:
			codeName = "暂存";
			break;
		case TO_BE_SEALED:
			codeName = "公司待盖章";
			break;
		case CONFIRMED:
			codeName = "公司已确认";
			break;
		case BOTH_PARTIES_HAVE_CONFIRMED:
			codeName = "双方已确认";
			break;
		default:
			break;
		}

		return codeName;
	}

	/**
	 * 轮换协议变更
	 */
	public static final String CHANGE_STATUS_TO_SUBMIT = "待提交";

	public static final String CHANGE_STATUS_TO_AUDIT = "待审核";

	public static final String CHANGE_STATUS_CONSENT = "同意";

	public static final String CHANGE_STATUS_REJECT = "驳回";

	public static final String CHANGE_STATUS_IN_THE_REPLY = "批复中";

	/**
	 * 字典组类型
	 */
	public static final String PRICE_TYPE = "price"; // 价格类型

	public static final String FOOD_TYPE = "food"; // 粮食类型

	public static final String OPEN_STATUS = "open"; // 开启状态

	public static final String APPLY_FOR_STATUS = "apply"; // 申请状态

	/**
	 * 轮换执行价格上报、盖章
	 */
	public static final String REPORTED = "r"; // 盖章

	public static final String STAMP = "s"; // 上报

	/**
	 * 轮换执行价格上报状态
	 */
	public static final String REPORTED_STATUS_YES = "待盖章";

	public static final String REPORTED_STATUS_NO = "未上报";

	public static final String REPORTED_STATUS_STAMP = "已盖章";

	/**
	 * 添加、更新、删除
	 */
	public static final String ADD_CODE = "0";

	public static final String UPDATE_CODE = "1";

	public static final String DELETE_CODE = "2";

	/**
	 * 架空期类型-轮出
	 */
	public static final Integer ROUND_OUT_THE = 1;

	/**
	 * 架空期类型-轮入
	 */
	public static final Integer TURN_INTO = 2;

	/**
	 * 架空期状态-未开始
	 */
	public static final Integer UNFINISHED = 1;
	public static final String UNFINISHED_NAME = "未完成";

	/**
	 * 架空期状态-进行中
	 */
	public static final Integer UNDERWAY = 2;
	public static final String UNDERWAY_NAME = "进行中";

	/**
	 * 架空期状态-预警期
	 */
	public static final Integer EARLY_WARNING_PERIOD = 3;
	public static final String EARLY_WARNING_PERIOD_NAME = "预警期";

	/**
	 * 架空期状态-已逾期
	 */
	public static final Integer overdue = 4;
	public static final String overdue_name = "已逾期";

	/**
	 * 架空期状态-已延期
	 */
	public static final Integer HAS_BEEN_POSTPONED = 5;
	public static final String HAS_BEEN_POSTPONED_NAME = "已延期";

	/**
	 * 架空期状态-已完成
	 */
	public static final Integer OFF_THE_STOCKS = 6;
	public static final String OFF_THE_STOCKS_NAME = "已完成";
}
