package com.unis.transaction.common.utils;

import jxl.CellView;
import jxl.SheetSettings;
import jxl.Workbook;
import jxl.format.Alignment;
import jxl.write.*;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang3.StringUtils;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.*;

/**
 * com.unis.common ver1.0.0
 * @author by PIG
 * @version 1.0.0
 * 2022/3/24 15
 */
public class JxlModelExcelUtil {
    private static String format="yyyy-MM-dd";

    public void setFormat(String format){
        this.format=format;
    }

    public static boolean writeExcel(OutputStream out, List<Map<String, Object>> objData, String sheetName, LinkedHashMap<String,String> headMap, int dataPerSheet) {
        boolean flag = false;
        if(headMap != null) {
            WritableWorkbook wwb;
            try {
                wwb = Workbook.createWorkbook(out);
                writeExcel(wwb, objData, sheetName, headMap, dataPerSheet);
                wwb.write();
                wwb.close();
                flag=true;
            } catch (IOException | WriteException e) {
                e.printStackTrace();
            }
        }
        return flag;
    }

    private static void writeExcel(WritableWorkbook wwb, List<Map<String, Object>> objData, String sheetName, LinkedHashMap<String,String> headMap, int dataPerSheet) throws WriteException {
        int colLen=headMap.size();
        int dataSize=0;
        if (objData != null) {
            dataSize= objData.size();
        }
        dataPerSheet=dataPerSheet<=0?65536-1:dataPerSheet;
        int piece=dataPerSheet-1>=65536-1?65536-1:dataPerSheet;
        int sheetNum=(int) Math.ceil((double)dataSize/piece);
        sheetNum=sheetNum==0?1:sheetNum;
        int start=0;
        int end=0;
        WritableSheet ws =null;
        SheetSettings ss=null;
        WritableFont fontTitle =new WritableFont(WritableFont.createFont("微软雅黑"), 10 ,WritableFont.BOLD);
        WritableFont fontContnet =new WritableFont(WritableFont.createFont("微软雅黑"), 9 ,WritableFont.NO_BOLD);

        //创建单元格样式
        WritableCellFormat wcfTitle = new WritableCellFormat(fontTitle);
        WritableCellFormat wcfContent = new WritableCellFormat(fontContnet);

        DateFormat df=new DateFormat(format);
        WritableCellFormat wcfDateContent = new WritableCellFormat(fontContnet,df);

        Object cObj=null;
        String value=null;
        Map<String, Object> map=null;
        wcfTitle.setBackground(jxl.format.Colour.YELLOW2);   		 //背景颜色
        wcfTitle.setVerticalAlignment(jxl.format.VerticalAlignment.CENTRE);  //垂直居中
        wcfTitle.setAlignment(jxl.format.Alignment.CENTRE); 				 //平行居中
        wcfTitle.setWrap(true);

        wcfContent.setVerticalAlignment(jxl.format.VerticalAlignment.CENTRE);  //垂直居中
        wcfContent.setAlignment(jxl.format.Alignment.CENTRE);
        wcfContent.setWrap(true);

        wcfDateContent.setVerticalAlignment(jxl.format.VerticalAlignment.CENTRE);  //垂直居中
        wcfDateContent.setAlignment(Alignment.CENTRE);
        wcfDateContent.setWrap(true);

        CellView cv = new CellView();
        cv.setSize(15);
        cv.setAutosize(true);
        Iterator<Map.Entry<String, String>> iterator=null;
        Map.Entry<String, String> entry=null;

        for(int n=0;n<sheetNum;n++){
            ws=wwb.createSheet(sheetNum==1?sheetName:sheetName+(n+1), n);
            ss = ws.getSettings();
            ss.setVerticalFreeze(1);//冻结表头
            Map<Integer,Integer> byteMap=new HashMap<>();
            //循环写入表头
            int index=0;
            iterator= headMap.entrySet().iterator();
            while (iterator.hasNext()) {
                entry=iterator.next();
                value= StringUtils.defaultString(entry.getValue(), "");
                int length=value.replaceAll("[^\\x00-\\xff]","00").length();
                Label label= new Label(index, 0, value, wcfTitle);
                //填加注释
                WritableCellFeatures cellFeatures = new WritableCellFeatures();
                cellFeatures.setComment(entry.getKey());
                label.setCellFeatures(cellFeatures);
                ws.addCell(label);
                byteMap.put(index, length);
                index++;
            }

            start=n*piece;
            end=(n+1)*piece-1;
            end=end>=dataSize?dataSize:end;
            for (int i = start; i < end; i++) {
                map =objData.get(i);
                int j=0;
                for(Map.Entry<String,String> o : headMap.entrySet()){
                    cObj=map.get(o.getKey());
                    int length=String.valueOf(cObj).replaceAll("[^\\x00-\\xff]","00").length();
                    if(byteMap.containsKey(j)){
                        byteMap.put(j, Math.max(byteMap.get(j), length));
                    }else{
                        byteMap.put(j, length);
                    }

                    if(cObj instanceof Date){
                        ws.addCell(new DateTime(j,i-start+1,(Date)cObj,wcfDateContent));
                    }else{
                        if(cObj!=null){
                            value= String.valueOf(cObj);
                        }else{
                            value= "";
                        }
                        ws.addCell(new Label(j,i-start+1, value,wcfContent));
                    }
                    j++;
                }
            }
            for (int j = 0; j < colLen; j++) {
                ws.setColumnView(j, byteMap.get(j)+3);
            }
        }
    }

    public static void exportExcel(HttpServletRequest request, HttpServletResponse response, String fileName, List<Map<String, Object>> objData, String sheetName, LinkedHashMap<String,String> headMap) throws IOException {
        ByteArrayOutputStream bos=new ByteArrayOutputStream();
        writeExcel(bos, objData, sheetName, headMap, 0);
        download(request, response, fileName,bos);
    }

    public static void download(HttpServletRequest request,HttpServletResponse response,String fileName,ByteArrayOutputStream bos){
        if(bos!=null){
            response.reset(); // 非常重要
            response.setContentType("application/octet-stream; charset=UTF-8");
            response.setContentLength(bos.size());
            ServletOutputStream out =null;
            try {
                response.setHeader("Content-disposition","attachment; filename=\""+ downloadFileName(request, fileName)+"\"");
                out = response.getOutputStream();
                bos.writeTo(out);
                out.flush();
                out.close();
                bos.close();
                out=null;
                bos=null;
            } catch (IOException e) {
                e.printStackTrace();
            }finally {
                if(out!=null){
                    IOUtils.closeQuietly(out);
                }
                if(bos!=null){
                    IOUtils.closeQuietly(bos);
                }
            }
        }
    }

    public static String downloadFileName(HttpServletRequest request,String fileName) {
        String agent= request.getHeader("User-Agent").toUpperCase();
        try {
            if(agent==null||agent.indexOf("MSIE")>0 || agent.contains("TRIDENT") || agent.contains("EDGE")){
                return URLEncoder.encode(fileName, "UTF-8").replace("+", "%20");
            }else{
                return new String(fileName.getBytes("UTF-8"),"ISO-8859-1");
            }
        } catch (UnsupportedEncodingException e) {
            e.getMessage();
        }
        return null;
    }
}
