package com.unis.transaction.common.vo.tradeplan;

import com.alibaba.fastjson.annotation.JSONField;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.unis.transaction.common.vo.UrlVO;
import com.unis.transaction.common.vo.backlog.ReceiverCollectionVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.Singular;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.Column;
import javax.persistence.Transient;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * @Author huyong
 * @Description 出入库委托书
 * @Date 2019-09-19
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "出入库委托书")
public class EntryAndExitOrderVO extends UrlVO implements Serializable {
    private static final long serialVersionUID = 1L;


    @ApiModelProperty(value = "wt+8位顺序号  编码", notes = "")
    private String wtbm;
    /**
     * 0-ap 1-hy
     */
    @ApiModelProperty(value = "交易方向<br/> 0采购 1销售 0,1购销双向", notes = "", example = "0,1")
    private String jyfx;

    @ApiModelProperty(value = "交易方向名称", notes = "")
    private String jyfxmc;

//    @ApiModelProperty(value = "品种编码", notes = "")
    private String pzbm;

//    @ApiModelProperty(value = "品种名称", notes = "")
    private String pzmc;

    @ApiModelProperty(value = "委托编号 CG/XS/SX + yyyyMMdd + xxx", notes = "")
    private String wtbh;

    @ApiModelProperty(value = "委托方编码", notes = "")
    private String wtfbm;

    @ApiModelProperty(value = "委托方名称", notes = "")
    private String wtfmc;

    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    @ApiModelProperty(value = "交割日期", notes = "")
    private Date jgrq;

    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    @ApiModelProperty(value = "交易日期", notes = "")
    private Date jyrq;

    @ApiModelProperty(value = "交易方式<br/> 0竞价  1挂牌 2购销双向", notes = "")
    private String jyfs;

    @ApiModelProperty(value = "交易方式<br/> 名称", notes = "")
    private String jyfsmc;

    @ApiModelProperty(value = "文本内容", notes = "")
    private String wbnr;

    @ApiModelProperty(value = "1确认 2驳回", notes = "")
    private Integer sfjs;

    @ApiModelProperty(value = "意见", notes = "")
    private String yj;

    @ApiModelProperty(value = "状态值<br/> " +
            "待提交 91000001  审核驳回 91000102 签章驳回 91000103 受理人已驳回  91000104<br/> " +
            "待审核 91000200<br/> " +
            "待盖章 91000300<br/> " +
            "待受理人审核  91000400 审核人已驳回  91000405<br/> " +
            "待审核人审核  91000500<br/> " +
            "已确认        91000600")
    private String zt;

    @ApiModelProperty(value = "状态名称", notes = "")
    private String ztmc;

    @ApiModelProperty(value = "公告标题", notes = "")
    private String ggbt;

    @ApiModelProperty(value = "公告正文", notes = "")
    private String ggzw;

    @ApiModelProperty(value = "公告发布人", notes = "")
    private String fbr;

    @ApiModelProperty(value = "交易标题", notes = "")
    private String mxbt;

//    @ApiModelProperty(value = "交易正文", notes = "")
//    private String mxzw;    //交易正文

//    @ApiModelProperty(value = "交易发布人", notes = "")
//    private String mxfbr;    //交易发布人

    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    @ApiModelProperty(value = "编制时间", notes = "")
    private Date bzsj;


    @ApiModelProperty(value = "联系人及电话", notes = "")
    private String bzr;

    @ApiModelProperty(value = "发布状态 0 未发布 1已发布 2 发布后撤回", notes = "")
    private Integer fbzt;

    @ApiModelProperty(value = "发布状态名称 0 未发布 1已发布 2 发布后撤回", notes = "")
    private String fbztmc;

    @ApiModelProperty(value = "备注", notes = "")
    private String remark;

    @ApiModelProperty(value = "安排状态 <br/> 待提交 91000001  签章驳回 91000103 <br/> 待盖章 91000300<br/> 已确认 91000600")
    private String apzt;

    @ApiModelProperty("安排状态名称")
    private String apztmc;

    @ApiModelProperty("货源表状态")
    private String hybzt;

//    @ApiModelProperty("货源表状态名称")
    private String hybztmc;

    @ApiModelProperty(value = "状态集合", notes = "")
    private List<String> zts;

    /**
     * 0-委托 1-安排 2-货源
     */
    @ApiModelProperty(value = "页面 0-委托 1-安排 2-货源", notes = "")
    private Integer page;

//    @ApiModelProperty("货源审核意见")
//    private String hyyj;

//    @ApiModelProperty("货源审核结果")
//    private String hyshjg;

    @ApiModelProperty("粮食性质编码<br/> 1·市储<br/> 2·区储<br/> 3·市自")
    private String lsxzbm;

    @ApiModelProperty("粮食性质名称")
    private String lsxzmc;

//    @ApiModelProperty("粮食数量")
//    private String lssl;

    @ApiModelProperty(value = "代办用户集合", notes = "")
    private List<ReceiverCollectionVO> userList;

//    @ApiModelProperty(value = "委托书附件", notes = "")
//    private String wtfj;

//    @ApiModelProperty(value = "承诺书附件", notes = "")
//    private String cnfj;

    @ApiModelProperty(value = "产地", notes = "产地")
    private String lscd;

    @JSONField(format = "yyyy-MM-dd")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    @ApiModelProperty("委托日期")
    private Date wtrq;

    @JSONField(format = "yyyy-MM-dd")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    @ApiModelProperty(value = "保质期限first")
    @Column(name = "bzq_first_date")
    private Date bzqFirstDate;

    @JSONField(format = "yyyy-MM-dd")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    @ApiModelProperty(value = "保质期限last")
    @Column(name = "bzq_last_date")
    private Date bzqLastDate;

    @ApiModelProperty(value = "完成时间")
    @Column(name = "wcsj")
    private String wcsj;
    @ApiModelProperty(value = "购销价差")
    private BigDecimal gxcj;

    @ApiModelProperty(value = "报名企业要求")
    @Column(name = "qybmyq")
    private String qybmyq;

    @ApiModelProperty(value = "资质<br/> 1生产 2经营 3应急 4进口")
    @Column(name = "qyzz")
    private String qyzz;
    @ApiModelProperty(value = "承诺")
    @Column(name = "commitment")
    private String commitment;
    @ApiModelProperty(value = "符合标准")
    @Column(name = "fhbz")
    private String fhbz;
    @ApiModelProperty(value = "检验项目要求")
    @Column(name = "jyxmyq")
    private String jyxmyq;
    @ApiModelProperty(value = "竞价差值")
    @Column(name = "jjcz")
    private BigDecimal jjcz;

    @ApiModelProperty(value = "包装要求")
    @Column(name = "bzyq")
    private String bzyq;
    @ApiModelProperty(value = "交货方式<br/> 1库内价 2汽车车板价")
    @Column(name = "jhfs")
    private String jhfs;
    @ApiModelProperty(value = "计量方式<br/> 1 地磅记录 2 检斤计价 3 其他")
    @Column(name = "jlfs")
    private String jlfs;
    @ApiModelProperty(value = "入库要求<br/> 1第三方报告 2出厂报告")
    @Column(name = "rkyq")
    private String rkyq;
    @ApiModelProperty(value = "第三方报告要求")
    @Column(name = "sfbgyq")
    private String sfbgyq;
    @ApiModelProperty(value = "出厂检验项目")
    @Column(name = "ccjyxm")
    private String ccjyxm;
    @ApiModelProperty(value = "出入库顺序<br/> 1先出后入 2先入后出 3其他")
    private String crksx;

    @ApiModelProperty("结算方式")
    private String jsfs;

    @ApiModelProperty("委托审核人")
    @Column(name = "wtshr")
    private String wtshr;
    @ApiModelProperty("委托审核时间")
    @Column(name = "wtshsj")
    private String wtshsj;
    @ApiModelProperty("委托方盖章")
    @Column(name = "wtfqz")
    private String wtfqz;
    @ApiModelProperty("委托方盖章时间")
    @Column(name = "wtfgzsj")
    private String wtfgzsj;

    @ApiModelProperty("受理人")
    private String slr;
    @ApiModelProperty("受理人意见")
    private String slryj;

    @JSONField(format = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    @ApiModelProperty("受理日期")
    private Date slrq;

    @ApiModelProperty("审核人")
    private String jyzxshr;

    @ApiModelProperty("审核人意见")
    private String jyzxshryj;

    @JSONField(format = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    @ApiModelProperty("审核人日期")
    private Date jyzxshrq;

    @ApiModelProperty("货物公告标题")
    @Column(name = "hwggbt")
    private String hwggbt;

    @ApiModelProperty("货物公告正文")
    @Column(name = "hwggzw")
    private String hwggzw;

    @Column(name = "wcm_id1")
    private String wcmId1;
    @Column(name = "wcm_id2")
    private String wcmId2;

    @Column(name = "slrshjg")
    @ApiModelProperty("受理人人审核结果")
    private Integer slrshjg;
    @Column(name = "jyzxshrshjg")
    @ApiModelProperty("交易中心审核人审核结果")
    private Integer jyzxshrshjg;

    @ApiModelProperty("交易时间")
    private String jysj;

    @Column(name = "jydjqz")
    private String jydjqz;

    @Transient
    @Singular
    private List<EntryAndExitOrderSeeSampleDO> seeSampleDOList;

    @Transient
    @Singular
    private List<EntryAndExitOrderGoodsDO> goodsDOList;
}
