package com.unis.transaction.server.config;

import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.RequestUtils;
import com.unis.common.utils.ResponseWrapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@Component
@Slf4j
public class SecurityInterceptor implements HandlerInterceptor {



	@Override
	public boolean preHandle(HttpServletRequest request, HttpServletResponse httpServletResponse, Object o)
			throws Exception {
		log.info("url:{}   param:{}   ua:{}   x-forwarded-for:{}   X-Real-IP:{}   host:{}   RemoteAddr:{}    method:{}   Referer:{}"
				,request.getRequestURL(),request.getQueryString(),request.getHeader("user-agent")
				,request.getHeader("x-forwarded-for") ,request.getHeader("X-Real-IP")
				,request.getHeader("host"),request.getRemoteAddr(),request.getMethod(),request.getHeader("Referer")
		);
		if(RequestUtils.getHeaderToken()==null) {
			httpServletResponse.setContentType("application/json;charset=utf-8");
			// 如果false，停止流程，api被拦截
			httpServletResponse.getWriter().write(JsonUtils.serialize(ResponseWrapper.error("用户信息获取失败,请重新登录")));
			return false;
		}
		return true;
	}

	// 请求处理之后进行调用，但是在视图被渲染之前（Controller方法调用之后）
	@Override
	public void postHandle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o,
			ModelAndView modelAndView) throws Exception {
		log.info("postHandle被调用");
	}

	// 在整个请求结束之后被调用，也就是在DispatcherServlet 渲染了对应的视图之后执行（主要是用于进行资源清理工作）
	@Override
	public void afterCompletion(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse,
			Object o, Exception e) throws Exception {
		log.info("afterCompletion被调用");
	}
}