package com.unis.transaction.server.controller.signuppay;

import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.vo.signuppay.TransactionSignUpVO;
import com.unis.transaction.common.vo.tradeplan.SiteVO;
import com.unis.transaction.server.entity.signuppay.TransactionSignUpDO;
import com.unis.transaction.server.service.TransactionSignUpService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * Author lidiaoquansb
 * 交易报名 at 2019-09-20
 */
@RestController
@RequestMapping(value = "/transactionsignup")
@Api(value = "交易报名", tags = "交易报名")
public class TransactionSignUpController {

    @Autowired
    private TransactionSignUpService transactionsignupService;


    //信用校验
    @ApiOperation(value = "报名-信用校验", notes = "参数：cccode")
    @PostMapping(value = "/valiTurn")
    public ResponseWrapper valiTurn(@RequestParam("dwbm") String dwbm) {
        try {
            return ResponseWrapper.success(transactionsignupService.valiTurn(dwbm));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //交易报名-新增
    @ApiOperation(value = "交易报名-新增", notes = "参数：TransactionSignUpVO")
    @PostMapping(value = "/insertTransactionSignUp")
    public ResponseWrapper insertTransactionSignUp(@RequestBody TransactionSignUpVO vo) {
        try {
            return transactionsignupService.insertTransactionSignUp(vo);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //交易报名-修改
    @ApiOperation(value = "交易报名-修改", notes = "参数：TransactionSignUpVO")
    @PostMapping(value = "/updateTransactionSignUp")
    public ResponseWrapper updateTransactionSignUp(@RequestBody TransactionSignUpVO vo) {
        try {
            return transactionsignupService.updateTransactionSignUp(vo, null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


    @ApiOperation(value = "手动完成场次列表", notes = "参数：TransactionSignUpVO")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping(value = "/selectClickList")
    public ResponseWrapper selectClickList(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum
            , @RequestParam(value = "pageSize", defaultValue = "10") int pageSize
            , @RequestBody SiteVO vo) {
        try {
            return ResponseWrapper.success(transactionsignupService.selectClickList(pageNum, pageSize, vo));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "交易报名-手动设置完成", notes = "参数：ccbm")
    @PostMapping(value = "/clickTransactionSignUp/{ccbm}")
    public ResponseWrapper clickTransactionSignUp(@PathVariable("ccbm") String ccbm) {
        try {
            return ResponseWrapper.success(transactionsignupService.clickTransactionSignUp(ccbm));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //交易报名-分页列表
    @ApiOperation(value = "交易报名-分页列表", notes = "参数：TransactionSignUpVO")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping(value = "/selectTransactionSignUpPageList")
    public ResponseWrapper selectTransactionSignUpPageList(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                           @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                                           @RequestBody TransactionSignUpVO vo) {
        try {
            return transactionsignupService.selectTransactionSignUpPageList(pageNum, pageSize, vo);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "交易报名-不分页列表", notes = "参数：TransactionSignUpVO")
    @PostMapping(value = "/selectTransactionSignUp")
    public ResponseWrapper selectTransactionSignUp(@RequestBody TransactionSignUpVO vo) {
        try {
            return transactionsignupService.selectTransactionSignUp(vo);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "交易报名查看-分页列表", notes = "参数：TransactionSignUpVO")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping(value = "/selectTranPageList")
    public ResponseWrapper selectTranPageList(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                              @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                              @RequestBody TransactionSignUpVO vo) {
        try {
            return transactionsignupService.selectTranPageList(pageNum, pageSize, vo);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //交易报名-列表全部数据
    @ApiOperation(value = "交易报名-列表全部数据", notes = "参数：TransactionSignUpVO")
    @PostMapping(value = "/selectTransactionSignUpAll")
    public ResponseWrapper selectTransactionSignUpAll(@RequestBody TransactionSignUpVO vo) {
        try {
            return transactionsignupService.selectTransactionSignUpAll(vo);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //交易报名-查看--返回单条
    @ApiOperation(value = "交易报名--查看--返回单条", notes = "参数：TransactionSignUpVO")
    @PostMapping(value = "/selectTransactionSignUpDetail")
    public ResponseWrapper selectTransactionSignUpDetail(@RequestBody TransactionSignUpVO vo) {
        try {
            return transactionsignupService.selectTransactionSignUpDetail(vo);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "交易报名--列表---场次---新增", notes = "参数：TransactionSignUpVO")
    @PostMapping(value = "/selectSceneList")
    public ResponseWrapper selectSceneList(@RequestBody TransactionSignUpVO vo) {
        try {
            return transactionsignupService.selectSceneList(vo);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "根据场次查询报名的企业", notes = "参数：TransactionSignUpVO")
    @PostMapping(value = "/listSignUpByCcbm")
    public ResponseWrapper listSignUpByCcbm(@RequestBody TransactionSignUpVO vo) {
        try {
            List<TransactionSignUpDO> signUpVOS = transactionsignupService.listSignUpByCcbm(vo);
            return ResponseWrapper.success(signUpVOS);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
}
