package com.unis.transaction.server.controller.tradeplan;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.vo.tradeplan.EntryAndExitOrderDTO;
import com.unis.transaction.common.vo.tradeplan.EntryAndExitOrderVO;
import com.unis.transaction.server.entity.tradeplan.EntryAndExitOrderDO;
import com.unis.transaction.server.service.EntryAndExitOrderService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * Author huyong
 * 出入库委托书 at 2019-09-19
 */
@Api(value = "出入库委托书", tags = "出入库委托书")
@Log4j2
@RestController
@RequestMapping(value = "/entryandexitorder")
public class EntryAndExitOrderController {

    @Autowired
    private EntryAndExitOrderService entryandexitorderService;

    //出入库委托书-新增
    @ApiOperation(value = "出入库委托书-新增", notes = "参数：EntryAndExitOrderVO")
    @PostMapping(value = "/insert")
    public ResponseWrapper insertEntryAndExitOrder(@RequestBody EntryAndExitOrderVO vo) {
        try {
            entryandexitorderService.insertEntryAndExitOrder(vo);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //出入库委托书-修改
    @ApiOperation(value = "出入库委托书-修改", notes = "参数：EntryAndExitOrderVO")
    @PostMapping(value = "/update")
    public ResponseWrapper updateEntryAndExitOrder(@RequestBody EntryAndExitOrderVO vo) {
        try {
            entryandexitorderService.updateEntryAndExitOrder(vo);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //出入库委托书-分页列表
    @ApiOperation(value = "出入库委托书-分页列表", notes = "参数：EntryAndExitOrderVO")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping(value = "/select")
    public ResponseWrapper selectEntryAndExitOrderPageList(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                           @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                                           @RequestBody EntryAndExitOrderVO vo) {
        try {
            return ResponseWrapper.success(entryandexitorderService.selectEntryAndExitOrderPageList(pageNum, pageSize, vo));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


    //出入库委托书-查看--返回单条
    @ApiOperation(value = "出入库委托书--查看--返回单条", notes = "参数：EntryAndExitOrderVO")
    @PostMapping(value = "/selectDetail")
    public ResponseWrapper selectEntryAndExitOrderInfo(@RequestBody EntryAndExitOrderVO vo) {
        try {
            return ResponseWrapper.success(entryandexitorderService.selectEntryAndExitOrderInfo(vo));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //出入库委托书-场次下拉关联
    @ApiOperation(value = "出入库委托书-场次下拉关联", notes = "参数：")
    @PostMapping(value = "/selectEntryAndExitOrder")
    public ResponseWrapper selectEntryAndExitOrder() {
        try {
            return ResponseWrapper.success(entryandexitorderService.selectEntryAndExitOrder());
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //出入库委托书-查看--通过主键
    @ApiOperation(value = "出入库委托书--查看--通过主键", notes = "参数：主键")
    @GetMapping(value = "/get/{id}")
    public ResponseWrapper selectEntryAndExitOrderDetail(@PathVariable("id") String id) {
        try {
            return ResponseWrapper.success(entryandexitorderService.getEntryAndExitOrderDetail(id));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //出入库委托书-查看--通过主键
    @ApiOperation(value = "出入库委托书--查看--通过主键", notes = "参数：主键")
    @GetMapping(value = "/selectEntryAndExitOrderBySite/{id}")
    public ResponseWrapper selectEntryAndExitOrderBySite(@PathVariable("id") String id) {
        try {
            return ResponseWrapper.success(entryandexitorderService.selectEntryAndExitOrderBySite(id));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


    //出入库委托书-删除--通过主键
    @ApiOperation(value = "出入库委托书--查看--通过主键", notes = "参数：主键")
    @DeleteMapping(value = "/del/{wtbm}")
    public ResponseWrapper removeEntryAndExitOrder(@PathVariable("wtbm") String wtbm) {
        try {
            entryandexitorderService.removeEntryAndExitOrder(wtbm);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "出入库委托书--查看--通过主键", notes = "参数：主键")
    @GetMapping(value = "/v2/getDTO/{wtbm}")
    public ResponseWrapper getEntryAndExitOrderDTO(@PathVariable("wtbm") String wtbm) {
        try {
            return ResponseWrapper.success(entryandexitorderService.getEntryAndExitOrderDTO(wtbm));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "出入库委托书-新增ver2", notes = "参数：EntryAndExitOrderDTO")
    @PostMapping(value = "/v2/insert")
    public ResponseWrapper insertEntryAndExitOrder2(@RequestBody EntryAndExitOrderDTO entityDTO) {
        try {
            log.info("==============出入库委托书-新增 >>>>>>>>>>>>>>> {}", JSON.toJSONString(entityDTO));
            int res = entryandexitorderService.insertEntryAndExitOrder2(entityDTO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "出入库委托书-修改ver2", notes = "参数：EntryAndExitOrderDTO")
    @PutMapping(value = "/v2/update")
    public ResponseWrapper updateEntryAndExitOrder2(@RequestBody EntryAndExitOrderDTO entityDTO) {
        try {
            log.info("==============出入库委托书-修改 >>>>>>>>>>>>>>> {}", JSON.toJSONString(entityDTO));
            int res = entryandexitorderService.updateEntryAndExitOrder2(entityDTO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "出入库委托书--查看--通过主键", notes = "参数：主键")
    @DeleteMapping(value = "/v2/del/{wtbm}")
    public ResponseWrapper deleteEntryAndExitOrder(@PathVariable("wtbm") String wtbm) {
        try {
            entryandexitorderService.deleteEntryAndExitOrder(wtbm);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


    //出入库委托书-修改
    @ApiOperation(value = "出入库委托书-更新状态", notes = "参数：EntryAndExitOrderVO")
    @PutMapping(value = "/update2NextNode")
    public ResponseWrapper update2NextNode(@RequestBody EntryAndExitOrderDO entity) {
        try {
            entryandexitorderService.update2NextNode(entity);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "更新标的 底价", notes = "参数：EntryAndExitOrderVO")
    @PutMapping(value = "/updatePrice")
    public ResponseWrapper updatePrice(@RequestBody EntryAndExitOrderDTO entityDTO) {
        try {
            int res = entryandexitorderService.updatePrice(entityDTO);
            return ResponseWrapper.success(res);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "底价审批 状态更新", notes = "参数：EntryAndExitOrderVO")
    @PutMapping(value = "/updatePrice2NextNode")
    public ResponseWrapper updatePrice2NextNode(@RequestBody EntryAndExitOrderVO entity) {
        try {
            int res = entryandexitorderService.updatePrice2NextNode(entity);
            return ResponseWrapper.success(res);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "委托书、货源、安排公告 状态更新", notes = "参数：EntryAndExitOrderVO")
    @PutMapping(value = "/updateNotice2NextNode")
    public ResponseWrapper updateNotice2NextNode(@RequestBody EntryAndExitOrderVO entity) {
        try {
            JSONObject res = entryandexitorderService.updateNotice2NextNode(entity);
            return ResponseWrapper.success(res);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

}
