package com.unis.transaction.server.controller.tradeplan;

import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.vo.tradeplan.RefundLetterVO;
import com.unis.transaction.common.vo.tradeplan.RefundNoticeQueryVO;
import com.unis.transaction.common.vo.tradeplan.RefundNoticeVO;
import com.unis.transaction.server.service.RefundNoticeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Api(value = "保证金退款通知单", tags = "保证金退款通知单")
@Slf4j
@RestController
@RequestMapping(value = "/refundNotice")
public class RefundNoticeController {

    @Autowired
    private RefundNoticeService refundNoticeService;

    @ApiOperation(value = "保证金退款通知单-企业端新增", notes = "参数：RefundNoticeVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(@RequestBody RefundNoticeVO vo) {
        try {
            if(vo == null || StringUtils.isEmpty(vo.getHtbm())){
                return ResponseWrapper.error("参数错误！");
            }
            if( refundNoticeService.save(vo) > 0){
                return ResponseWrapper.success();
            }
        } catch (Exception e) {
            log.error("RefundNoticeController.save:{}",e.getMessage());
        }
        return ResponseWrapper.error();
    }

    //保证金退款通知单-修改
    @ApiOperation(value = "保证金退款通知单-修改", notes = "参数：RefundNoticeVO, type:1:修改生成前数据, 2:生成, 3:盖章 4:盖章")
    @PostMapping(value = "/update/{type}")
    public ResponseWrapper update(@PathVariable("type") Integer type, @RequestBody RefundNoticeVO vo) {
        try {
            if(vo == null || StringUtils.isEmpty(vo.getId())){
                return ResponseWrapper.error("参数错误！");
            }
            return  refundNoticeService.update(type,vo);

        } catch (Exception e) {
            log.error("RefundNoticeController.update:{}",e.getMessage());
        }
        return ResponseWrapper.error();

    }

    //保证金退款通知单-分页查询
    @ApiOperation(value = "保证金退款通知单-分页查询", notes = "参数：RefundNoticeQueryVO")
    @PostMapping(value = "/page/{pageNum}/{pageSize}")
    public ResponseWrapper getPage( @PathVariable("pageNum") Integer pageNum,
                                    @PathVariable("pageSize") Integer pageSize,
                                    @RequestBody RefundNoticeQueryVO queryVO) {
        try {
            return ResponseWrapper.success(refundNoticeService.getPage(pageNum, pageSize, queryVO));
        } catch (Exception e) {
            log.error("RefundNoticeController.getPage:{}",e.getMessage());
        }
        return ResponseWrapper.error();
    }

    //保证金退款通知单-合同分页查询
    @ApiOperation(value = "保证金退款通知单-合同分页查询", notes = "参数：RefundNoticeQueryVO")
    @PostMapping(value = "/contractPage/{pageNum}/{pageSize}")
    public ResponseWrapper getContractPage( @PathVariable("pageNum") Integer pageNum,
                                    @PathVariable("pageSize") Integer pageSize,
                                    @RequestBody RefundNoticeQueryVO queryVO){

        try {
            return ResponseWrapper.success(refundNoticeService.getContractPage(pageNum, pageSize, queryVO));
        } catch (Exception e) {
            log.error("RefundNoticeController.getContractPage:{}",e.getMessage());
        }
        return ResponseWrapper.error();
    }

    @ApiOperation(value = "保证金退款说明函-企业端新增", notes = "参数：RefundLetterVO")
    @PostMapping(value = "/letter/save")
    public ResponseWrapper saveLetter(@RequestBody RefundLetterVO vo) {
        try {
            if(vo == null || StringUtils.isEmpty(vo.getHtbm())){
                return ResponseWrapper.error("参数错误！");
            }
            if( refundNoticeService.saveLetter(vo) > 0){
                return ResponseWrapper.success();
            }
        } catch (Exception e) {
            log.error("RefundNoticeController.saveLetter:{}",e.getMessage());
        }
        return ResponseWrapper.error();
    }

    @ApiOperation(value = "保证金退款说明函-修改", notes = "参数：RefundLetterVO, type:1:修改生成前数据, 2:生成, 3:盖章 4:盖章")
    @PostMapping(value = "/letter/update/{type}")
    public ResponseWrapper updateLetter(@PathVariable("type") Integer type, @RequestBody RefundLetterVO vo) {
        try {
            if(vo == null || StringUtils.isEmpty(vo.getId())){
                return ResponseWrapper.error("参数错误！");
            }
            return  refundNoticeService.updateLetter(type,vo);

        } catch (Exception e) {
            log.error("RefundNoticeController.update:{}",e.getMessage());
        }
        return ResponseWrapper.error();

    }

    @ApiOperation(value = "保证金退款通知单-详情", notes = "参数：htbm")
    @GetMapping(value = "/info/{htbm}")
    public ResponseWrapper getInfoByHtbm(@PathVariable("htbm") String htbm) {
        try {
            RefundNoticeVO refundNoticeVO = refundNoticeService.getInfoByHtbm(htbm);
            return  ResponseWrapper.success(refundNoticeVO);

        } catch (Exception e) {
            log.error("RefundNoticeController.update:{}",e.getMessage());
        }
        return ResponseWrapper.error();

    }

}
