package com.unis.transaction.server.controller.tradeplan;

import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.vo.tradeplan.*;
import com.unis.transaction.server.service.TradeMarkService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * Author huyong
 *  交易标的 at 2019-09-21
 */
@RestController
@RequestMapping(value = "/trademark")
@Api(value = "交易标的", tags = "交易标的")
public class TradeMarkController {

    @Autowired
    private TradeMarkService trademarkService;

 	//交易标的-新增
 	@ApiOperation(value = "交易标的-新增", notes = "参数：TradeMarkBackVO")
    @PostMapping(value = "/insert")
    public ResponseWrapper insertTradeMark(@RequestBody TradeMarkBackVO vo) {
		try {
			trademarkService.insertTradeMark(vo);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//交易标的-修改
 	@ApiOperation(value = "交易标的-修改", notes = "参数：TradeMarkVO")
    @PostMapping(value = "/update")
    public ResponseWrapper updateTradeMark(@RequestBody TradeMarkBackVO vo) {
		try {
			trademarkService.updateTradeMark(vo);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//交易标的-新增
	@ApiOperation(value = "场次-新增", notes = "参数：TradeMarkVO")
	@PostMapping(value = "/insertCC")
	public ResponseWrapper insertCC(@RequestBody  SiteVO vo) {
		try {
			trademarkService.insertCC(vo);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//交易标的-新增
	@ApiOperation(value = "合同新增", notes = "参数：ContractVO")
	@PostMapping(value = "/insertContract")
	public ResponseWrapper insertContract(@RequestBody  ContractVO vo) {
		try {
			trademarkService.insertContract(vo);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}


	//交易标的-新增
	@ApiOperation(value = "合同修改", notes = "参数：ContractVO")
	@PostMapping(value = "/updateContract")
	public ResponseWrapper updateContract(@RequestBody  ContractVO vo) {
		try {
			trademarkService.updateContract(vo);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//交易标的-修改成不能修改
	@ApiOperation(value = "修改成不能修改", notes = "参数：ContractVO")
	@PostMapping(value = "/updateContractByisChange")
	public ResponseWrapper updateContractByisChange(@RequestBody  ContractVO vo) {
		try {
			trademarkService.updateContractByisChange(vo);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}


	//场次-查看--通过主键
	@ApiOperation(value = "合同--查看--通过主键", notes = "参数：主键")
	@GetMapping(value = "/selectContractDetail/{id}")
	public ResponseWrapper selectContractDetail(@PathVariable("id") String id) {
		try {
			return ResponseWrapper.success(trademarkService.selectContractDetail(id));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	@ApiOperation(value = "获取标的下拉列表", notes = "获取场次列表")
	@PostMapping(value = "/selectTradeMarkAll")
	public ResponseWrapper selectTradeMarkAll() {
		try {
			return ResponseWrapper.success(trademarkService.selectTradeMarkAll());
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	@ApiOperation(value = "根据标的号查询信息", notes = "参数：主键")
	@GetMapping(value = "/selectContract/{id}")
	public ResponseWrapper selectContract(@PathVariable("id") String id) {
		try {
			return ResponseWrapper.success(trademarkService.selectContract(id));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	@ApiOperation(value = "标的--查看--通过标的号", notes = "参数：标的号")
	@GetMapping(value = "/selectTradeMarkByBdh/{bdh}")
	public TradeMarkVO selectTradeMarkByBdh(@PathVariable("bdh") String bdh) {
		TradeMarkVO tradeMarkVO = null;
		try {
			 tradeMarkVO = trademarkService.selectTradeMarkByBdh(bdh);

		} catch (Exception e) {
			e.printStackTrace();
		}
		return tradeMarkVO;
	}

	@ApiOperation(value = "获取场次对应的合同下拉列表", notes = "参数：主键")
	@GetMapping(value = "/selectContractList/{id}")
	public ResponseWrapper selectContractList(@PathVariable("id") String id) {
		try {
			return ResponseWrapper.success(trademarkService.selectContractList(id));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	@ApiOperation(value = "获取场次对应的单位下拉列表", notes = "参数：主键")
	@GetMapping(value = "/selectDWmcList/{id}")
	public ResponseWrapper selectDWmcList(@PathVariable("id") String id) {
		try {
			return ResponseWrapper.success(trademarkService.selectDWmcList(id));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	@ApiOperation(value = "查询单位对应的合同下拉列表", notes = "参数：主键")
	@GetMapping(value = "/selectContractByDwbm/{dwbm}/{ccbm}")
	public ResponseWrapper selectContractByDwbm(@PathVariable("dwbm") String dwbm,@PathVariable("ccbm") String ccbm) {
		try {
			return ResponseWrapper.success(trademarkService.selectContractByDwbm(dwbm,ccbm));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}


	@ApiOperation(value = "查询场次对应的标的下拉列表", notes = "参数：主键")
	@PostMapping(value = "/selectTradeByCcbm/{ccbm}")
	public ResponseWrapper selectTradeByCcbm(@PathVariable("ccbm") String ccbm) {
		try {
			return ResponseWrapper.success(trademarkService.selectTradeByCcbm(ccbm));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	@ApiOperation(value = "查询单位对应的未退款合同列表", notes = "参数：ContractVO")
	@PostMapping(value = "/selectContracts/{dwbm}/{jylx}")
	public ResponseWrapper selectContracts(@PathVariable("dwbm") String dwbm,@PathVariable("jylx") String jylx) {
		try {
			return trademarkService.selectContracts(dwbm,jylx);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	@ApiOperation(value = "查询所有的未退款合同列表", notes = "参数：ContractVO")
	@PostMapping(value = "/selectContractAll")
	public ResponseWrapper selectContractAll() {
		try {
			return trademarkService.selectContractAll();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	@ApiOperation(value = "查询所有的未退款合同列表", notes = "参数：ContractVO")
	@PostMapping(value = "/selectContractAlls/{jylx}")
	public ResponseWrapper selectContractAlls(@PathVariable("jylx") String jylx) {
		try {
			return trademarkService.selectContractAlls(jylx);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	@ApiOperation(value = "获取合同列表", notes = "获取场次列表")
	@PostMapping(value = "/selectContractPage")
	public ResponseWrapper selectContractPage(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                              @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                              @RequestBody ContractVO vo) {
		try {
			return ResponseWrapper.success(trademarkService.selectContractPage(pageNum,pageSize,vo));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//交易标的-修改
	@ApiOperation(value = "场次-修改", notes = "参数：TradeMarkVO")
	@PostMapping(value = "/updateCC")
	public ResponseWrapper updateCC(@RequestBody SiteVO vo) {
		try {
			trademarkService.updateCC(vo);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//交易标的-修改
	@ApiOperation(value = "场次-修改", notes = "参数：")
	@PostMapping(value = "/selectCode")
	public ResponseWrapper selectCode() {
		try {
			return ResponseWrapper.success(trademarkService.selectCode());
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//场次-查看--通过主键
	@ApiOperation(value = "场次--查看--通过主键", notes = "参数：主键")
	@GetMapping(value = "/selectCC/{id}")
	public ResponseWrapper selectCC(@PathVariable("id") String id) {
		try {
			return ResponseWrapper.success(trademarkService.selectCC(id));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}


	//交易标的-修改
	@ApiOperation(value = "场次-修改", notes = "参数：cccode")
	@PostMapping(value = "/valiCode")
	public ResponseWrapper valiCode(@RequestParam("ccbm") String ccbm,@RequestParam("cccode") String cccode) {
		try {
			return ResponseWrapper.success(trademarkService.valiCode(ccbm,cccode));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}



	//交易标的-查看--返回单条
	@ApiOperation(value = "交易标的--查看--返回单条", notes = "参数：TradeMarkVO")
	@PostMapping(value = "/selectDetail")
    public ResponseWrapper selectTradeMarkInfo(@RequestBody TradeMarkVO vo) {
       	try {
			return ResponseWrapper.success(trademarkService.selectTradeMarkInfo(vo));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
    }

	//场次-删除--通过主键
	@ApiOperation(value = "场次--查看--通过主键", notes = "参数：主键")
	@DeleteMapping(value = "/delCC/{id}")

	public ResponseWrapper delCC(@PathVariable("id") String id) {
		try {
			trademarkService.delCC(id);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

    //交易标的-查看--通过主键
	@ApiOperation(value = "交易标的--查看--通过主键", notes = "参数：主键")
	@GetMapping(value = "/get/{id}")
    public ResponseWrapper selectTradeMarkDetail(@PathVariable("id") String id) {
       	try {
			return ResponseWrapper.success(trademarkService.getTradeMarkDetail(id));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
    }


     //交易标的-删除--通过主键
	@ApiOperation(value = "交易标的--查看--通过主键", notes = "参数：主键")
	@DeleteMapping(value = "/del/{id}")

    public ResponseWrapper deleteTradeMark(@PathVariable("id") String id) {
       	try {
       	 trademarkService.deleteTradeMark(id);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
    }


	//交易标的-删除--通过主键
	@ApiOperation(value = "交易标的--查看--通过主键", notes = "参数：主键")
	@DeleteMapping(value = "/deleteTrade/{id}")

	public ResponseWrapper deleteTrade(@PathVariable("id") String id) {
		try {
			trademarkService.deleteTrade(id);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	@ApiOperation(value = "获取b标的列表", notes = "获取场次列表")
	@PostMapping(value = "/selectPage")
	public ResponseWrapper selectPage(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum
			,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
			,@RequestBody WarehousingArrangementVO vo) {
		try {
			return ResponseWrapper.success(trademarkService.selectPage(pageNum,pageSize,vo));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

    @ApiOperation(value = "获取场次列表", notes = "获取场次列表")
    @PostMapping(value = "/selectList")
    public ResponseWrapper selectByWtfbm(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                         @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                         @RequestBody SiteVO vo) {
        try {
            return ResponseWrapper.success(trademarkService.selectByWtfbm(pageNum, pageSize, vo));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }



	@ApiOperation(value = "交易标的--导出", notes = "参数：安排编码")
	@GetMapping(value = "/export/{apbm}")
	public ResponseWrapper export(@PathVariable("apbm")String apbm) {
	  	try {
				return ResponseWrapper.success(trademarkService.exportTradeMark(apbm));
			} catch (Exception e) {
				e.printStackTrace();
				return ResponseWrapper.error();
			}
	}



}
