package com.unis.transaction.server.controller.tradeplan;

import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.server.entity.tradeplan.TyBmkhxxtj;
import com.unis.transaction.server.entity.tradeplan.TyJyccKhxx;
import com.unis.transaction.server.entity.tradeplan.TyJyccKhxxVO;
import com.unis.transaction.server.service.TyJyccKhxxService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.util.List;

/**
 * @Classname TyJyccKhxxController
 * @Description 交易场次_报名客户Controller
 * @Date 2023/7/27 15:17
 * @Created by rising123sun
 */
@RestController
@RequestMapping(value = "/jyccKhxx")
@Api(value = "交易场次_报名客户", tags = "交易场次_报名客户")
public class TyJyccKhxxController {

    @Resource
    private TyJyccKhxxService tyJyccKhxxService;

    //    写下使用easyexcel导入数据并存入到数据库的代码
    @PostMapping(value = "/importExcel")
    public ResponseWrapper importExcel(@RequestBody TyJyccKhxxVO tyJyccKhxxVO) {
        try {
            return tyJyccKhxxService.importExcel(tyJyccKhxxVO);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    // 根据ccId查询所有的客户信息
    @GetMapping(value = "/selectKhxxByWtbh")
    public ResponseWrapper selectKhxxByWtbh(@ApiParam(name = "ccId", value = "场次id", required = true) @RequestParam(value = "ccId") String ccId) {
        try {
            return ResponseWrapper.success(tyJyccKhxxService.selectKhxxByWtbh(ccId));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    // 根据wtbh查询所有的客户信息
    @GetMapping(value = "/selectKhxx")
    public ResponseWrapper selectKhxx(@ApiParam(name = "wtbm", value = "wtbm", required = true) @RequestParam(value = "wtbm") String wtbm) {
        try {
            return ResponseWrapper.success(tyJyccKhxxService.selectKhxx(wtbm));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    // 添加客户信息
    @PostMapping(value = "/addKhxx")
    public ResponseWrapper addKhxx(List<TyJyccKhxx> tyJyccKhxxList) {
        try {
            return ResponseWrapper.success(tyJyccKhxxService.addKhxx(tyJyccKhxxList));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    // 删除客户信息
    @DeleteMapping(value = "/deleteKhxx")
    public ResponseWrapper deleteKhxx(List<TyJyccKhxx> tyJyccKhxxList) {
        try {
            return ResponseWrapper.success(tyJyccKhxxService.deleteKhxx(tyJyccKhxxList));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    // 报名客户信息统计分页列表查询
    @PostMapping(value = "/selectKhxxTj")
    @ApiOperation(value = "报名客户信息统计分页列表查询", notes = "报名客户信息统计分页列表查询")
    public ResponseWrapper selectKhxxTj(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                        @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                        @RequestBody TyBmkhxxtj tyBmkhxxtj) {
        try {
            return ResponseWrapper.success(tyJyccKhxxService.selectKhxxTj(pageNum, pageSize, tyBmkhxxtj));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    // 报名客户信息统计报表导出
    @PostMapping(value = "/exportKhxxTj")
    @ApiOperation(value = "报名客户信息统计报表导出", notes = "报名客户信息统计报表导出")
    public ResponseWrapper exportKhxxTj(@RequestBody TyBmkhxxtj tyBmkhxxtj) {
        try {
            return ResponseWrapper.success(tyJyccKhxxService.exportKhxxTj(tyBmkhxxtj));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
}
