package com.unis.transaction.server.controller.tradeplan;

import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.vo.tradeplan.EntryAndExitOrderInputVO;
import com.unis.transaction.common.vo.tradeplan.WarehousingArrangementVO;
import com.unis.transaction.server.service.WarehousingArrangementService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * Author huyong
 * 出入库安排 at 2019-09-20
 */
@RestController
@RequestMapping(value = "/warehousingarrangement")
@Api(value = "出入库安排", tags = "出入库安排")
public class WarehousingArrangementController {

    @Autowired
    private WarehousingArrangementService warehousingarrangementService;

    //出入库安排-新增
    @ApiOperation(value = "出入库安排-新增", notes = "参数：EntryAndExitOrderInputVO")
    @PostMapping(value = "/insert")
    public ResponseWrapper insertWarehousingArrangement(@RequestBody EntryAndExitOrderInputVO vo) {
        try {
            warehousingarrangementService.insertWarehousingArrangement(vo);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //出入库安排-修改
    @ApiOperation(value = "出入库安排-修改", notes = "参数：EntryAndExitOrderInputVO")
    @PostMapping(value = "/update")
    public ResponseWrapper updateWarehousingArrangement(@RequestBody EntryAndExitOrderInputVO vo, @RequestParam("sjlx") Integer sjlx) {
        try {
            warehousingarrangementService.updateWarehousingArrangement(vo, sjlx);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


    //出入库安排-分页列表
    @ApiOperation(value = "出入库安排-分页列表", notes = "参数：WarehousingArrangementVO")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping(value = "/select")
    public ResponseWrapper selectWarehousingArrangementPageList(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                                                @RequestBody WarehousingArrangementVO vo) {
        try {
            return ResponseWrapper.success(warehousingarrangementService.selectWarehousingArrangementPageList(pageNum, pageSize, vo));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


    //出入库安排-查看--返回单条
    @ApiOperation(value = "出入库安排--查看--返回多条", notes = "参数：WarehousingArrangementVO")
    @PostMapping(value = "/selectDetail")
    public ResponseWrapper selectWarehousingArrangementInfo(@RequestBody WarehousingArrangementVO vo) {
        try {
            return ResponseWrapper.success(warehousingarrangementService.selectWarehousingArrangementInfo(vo));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "出入库安排--查看--返回多条", notes = "参数：WarehousingArrangementVO")
    @PostMapping(value = "/selectWareDetail")
    public ResponseWrapper selectWareDetail(@RequestBody WarehousingArrangementVO vo) {
        try {
            return ResponseWrapper.success(warehousingarrangementService.selectWareDetail(vo));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //出入库安排-查看--通过主键
    @ApiOperation(value = "出入库安排--查看--通过主键", notes = "参数：主键")
    @GetMapping(value = "/get/{id}")
    public ResponseWrapper selectWarehousingArrangementDetail(@PathVariable("id") String id) {
        try {
            return ResponseWrapper.success(warehousingarrangementService.getWarehousingArrangementDetail(id));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //出入库安排-根据委托编码查询
    @ApiOperation(value = "出入库安排--根据委托编码查询", notes = "参数：主键")
    @GetMapping(value = "/selectwarehousingArrangementByWtbm/{wtbm}")
    public ResponseWrapper selectwarehousingArrangementByWtbm(@PathVariable("wtbm") String id) {
        try {
            return warehousingarrangementService.selectwarehousingArrangementByWtbm(id);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


    //出入库安排-删除--通过主键
    @ApiOperation(value = "出入库安排--查看--通过主键", notes = "参数：主键")
    @DeleteMapping(value = "/del/{id}")

    public ResponseWrapper deleteWarehousingArrangement(@PathVariable("id") String id) {
        try {
            warehousingarrangementService.deleteWarehousingArrangement(id);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    //出入库安排-修改
    @ApiOperation(value = "出入库安排-单条修改", notes = "参数：WarehousingArrangementVO")
    @PostMapping(value = "/singleupdate")
    public ResponseWrapper updateWarehousingArrangement(@RequestBody WarehousingArrangementVO vo) {
        try {
            Integer updateWarehousingArrangement = warehousingarrangementService.updateWarehousingArrangement(vo);
            if (updateWarehousingArrangement > 0) {
                return ResponseWrapper.success("修改成功");
            }
            return ResponseWrapper.error("修改失败");

        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

}
