package com.unis.transaction.server.domain.creditevaluate;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.utils.EntityUtil;
import com.unis.transaction.common.utils.JsonUtils;
import com.unis.transaction.common.vo.creditevaluate.EnterPriseClassSetVO;
import com.unis.transaction.common.vo.creditevaluate.EnterPriseClassVO;
import com.unis.transaction.common.vo.creditevaluate.EnterPriseClassVariableVO;
import com.unis.transaction.server.dao.EnterPriseClassSetDao;
import com.unis.transaction.server.dao.EnterPriseClassVariableDao;
import com.unis.transaction.server.entity.creditevaluate.EnterPriseClassSetDO;
import com.unis.transaction.server.entity.creditevaluate.EnterPriseClassVariableDO;
import com.unis.transaction.server.service.impl.BaseRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 企业分级设置业务
 * @author lidiaoquan at 2019-09-26
 */
@Component
public class EnterPriseClassSetDomain{

    @Autowired
    EnterPriseClassSetDao enterpriseclasssetDao;
    
    @Autowired
    EnterPriseClassVariableDao enterPriseClassVariableDao;
    
    @Autowired
    BaseRepository baseMapper;
        
	/**
   	  * 通用的插入处理Calendar.getInstance().get(Calendar.YEAR)
     * @param entity <企业分级设置>
     */
    private void buildInsertData(EnterPriseClassSetDO entity){
        entity.buildInsertData();
        String pk= baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(EnterPriseClassSetDO.class)
        ,"szbm", "SZ", 8);
        entity.setSzbm(pk);
    }
    
   /**
       * 通用的更新处理
    * @param entity
    */
    private void buildUpdateData(EnterPriseClassSetDO entity){
        entity.buildUpdateData();
    }
    
    /**
     * <企业分级设置>插入全部字段
     * @author lidiaoquan
     */
    public int insertEntity(EnterPriseClassSetDO entity) {
        buildInsertData(entity);
        return enterpriseclasssetDao.insertSelective(entity);
    }
    
    /**
     * <企业分级设置>非null的修改
     * @author lidiaoquan
     */
    public int updateEntity(EnterPriseClassSetDO entity) {
        buildUpdateData(entity);
        return enterpriseclasssetDao.updateByPrimaryKeySelective(entity);
    }
    
	//企业分级设置-新增
    public ResponseWrapper insertEnterPriseClassSet(EnterPriseClassVO vo){
    	if(vo != null) {
    		List<EnterPriseClassSetVO> setList = vo.getSetList();
    		for (EnterPriseClassSetVO set : setList) {
    	        EnterPriseClassSetDO entity=JsonUtils.parse(
    	                JsonUtils.serialize(set),EnterPriseClassSetDO.class);
    	        insertEntity(entity);
			}
    		List<EnterPriseClassVariableVO> varList = vo.getVarList();
    		for (EnterPriseClassVariableVO var : varList) {
    			EnterPriseClassVariableDO entity=JsonUtils.parse(
    	                JsonUtils.serialize(var),EnterPriseClassVariableDO.class);
    	        entity.buildInsertData();
    	        String pk= baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(EnterPriseClassVariableDO.class)
    	        ,"blbm", "BL", 8);
    	        entity.setBlbm(pk);    			
    			enterPriseClassVariableDao.insert(entity);
			}
    	}
        return ResponseWrapper.success();		 
    }

	//企业分级设置-修改 注意：updateType非必填项 默认为null 代表业务更新 ，值为1时代表 单表更新
    public ResponseWrapper updateEnterPriseClassSet(EnterPriseClassSetVO vo,java.lang.Integer updateType){
        EnterPriseClassSetDO entity=JsonUtils.parse(
            JsonUtils.serialize(vo),EnterPriseClassSetDO.class);
   		int num = updateEntity(entity);
        return ResponseWrapper.choose(num);
	}
	
	//企业分级设置-分页列表
    public Page<EnterPriseClassSetVO> selectEnterPriseClassSetPageList(int pageNum, int pageSize, EnterPriseClassSetVO vo){
 		PageHelper.startPage(pageNum,pageSize);
  		Page<EnterPriseClassSetVO> selectPageList = enterpriseclasssetDao.selectPageList(vo);
        return selectPageList;		
    }

	//企业分级设置-列表全部数据
	@SuppressWarnings("unchecked")
    public ResponseWrapper selectEnterPriseClassSetAll(EnterPriseClassSetVO vo){
		List<EnterPriseClassSetDO> enterpriseclasssetDOList=enterpriseclasssetDao.selectList(vo);
        List<EnterPriseClassSetVO> voList=JsonUtils.parse(
            JsonUtils.serialize(enterpriseclasssetDOList),List.class);
        return ResponseWrapper.success(voList);
    }

	//企业分级设置--查看--返回单条
    public ResponseWrapper selectEnterPriseClassSetDetail(EnterPriseClassSetVO vo){
		EnterPriseClassSetVO selectById = enterpriseclasssetDao.selectDetail(vo);
        return ResponseWrapper.success(selectById);   
    }

}
