package com.unis.transaction.server.domain.givebackbail;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.constant.GiveBackBailConstant;
import com.unis.transaction.common.constant.PlanStatusConstant;
import com.unis.transaction.common.utils.EntityUtil;
import com.unis.transaction.common.vo.backlog.BacklogAddVO;
import com.unis.transaction.common.vo.backlog.BacklogUpdateVO;
import com.unis.transaction.common.vo.backlog.ReceiverCollectionVO;
import com.unis.transaction.common.vo.givebackbail.ComplainVO;
import com.unis.transaction.common.vo.givebackbail.GiveBackBailLetterVO;
import com.unis.transaction.common.vo.signuppay.TransactionSignUpVO;
import com.unis.transaction.common.vo.tradeplan.ContractVO;
import com.unis.transaction.common.vo.tradeplan.SiteVO;
import com.unis.transaction.server.dao.ComplainDao;
import com.unis.transaction.server.dao.GiveBackBailLetterDao;
import com.unis.transaction.server.dao.TradeMarkDao;
import com.unis.transaction.server.dao.TransactionSignUpDao;
import com.unis.transaction.server.entity.givebackbail.ComplainDO;
import com.unis.transaction.server.entity.signuppay.TransactionSignUpDO;
import com.unis.transaction.server.service.BacklogMQService;
import com.unis.transaction.server.service.impl.BaseRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 交易申诉业务
 * @author lgd
 */
@Component
public class ComplainDomain {


    @Autowired
    ComplainDao complainDao;
    @Autowired
    BacklogMQService mqService;
    @Autowired
    BaseRepository baseMapper;
    @Autowired
    TradeMarkDao tradeMarkDao;
    @Autowired
    TransactionSignUpDao transactionsignupDao;

    @Autowired
    GiveBackBailLetterDao giveBackBailLetterDao;
    /**
     * 通用的插入处理Calendar.getInstance().get(Calendar.YEAR)
     * @param entity <保证金退款>
     */
    private void buildInsertData(ComplainDO entity){
        entity.buildInsertData();
        String pk= baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(ComplainDO.class)
                ,"csbm", "CS", 8);
        entity.setCsbm(pk);
    }

    /**
     * 通用的更新处理
     * @param entity
     */
    private void buildUpdateData(ComplainDO entity){
        entity.buildUpdateData();
    }

    /**
     * <交易申诉>插入全部字段
     * @author lgd
     */
    public int insertEntity(ComplainDO entity) {
        buildInsertData(entity);
        return complainDao.insertSelective(entity);
    }

    /**
     * <交易申诉>非null的修改
     * @author lgd
     */
    public int updateEntity(ComplainDO entity) {
        buildUpdateData(entity);
        return complainDao.updateByPrimaryKeySelective(entity);
    }
    public ResponseWrapper insertComplain(ComplainVO vo) {
        ComplainDO entity= JsonUtils.parse(
                JsonUtils.serialize(vo),ComplainDO.class);
        if(vo.getSjlx()==1){
            entity.setBcszt("0");
        }
        int num= insertEntity(entity);
        if(num>0){
            if (PlanStatusConstant.ISSUED.getValue().equals(vo.getCszt())) {
                BacklogAddVO record = new BacklogAddVO();
                record.buildAddVO(record);
                record.setItemId(entity.getCsbm());
                record.setItemQuery(vo.getItemQuery());
                record.setItemQueryHaveDone(vo.getItemQueryHaveDone());
                record.setItemUrlHaveDone(vo.getItemUrlHaveDone());
                if(vo.getSjlx()==1){
                    record.setItemName(entity.getApcc() + "的交易诉求已发起，待交易中心处理");
                }else{
                    record.setItemName(entity.getApcc() + "的交易申诉已发起，待交易中心处理");
                }
                record.setItemStatus(Integer.valueOf(vo.getCszt()));
                record.setItemStatusName(vo.getCsztmc());
                record.setItemUrl(vo.getUrl());
                new Thread(new Runnable() {
                    @Override
                    public void run() {
                        if (vo.getUserMap() != null && vo.getUserMap().size() > 0) {
                            for (Map.Entry<String, List<ReceiverCollectionVO>> m : vo.getUserMap().entrySet()) {
                                for (ReceiverCollectionVO userVO : m.getValue()) {
                                    System.out.println("********************接收人*******************");
                                    System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                                    System.out.println("********************************************");
                                    record.setReceiver(userVO.getUserName());
                                    record.setReceiverId(userVO.getUserId());
                                    mqService.sendMsg(JSON.parseObject(com.unis.transaction.common.utils.JsonUtils.serialize(record)), "insert");
                                }
                            }
                        }
                    }
                }).start();
            }
        }
        return ResponseWrapper.choose(num);
    }

    public ResponseWrapper updateComplain(ComplainVO vo) {
        ComplainDO entity=JsonUtils.parse(
                JsonUtils.serialize(vo),ComplainDO.class);
        if(PlanStatusConstant.FINISHED.getValue().equals(vo.getCszt())){
            if(vo.getHflx()==1||vo.getHflx()==2){
                if(vo.getCsdw().equals(vo.getCcdw())){
                    entity.setBcsdw(vo.getSgdw());
                }else{
                    entity.setBcsdw(vo.getCcdw());
                }
            }
        }
        int num = updateEntity(entity);
        if(num>0){
            if (PlanStatusConstant.ISSUED.getValue().equals(vo.getCszt())) {
                BacklogAddVO record = new BacklogAddVO();
                record.buildAddVO(record);
                record.setItemQuery(vo.getItemQuery());
                record.setItemId(entity.getCsbm());
                record.setItemQueryHaveDone(vo.getItemQueryHaveDone());
                record.setItemUrlHaveDone(vo.getItemUrlHaveDone());
                if(vo.getSjlx()==1){
                    record.setItemName(entity.getApcc() + "的交易诉求已发起，待交易中心处理");
                }else{
                    record.setItemName(entity.getApcc() + "的交易申诉已发起，待交易中心处理");
                }
                record.setItemStatus(Integer.valueOf(vo.getCszt()));
                record.setItemStatusName(vo.getCsztmc());
                record.setItemUrl(vo.getUrl());
                new Thread(new Runnable() {
                    @Override
                    public void run() {
                        if (vo.getUserMap() != null && vo.getUserMap().size() > 0) {
                            for (Map.Entry<String, List<ReceiverCollectionVO>> m : vo.getUserMap().entrySet()) {
                                for (ReceiverCollectionVO userVO : m.getValue()) {
                                    System.out.println("********************接收人*******************");
                                    System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                                    System.out.println("********************************************");
                                    record.setReceiver(userVO.getUserName());
                                    record.setReceiverId(userVO.getUserId());
                                    mqService.sendMsg(JSON.parseObject(com.unis.transaction.common.utils.JsonUtils.serialize(record)), "insert");
                                }
                            }
                        }
                    }
                }).start();
            }
            //申诉已办
            if (PlanStatusConstant.FINISHED.getValue().equals(vo.getCszt())) {
                BacklogUpdateVO updateVO = new BacklogUpdateVO();
                updateVO.buildUpdateVO(updateVO);
                updateVO.setItemId(vo.getCsbm());
                if(vo.getSjlx()==1){
                    updateVO.setItemName(entity.getApcc() + "的交易诉求交易中心业务部已处理");
                }else{
                    updateVO.setItemName(entity.getApcc() + "的交易申诉交易中心业务部已处理");
                }
                updateVO.setItemStatus(Integer.valueOf(vo.getCszt()));
                updateVO.setItemStatusName(vo.getCsztmc());
                mqService.sendMsg(JSON.parseObject(com.unis.transaction.common.utils.JsonUtils.serialize(updateVO)), "update");
            }
            if (PlanStatusConstant.Back.getValue().equals(vo.getCszt())) {
                BacklogUpdateVO updateVO = new BacklogUpdateVO();
                updateVO.buildUpdateVO(updateVO);
                updateVO.setItemId(vo.getCsbm()+"-01");
                updateVO.setItemName(entity.getApcc() + "的交易诉求被诉求方已回复");
                updateVO.setItemStatus(Integer.valueOf(vo.getCszt()));
                updateVO.setItemStatusName(vo.getCsztmc());
                mqService.sendMsg(JSON.parseObject(com.unis.transaction.common.utils.JsonUtils.serialize(updateVO)), "update");
            }
            if (PlanStatusConstant.FINISHED.getValue().equals(vo.getCszt())&&vo.getSjlx()==1) {
                BacklogAddVO record = new BacklogAddVO();
                record.buildAddVO(record);
                record.setItemQuery(vo.getItemQuery());
                record.setItemId(entity.getCsbm()+"-01");
                record.setItemQueryHaveDone(vo.getItemQueryHaveDone());
                record.setItemUrlHaveDone(vo.getItemUrlHaveDone());
                record.setItemName(entity.getApcc() + "的交易诉求待回复");
                record.setItemStatus(Integer.valueOf(vo.getCszt()));
                record.setItemStatusName(vo.getCsztmc());
                record.setItemUrl(vo.getUrl());
                new Thread(new Runnable() {
                    @Override
                    public void run() {
                        if (vo.getUserMap() != null && vo.getUserMap().size() > 0) {
                            for (Map.Entry<String, List<ReceiverCollectionVO>> m : vo.getUserMap().entrySet()) {
                                for (ReceiverCollectionVO userVO : m.getValue()) {
                                    System.out.println("********************接收人*******************");
                                    System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                                    System.out.println("********************************************");
                                    record.setReceiver(userVO.getUserName());
                                    record.setReceiverId(userVO.getUserId());
                                    mqService.sendMsg(JSON.parseObject(com.unis.transaction.common.utils.JsonUtils.serialize(record)), "insert");
                                }
                            }
                        }
                    }
                }).start();
            }
        }
        return ResponseWrapper.choose(num);
    }

    public ResponseWrapper deleteComplain(ComplainVO vo) {
        int num = complainDao.deleteByPrimaryKey(vo.getCsbm());
        return ResponseWrapper.choose(num);
    }

    public ResponseWrapper selectComplainDetail(ComplainVO vo) {
        ComplainDO selectById = complainDao.selectByPrimaryKey(vo.getCsbm());
        return ResponseWrapper.success(selectById);
    }

    public Page<ComplainVO> selectComplainPageList(int pageNum, int pageSize, ComplainVO vo) {
        PageHelper.startPage(pageNum,pageSize);
        if(PlanStatusConstant.TO_BE_ISSUE.getValue().equals(vo.getPageType())){
            List<String> ztList = new ArrayList<>();
            if(vo.getCszt()==null){
                if("LS001020".equals(CurrentUtil.getOrgId())){
                    ztList.add(PlanStatusConstant.FINISHED.getValue());
                    ztList.add(PlanStatusConstant.ISSUED.getValue());
                    ztList.add(PlanStatusConstant.Back.getValue());
                }else{
                    ztList.add(PlanStatusConstant.FINISHED.getValue());
                    ztList.add(PlanStatusConstant.TO_BE_ISSUE.getValue());
                    ztList.add(PlanStatusConstant.ISSUED.getValue());
                    ztList.add(PlanStatusConstant.Back.getValue());
                    vo.setCsdw(CurrentUtil.getOrgId());
                }
            }
            if(ztList.size()>0){
                vo.setZtList(ztList);
            }
        }else{
            List<String> ztList = new ArrayList<>();
            ztList.add(PlanStatusConstant.ISSUED.getValue());
            ztList.add(PlanStatusConstant.FINISHED.getValue());
            ztList.add(PlanStatusConstant.Back.getValue());
            if(ztList.size()>0){
                vo.setZtList(ztList);
            }
            //vo.setCszt(PlanStatusConstant.FINISHED.getValue());
            vo.setBcsdw(CurrentUtil.getOrgId());
        }
        Page<ComplainVO> selectPageList = complainDao.selectPageList(vo);
        return selectPageList;
    }

    public ResponseWrapper selectSiteAll() {
        TransactionSignUpVO vo = new TransactionSignUpVO();
        vo.setDwbm(CurrentUtil.getOrgId());
        vo.setZt(Integer.valueOf(GiveBackBailConstant.ZC.getValue()));
        List<String> htList = new ArrayList<>();
        GiveBackBailLetterVO giveBackBailLettervo = new GiveBackBailLetterVO();
        giveBackBailLettervo.setZt(GiveBackBailConstant.ZC.getValue());
        //giveBackBailLettervo.setWtfbm(CurrentUtil.getOrgId());
        List<GiveBackBailLetterVO> list = giveBackBailLetterDao.selectHt(giveBackBailLettervo);
        for(GiveBackBailLetterVO giveBackBailLetterDO:list){
            String[] strings = giveBackBailLetterDO.getHtbm().split(",");
            for(String str:strings){
                htList.add(str);
            }
        }
        if(htList.size()>0){
            vo.setHtList(htList);
        }
        List<TransactionSignUpDO> transactionsignupDOList=transactionsignupDao.selectSiteAll(vo);
        return ResponseWrapper.success(transactionsignupDOList);
    }

    public ResponseWrapper selectContracts(String ccbm) {
        TransactionSignUpVO vo = new TransactionSignUpVO();
        vo.setDwbm(CurrentUtil.getOrgId());
        vo.setZt(Integer.valueOf(GiveBackBailConstant.ZC.getValue()));
        SiteVO siteVO = new SiteVO();
        siteVO.setCcbm(ccbm);
        siteVO.setDwbm(CurrentUtil.getOrgId());
        siteVO.setZt(Integer.valueOf(GiveBackBailConstant.ZC.getValue()));
        List<ContractVO> list = tradeMarkDao.selectContracts(siteVO);
        return ResponseWrapper.success(list);
    }
}
