/*
 * GiveBackBailLetterDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-09-20 21:04:21 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.transaction.server.domain.givebackbail;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.EntityUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.constant.GiveBackBailConstant;
import com.unis.transaction.common.constant.RotatePlanStatusConstant;
import com.unis.transaction.common.vo.backlog.BacklogAddVO;
import com.unis.transaction.common.vo.backlog.ReceiverCollectionVO;
import com.unis.transaction.common.vo.givebackbail.GiveBackBailLetterVO;
import com.unis.transaction.common.vo.givebackbail.GiveBackVO;
import com.unis.transaction.common.vo.tradeplan.ContractVO;
import com.unis.transaction.common.vo.tradeplan.SiteVO;
import com.unis.transaction.server.dao.*;
import com.unis.transaction.server.domain.signuppay.TransactionSignUpDomain;
import com.unis.transaction.server.entity.givebackbail.GiveBackBailLetterDO;
import com.unis.transaction.server.entity.givebackbail.GiveBackDO;
import com.unis.transaction.server.entity.tradeplan.EntryAndExitOrderDO;
import com.unis.transaction.server.entity.tradeplan.SiteDO;
import com.unis.transaction.server.service.BacklogMQService;
import com.unis.transaction.server.service.impl.BaseRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * TY_JYTKWTH-退保证金委托函
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2019-09-20 21:04:21
 */
@Component
@Transactional
public class GiveBackBailLetterDomain {

    @Autowired
    GiveBackBailLetterDao giveBackBailLetterDao;

    @Autowired
    GiveBackDao giveBackDao;

    @Autowired
    TradeMarkDao trademarkMapper;

    @Autowired
    SiteDao siteDao;

    @Autowired
    EntryAndExitOrderDao entryAndExitOrderDao;

    @Autowired
    TransactionSignUpDomain transactionSignUpDomain;

    @Autowired
    BaseRepository baseRepository;
    @Autowired
    BacklogMQService mqService;
   /**
    * 通用的插入处理
    * @param entity    <退保证金委托函>对象
    */
    private void buildInsertData(GiveBackBailLetterDO entity){
        entity.buildInsertData();
        //当前为主表
        String pk= baseRepository.selectByTableNameAndAttr(EntityUtil.getTableName(GiveBackBailLetterDO.class)
        ,"WTHBM", "WT", 8);
        entity.setWthbm(pk);
    }

   /**
    * 通用的更新处理
    * @param entity    <退保证金委托函>对象
    */
    private void buildUpdateData(GiveBackBailLetterDO entity){
        entity.buildUpdateData();
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>插入全部字段
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntity(GiveBackBailLetterDO entity) {
        buildInsertData(entity);
        return giveBackBailLetterDao.insertEntity(entity);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>插入全部字段
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(GiveBackBailLetterVO bailLetterVO) {
        //有属性操作则优先在vo处理
        GiveBackBailLetterDO entity= JsonUtils.parse(
            JsonUtils.serialize(bailLetterVO), GiveBackBailLetterDO.class);
        int num= insertEntity(entity);
        if(num>0){
            //主键设置回去
            bailLetterVO.setWthbm(entity.getWthbm());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>插入全部字段,可删除部分字段改为选择性插入
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(GiveBackBailLetterDO entity) {
        buildInsertData(entity);
        return giveBackBailLetterDao.insertEntitySelective(entity);
    }

    public void dataPrevew(GiveBackBailLetterVO bailLetterVO){
        if(GiveBackBailConstant.YFS.getValue().equals(bailLetterVO.getZt())){
            String[] data  = bailLetterVO.getHtbm().split(",");
            for(String htbm:data){
                GiveBackVO giveBackVO=  new GiveBackVO();
                giveBackVO.setHtbm(htbm);
                giveBackVO.setSjlx("1");
                GiveBackDO giveBackDO = giveBackDao.selectDetail(giveBackVO);
                giveBackDO.setTkzt(GiveBackBailConstant.JYJB.getValue());
                giveBackDO.setTkztmc(GiveBackBailConstant.JYJB.getName());
                giveBackDO.setWthbm(bailLetterVO.getWthbm());
                giveBackDao.updateByPrimaryKeySelective(giveBackDO);
            }
        }
    }

    public ResponseWrapper uniqueCheck(GiveBackBailLetterVO bailLetterVO){
        GiveBackBailLetterVO giveBackBailLetterDO=new GiveBackBailLetterVO();
        //查询出所有已发送的合同
        giveBackBailLetterDO.setWtfbm(CurrentUtil.getOrgId());
        giveBackBailLetterDO.setZt(GiveBackBailConstant.YFS.getValue());
        List<GiveBackBailLetterVO> listAll =  giveBackBailLetterDao.selectYfsHt(giveBackBailLetterDO);
        List<String> list = new ArrayList<>();
        for(GiveBackBailLetterVO giveBackBailLetterVO:listAll){
            String[] strings = giveBackBailLetterVO.getHtbm().split(",");
            for(String str:strings){
                list.add(str);
            }
        }
        String[] hts = bailLetterVO.getHtbm().split(",");
        for(String str:hts){
            if(list.contains(str)){
                return ResponseWrapper.duplicate();
            }
        }
        return ResponseWrapper.success();
        }

    /**
     * <TY_JYTKWTH-退保证金委托函>插入全部字段,可删除部分字段改为选择性插入
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(GiveBackBailLetterVO bailLetterVO) {
        ResponseWrapper res=uniqueCheck(bailLetterVO);
        if(RotatePlanStatusConstant.QDCH.getValue().equals(bailLetterVO.getZt())) {
            if (!res.isSuccess()) {
                return res;
            }
        }
        bailLetterVO.setWtfbm(CurrentUtil.getOrgId());
        //有属性操作则优先在vo处理
        GiveBackBailLetterDO entity= JsonUtils.parse(
            JsonUtils.serialize(bailLetterVO), GiveBackBailLetterDO.class);
        int num= insertEntitySelective(entity);
        if(num>0){
            //主键设置回去
            bailLetterVO.setWthbm(entity.getWthbm());
        	dataPrevew(bailLetterVO);
        	/*GiveBackDO giveBackDO = giveBackDao.selectDetailByWthbm(entity.getWthbm(),CurrentUtil.getOrgId(),
                    bailLetterVO.getJsdwbm());*/
            List<GiveBackDO> giveBackDOs = giveBackDao.selectDetailByWthbms(entity.getWthbm(),CurrentUtil.getOrgId(),
                    bailLetterVO.getJsdwbm());
            if(RotatePlanStatusConstant.QDCH.getValue().equals(bailLetterVO.getZt())){
                for(GiveBackDO giveBack:giveBackDOs){
                    System.out.println("*************进入创建待办************");
                    BacklogAddVO record = new BacklogAddVO();
                    record.buildAddVO(record);
                    //SiteDO siteDO = siteDao.selectByPrimaryKey(entity.getCcbm());
                    //EntryAndExitOrderDO exitOrderDO = entryAndExitOrderDao.selectByPrimaryKey(siteDO.getWtbm());
                    String query ="";
                    if(bailLetterVO.getItemQuery()!=null){
                        query = bailLetterVO.getItemQuery().replace("undefined",CurrentUtil.getOrgName());
                    }
                    String queryView ="";
                    if(bailLetterVO.getItemQueryHaveDone()!=null){
                        queryView = bailLetterVO.getItemQueryHaveDone().replace("undefined",CurrentUtil.getOrgName());
                    }
                    record.setItemQuery(query);
                    record.setItemQueryHaveDone(queryView);
                    record.setItemUrlHaveDone(bailLetterVO.getItemUrlHaveDone());
                    record.setItemId(giveBack.getTkbm()+"-05");
                    record.setItemName(entity.getApcc() + "的退保证金委托函已发送");
                    record.setItemStatus(Integer.valueOf(bailLetterVO.getZt()));
                    record.setItemStatusName(bailLetterVO.getZtmc());
                    record.setItemUrl(bailLetterVO.getUrl());
                    // 另起线程执行待办
                    //List<ReceiverCollectionVO> userList =
                    new Thread(new Runnable() {
                        @Override
                        public void run() {
                            for (ReceiverCollectionVO userVO : bailLetterVO.getUserList()) {
                                System.out.println("********************接收人*******************");
                                System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                                System.out.println("********************************************");
                                record.setReceiver(userVO.getUserName());
                                record.setReceiverId(userVO.getUserId());
                                // 需要将对象序列化成JSONObject
                                mqService.sendMsg(JSON.parseObject(com.unis.transaction.common.utils.JsonUtils.serialize(record)), "insert");
                            }
                        }
                    }).start();
                }
            }
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>更改状态
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(GiveBackBailLetterDO entity) {
        return giveBackBailLetterDao.updateStatusByEntity(entity);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>更改状态
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(GiveBackBailLetterVO bailLetterVO) {
        //有属性操作则优先在vo处理
        GiveBackBailLetterDO entity= JsonUtils.parse(
            JsonUtils.serialize(bailLetterVO), GiveBackBailLetterDO.class);
        int num= updateStatusByEntity(entity);
        if(num>0){
            dataPrevew(bailLetterVO);
            //主键设置回去(此处实际不需要)
            bailLetterVO.setWthbm(entity.getWthbm());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体更新单条或者多条数据
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(GiveBackBailLetterDO entity) {
        buildUpdateData(entity);
        return giveBackBailLetterDao.updateByEntity(entity);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体更新单条或者多条数据
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(GiveBackBailLetterVO bailLetterVO) {
        //有属性操作则优先在vo处理
        GiveBackBailLetterDO entity= JsonUtils.parse(
            JsonUtils.serialize(bailLetterVO), GiveBackBailLetterDO.class);
        int num= updateByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            bailLetterVO.setWthbm(entity.getWthbm());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体选择性更新
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(GiveBackBailLetterDO entity) {
        buildUpdateData(entity);
        int update = giveBackBailLetterDao.updateByEntitySelective(entity);
        return update;
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体选择性更新(存在则更新,不存在则插入,其余删除)
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(GiveBackBailLetterVO bailLetterVO) {
        ResponseWrapper res=uniqueCheck(bailLetterVO);
        if(RotatePlanStatusConstant.QDCH.getValue().equals(bailLetterVO.getZt())) {
            if (!res.isSuccess()) {
                return res;
            }
        }
        GiveBackBailLetterDO entity= JsonUtils.parse(
            JsonUtils.serialize(bailLetterVO), GiveBackBailLetterDO.class);
        entity.setWtfbm(CurrentUtil.getOrgId());
        int num= updateByEntitySelective(entity);
        if(num>0){
        	dataPrevew(bailLetterVO);
            //主键设置回去(此处实际不需要)
            bailLetterVO.setWthbm(entity.getWthbm());
            GiveBackDO giveBackDO = giveBackDao.selectDetailByWthbm(entity.getWthbm(),CurrentUtil.getOrgId(),bailLetterVO.getJsdwbm());
            if(RotatePlanStatusConstant.QDCH.getValue().equals(bailLetterVO.getZt())){
                System.out.println("*************进入创建待办************");
                BacklogAddVO record = new BacklogAddVO();
                record.buildAddVO(record);
                //SiteDO siteDO = siteDao.selectByPrimaryKey(entity.getCcbm());
                //EntryAndExitOrderDO exitOrderDO = entryAndExitOrderDao.selectByPrimaryKey(siteDO.getWtbm());
                String query ="";
                if(bailLetterVO.getItemQuery()!=null){
                    query = bailLetterVO.getItemQuery().replace("undefined",CurrentUtil.getOrgName());
                }
                String queryView ="";
                if(bailLetterVO.getItemQueryHaveDone()!=null){
                    queryView = bailLetterVO.getItemQueryHaveDone().replace("undefined",CurrentUtil.getOrgName());
                }
                //String query = bailLetterVO.getItemQuery().replace("undefined",exitOrderDO.getWtfmc());
                //String queryView = bailLetterVO.getItemQueryHaveDone().replace("undefined",exitOrderDO.getWtfmc());
                record.setItemQuery(query);
                record.setItemQueryHaveDone(queryView);
                record.setItemUrlHaveDone(bailLetterVO.getItemUrlHaveDone());
                record.setItemId(giveBackDO.getTkbm()+"-01");
                record.setItemName(bailLetterVO.getJsdw()+ "的退保证金委托函已发送");
                record.setItemStatus(Integer.valueOf(bailLetterVO.getZt()));
                record.setItemStatusName(bailLetterVO.getZtmc());
                record.setItemUrl(bailLetterVO.getUrl());
                // 另起线程执行待办
                //List<ReceiverCollectionVO> userList =
                new Thread(new Runnable() {
                    @Override
                    public void run() {
                        for (ReceiverCollectionVO userVO : bailLetterVO.getUserList()) {
                            System.out.println("********************接收人*******************");
                            System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                            System.out.println("********************************************");
                            record.setReceiver(userVO.getUserName());
                            record.setReceiverId(userVO.getUserId());
                            // 需要将对象序列化成JSONObject
                            mqService.sendMsg(JSON.parseObject(com.unis.transaction.common.utils.JsonUtils.serialize(record)), "insert");
                        }
                    }
                }).start();
            }
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体单条或者批量删除
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int deleteByEntity(GiveBackBailLetterDO entity) {
        GiveBackBailLetterVO bailLetterVO= JsonUtils.parse(
            JsonUtils.serialize(entity),GiveBackBailLetterVO.class);
        return giveBackBailLetterDao.deleteByEntity(bailLetterVO);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体单条或者批量删除
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(GiveBackBailLetterVO bailLetterVO) {
        int num= giveBackBailLetterDao.deleteByEntity(bailLetterVO);
        return ResponseWrapper.choose(num);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int deleteShamByEntity(GiveBackBailLetterDO entity) {
        GiveBackBailLetterVO bailLetterVO= JsonUtils.parse(
            JsonUtils.serialize(entity),GiveBackBailLetterVO.class);
        return giveBackBailLetterDao.deleteShamByEntity(bailLetterVO);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(GiveBackBailLetterVO bailLetterVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= giveBackBailLetterDao.deleteShamByEntity(bailLetterVO);
        return ResponseWrapper.choose(num);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体查询数量
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(GiveBackBailLetterVO bailLetterVO) {
        int num= giveBackBailLetterDao.selectCountByEntity(bailLetterVO);
        return num;
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体(唯一标示)查询一条数据
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public GiveBackBailLetterVO selectById(GiveBackBailLetterDO entity) {
        GiveBackBailLetterVO bailLetterVO= JsonUtils.parse(
            JsonUtils.serialize(entity),GiveBackBailLetterVO.class);
        return giveBackBailLetterDao.selectById(bailLetterVO);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体(唯一标示)查询一条数据
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public GiveBackBailLetterVO selectById(GiveBackBailLetterVO bailLetterVO) {
        GiveBackBailLetterVO bailLetterVODb= giveBackBailLetterDao.selectById(bailLetterVO);
        return bailLetterVODb;
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体查询分页列表
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<GiveBackBailLetterVO> selectPageByEntity(int pageNo, int pageSize
        , GiveBackBailLetterVO bailLetterVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        Page<GiveBackBailLetterVO> bailLetterVOPage=giveBackBailLetterDao.selectPageByEntity(bailLetterVO);
        for(GiveBackBailLetterVO giveBackBailLetterVO:bailLetterVOPage){
            if(giveBackBailLetterVO.getCcbm()!=null){
                SiteDO siteDO = siteDao.selectByPrimaryKey(giveBackBailLetterVO.getCcbm());
                EntryAndExitOrderDO exitOrderDO = entryAndExitOrderDao.selectByPrimaryKey(siteDO.getWtbm());
                giveBackBailLetterVO.setLspz(exitOrderDO.getPzmc());
            }
        }
        return bailLetterVOPage;
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体查询列表
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<GiveBackBailLetterVO> selectByEntity(GiveBackBailLetterDO entity) {
        GiveBackBailLetterVO bailLetterVO= JsonUtils.parse(
            JsonUtils.serialize(entity),GiveBackBailLetterVO.class);
        return giveBackBailLetterDao.selectByEntity(bailLetterVO);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>根据实体查询列表
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<GiveBackBailLetterVO> selectByEntity(GiveBackBailLetterVO bailLetterVO) {
        return giveBackBailLetterDao.selectByEntity(bailLetterVO);
    }

    public List<ContractVO> selectTkdwList() {
        String dwdm = CurrentUtil.getOrgId();
        List<ContractVO> list = null;
        //查询出所有已发送的合同
        List<String> htList = new ArrayList<>();
        GiveBackBailLetterVO giveBackBailLettervo = new GiveBackBailLetterVO();
        giveBackBailLettervo.setZt(GiveBackBailConstant.ZC.getValue());
        giveBackBailLettervo.setWtfbm(CurrentUtil.getOrgId());
        List<GiveBackBailLetterVO> lists = giveBackBailLetterDao.selectHt(giveBackBailLettervo);
        if(!lists.isEmpty()){
            for(GiveBackBailLetterVO giveBackBailLetterDO:lists){
                String[] strings = giveBackBailLetterDO.getHtbm().split(",");
                for(String str:strings){
                    htList.add(str);
                }
            }
        }
        SiteVO siteVO = new SiteVO();
        if(htList.size()>0){
            siteVO.setHtList(htList);
        }
        siteVO.setDwbm(dwdm);
        list = trademarkMapper.selectTkdwList(siteVO);
        List<ContractVO> result = new ArrayList<>();
        Map<String,String> map = new HashMap<>();
       for(ContractVO contractVO:list){
            if(contractVO.getCmdw().equals(dwdm)){
                map.put(contractVO.getSgdw(),contractVO.getSgmc());
            }else{
                map.put(contractVO.getCmdw(),contractVO.getCmmc());
            }
       }
        for (Map.Entry<String, String> entry : map.entrySet()) {
            ContractVO contractVO = new ContractVO();
            contractVO.setCmmc(entry.getValue());
            contractVO.setCmdw(entry.getKey());
            result.add(contractVO);
        }
        return result;
    }

    public List<ContractVO>  selectTkdwHtList(String dwbm) {
        String dwdm = CurrentUtil.getOrgId();
        List<ContractVO> list = null;
        //查询出所有已发送的合同
        List<String> htList = new ArrayList<>();
        GiveBackBailLetterVO giveBackBailLettervo = new GiveBackBailLetterVO();
        giveBackBailLettervo.setZt(GiveBackBailConstant.ZC.getValue());
        giveBackBailLettervo.setWtfbm(CurrentUtil.getOrgId());
        List<GiveBackBailLetterVO> lists = giveBackBailLetterDao.selectHt(giveBackBailLettervo);
        if(!lists.isEmpty()){
            for(GiveBackBailLetterVO giveBackBailLetterDO:lists){
                String[] strings = giveBackBailLetterDO.getHtbm().split(",");
                for(String str:strings){
                    htList.add(str);
                }
            }
        }
        SiteVO siteVO = new SiteVO();
        if(htList.size()>0){
            siteVO.setHtList(htList);
        }
        siteVO.setWtbm(dwbm);
        siteVO.setDwbm(dwdm);
        list = trademarkMapper.selectTkdwHtList(siteVO);
        return list;
    }
}
