package com.unis.transaction.server.domain.givebackbail;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.constant.GiveBackBailConstant;
import com.unis.transaction.common.utils.EntityUtil;
import com.unis.transaction.common.vo.backlog.BacklogAddVO;
import com.unis.transaction.common.vo.backlog.BacklogUpdateVO;
import com.unis.transaction.common.vo.backlog.ReceiverCollectionVO;
import com.unis.transaction.common.vo.givebackbail.GiveBackChildVO;
import com.unis.transaction.common.vo.givebackbail.GiveBackVO;
import com.unis.transaction.common.vo.givebackbail.PassBackVO;
import com.unis.transaction.server.dao.*;
import com.unis.transaction.server.entity.givebackbail.GiveBackBailLetterDO;
import com.unis.transaction.server.entity.givebackbail.GiveBackChildDO;
import com.unis.transaction.server.entity.givebackbail.GiveBackDO;
import com.unis.transaction.server.entity.givebackbail.PassBackDO;
import com.unis.transaction.server.entity.signuppay.TransactionSignUpDO;
import com.unis.transaction.server.entity.tradeplan.EntryAndExitOrderDO;
import com.unis.transaction.server.service.BacklogMQService;
import com.unis.transaction.server.service.impl.BaseRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * 保证金退款业务
 * @author lidiaoquan at 2019-09-21
 */
@Component
public class GiveBackDomain{

    @Autowired
    GiveBackDao givebackDao;
    @Autowired
   PassBackDao passBackDao;
    @Autowired
    GiveBackChildDao giveBackChildDao;
    @Autowired
    GiveBackBailLetterDao giveBackBailLetterDao;

    @Autowired
    EntryAndExitOrderDao entryandexitorderMapper;

    @Autowired
    BaseRepository baseMapper;
    @Autowired
    BacklogMQService mqService;

    @Autowired
    TransactionSignUpDao transactionSignUpDao;

	/**
   	  * 通用的插入处理Calendar.getInstance().get(Calendar.YEAR)
     * @param entity <保证金退款>
     */
    private void buildInsertData(GiveBackDO entity){
        entity.buildInsertData();
        String pk= baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(GiveBackDO.class)
        ,"tkbm", "TK", 8);
        entity.setTkbm(pk);
    }

   /**
       * 通用的更新处理
    * @param entity
    */
    private void buildUpdateData(GiveBackDO entity){
        entity.buildUpdateData();
    }

    /**
     * <保证金退款>插入全部字段
     * @author lidiaoquan
     */
    public int insertEntity(GiveBackDO entity) {
        buildInsertData(entity);
        return givebackDao.insertSelective(entity);
    }

    /**
     * <保证金退款>非null的修改
     * @author lidiaoquan
     */
    public int updateEntity(GiveBackDO entity) {
        buildUpdateData(entity);
        return givebackDao.updateByPrimaryKeySelective(entity);
    }

	//保证金退款-新增
    public ResponseWrapper insertGiveBack(GiveBackVO vo){
        GiveBackDO entity=JsonUtils.parse(
            JsonUtils.serialize(vo),GiveBackDO.class);
        int num= insertEntity(entity);
        return ResponseWrapper.choose(num);
    }

	//保证金退款-修改 注意：updateType非必填项 默认为null 代表业务更新 ，值为1时代表 单表更新
    public ResponseWrapper updateGiveBack(GiveBackVO vo,java.lang.Integer updateType){
        GiveBackDO entity=JsonUtils.parse(
            JsonUtils.serialize(vo),GiveBackDO.class);
   		int num = updateEntity(entity);
   		if(num > 0) {
   			dataPrevew(entity);
            if(GiveBackBailConstant.JYSH.getValue().equals(vo.getTkzt())||GiveBackBailConstant.CWSP.getValue().equals
                    (vo.getTkzt())||GiveBackBailConstant.JSSP.getValue().equals(vo.getTkzt())||GiveBackBailConstant.CWQP.getValue().equals(vo.getTkzt())){
                System.out.println("*************五步审核进入创建待办************");
                BacklogAddVO record = new BacklogAddVO();
                record.buildAddVO(record);
                record.setItemQuery(vo.getItemQuery());
                record.setItemQueryHaveDone(vo.getItemQueryHaveDone());
                record.setItemUrlHaveDone(vo.getItemUrlHaveDone());
                if(GiveBackBailConstant.JYSH.getValue().equals(vo.getTkzt())){
                    record.setItemId(entity.getTkbm()+"-01");
                    record.setItemName(entity.getApcc() + "的成交保证金待交易部负责人审核");
                }else if(GiveBackBailConstant.CWSP.getValue().equals(vo.getTkzt())){
                    record.setItemId(entity.getTkbm()+"-02");
                    record.setItemName(entity.getApcc() + "的成交保证金待财务审批人员审核");
                }else if(GiveBackBailConstant.JSSP.getValue().equals(vo.getTkzt())){
                    record.setItemId(entity.getTkbm()+"-03");
                    record.setItemName(entity.getApcc() + "的成交保证金待结算部负责人审核");
                }else {
                    record.setItemId(entity.getTkbm()+"-04");
                    record.setItemName(entity.getApcc() + "的成交保证金待分管副总裁审核");
                }
                //record.setItemId(entity.getTkbm());
                //record.setItemName(entity.getApcc() + "的保证金待退款");
                record.setItemStatus(Integer.valueOf(vo.getTkzt()));
                record.setItemStatusName(vo.getTkztmc());
                record.setItemUrl(vo.getUrl());
                // 另起线程执行待办
               // ThreadUtil.startThread(record,vo.getUserList());
               new Thread(new Runnable() {
                    @Override
                    public void run() {
                        for (ReceiverCollectionVO userVO : vo.getUserList()) {
                            System.out.println("********************接收人*******************");
                            System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                            System.out.println("********************************************");
                            record.setReceiver(userVO.getUserName());
                            record.setReceiverId(userVO.getUserId());
                            // 需要将对象序列化成JSONObject
                            mqService.sendMsg(JSON.parseObject(com.unis.transaction.common.utils.JsonUtils.serialize(record)), "insert");
                        }
                    }
                }).start();
            }
            //五步审核已办   ---已办
            if(GiveBackBailConstant.YTK.getValue().equals(vo.getTkzt())||GiveBackBailConstant.JYSH.getValue().equals(vo
                    .getTkzt())||GiveBackBailConstant.CWSP.getValue().equals(vo.getTkzt())||GiveBackBailConstant.JSSP.getValue().equals(vo.getTkzt())||GiveBackBailConstant.CWQP.getValue().equals(vo.getTkzt())){
                BacklogUpdateVO updateVO = new BacklogUpdateVO();
                updateVO.buildUpdateVO(updateVO);
                if(GiveBackBailConstant.JYSH.getValue().equals(vo.getTkzt())){
                    updateVO.setItemId(entity.getTkbm()+"-05");
                    updateVO.setItemName(entity.getApcc() + "的成交保证金退款在交易经办人处已处理");
                }else if(GiveBackBailConstant.CWSP.getValue().equals(vo.getTkzt())){
                    updateVO.setItemId(entity.getTkbm()+"-01");
                    updateVO.setItemName(entity.getApcc() + "的成交保证金在交易部负责人处已处理");
                }else if(GiveBackBailConstant.JSSP.getValue().equals(vo.getTkzt())){
                    updateVO.setItemId(entity.getTkbm()+"-02");
                    updateVO.setItemName(entity.getApcc() + "的成交保证金在财务审批人员处已处理");
                }else if(GiveBackBailConstant.CWQP.getValue().equals(vo.getTkzt())){
                    updateVO.setItemId(entity.getTkbm()+"-03");
                    updateVO.setItemName(entity.getApcc() + "的成交保证金在结算部负责人处已处理");
                }else{
                    updateVO.setItemId(entity.getTkbm()+"-04");
                    updateVO.setItemName(entity.getApcc() + "的成交保证金在分管副总裁处已处理");
                }
                    updateVO.setItemStatus(Integer.valueOf(vo.getTkzt()));
                    updateVO.setItemStatusName(vo.getTkztmc());
                    updateVO.setItemQueryHaveDone(vo.getItemQueryHaveDone());
                    updateVO.setItemUrlHaveDone(vo.getItemUrlHaveDone());
                    mqService.sendMsg(JSON.parseObject(com.unis.transaction.common.utils.JsonUtils.serialize(updateVO)), "update");
                }
   		}
        return ResponseWrapper.choose(num);
	}

	private void dataPrevew(GiveBackDO entity) {
        if(GiveBackBailConstant.YTK.getValue().equals(entity.getTkzt())){
        	entity = givebackDao.selectByPrimaryKey(entity.getTkbm());
        	/*if(StringUtils.isNotEmpty(entity.getApcc())){
                //更新报名记录为退款中
                TransactionSignUpDO transactionsignup = new TransactionSignUpDO();
                transactionsignup.setApcc(entity.getApcc());
                transactionsignup.setTkzt(GiveBackBailConstant.YTK.getValue());
                transactionsignup.setTkztmc(GiveBackBailConstant.YTK.getName());
                transactionSignUpDao.updateSignUpTkzt(transactionsignup);
            }*/
        }
        if(entity.getTkfl()==0){
                GiveBackBailLetterDO giveBackBailLetterDO = giveBackBailLetterDao.selectByPrimaryKey(entity.getWthbm());
                giveBackBailLetterDO.setZt(entity.getTkzt());
                giveBackBailLetterDO.setZtmc(entity.getTkztmc());
                giveBackBailLetterDao.updateByEntitySelective(giveBackBailLetterDO);
                if(GiveBackBailConstant.YTK.getValue().equals(entity.getTkzt())){
                    // 修改报名状态
                    TransactionSignUpDO transactionSignUpDO = transactionSignUpDao.selectByPrimaryKey(entity.getJybm());
                    transactionSignUpDO.setShzt(GiveBackBailConstant.YTK.getValue());
                    transactionSignUpDO.setShztmc(GiveBackBailConstant.YTK.getName());
                    transactionSignUpDao.updateByPrimaryKeySelective(transactionSignUpDO);
                }
        }
	}

	//保证金退款-分页列表
    public Page<GiveBackVO> selectGiveBackPageList(int pageNum, int pageSize, GiveBackVO vo){
 		PageHelper.startPage(pageNum,pageSize);
 		List<String> tkztList = new ArrayList<String>();
 		if(vo.getTkzt()!=null){

        }else{
            switch (vo.getPageType()) {
                case 1:
                    tkztList.add(GiveBackBailConstant.JYJB.getValue());
                    tkztList.add(GiveBackBailConstant.JSSP.getValue());
                    tkztList.add(GiveBackBailConstant.JYSH.getValue());
                    tkztList.add(GiveBackBailConstant.CWQP.getValue());
                    tkztList.add(GiveBackBailConstant.CWSP.getValue());
                    tkztList.add(GiveBackBailConstant.YTK.getValue());
                    break;
                case 2:
                    tkztList.add(GiveBackBailConstant.JSSP.getValue());
                    tkztList.add(GiveBackBailConstant.JYSH.getValue());
                    tkztList.add(GiveBackBailConstant.CWQP.getValue());
                    tkztList.add(GiveBackBailConstant.CWSP.getValue());
                    tkztList.add(GiveBackBailConstant.YTK.getValue());
                    break;
                case 3:
                    tkztList.add(GiveBackBailConstant.JSSP.getValue());
                    tkztList.add(GiveBackBailConstant.CWQP.getValue());
                    tkztList.add(GiveBackBailConstant.CWSP.getValue());
                    tkztList.add(GiveBackBailConstant.YTK.getValue());
                    break;
                case 4:
                    tkztList.add(GiveBackBailConstant.CWQP.getValue());
                    tkztList.add(GiveBackBailConstant.JSSP.getValue());
                    tkztList.add(GiveBackBailConstant.YTK.getValue());
                    break;
                case 5:
                    tkztList.add(GiveBackBailConstant.CWQP.getValue());
                    tkztList.add(GiveBackBailConstant.YTK.getValue());
                    break;
                default:
                    break;
            }
            if(tkztList.size()>0){
                vo.setTkztList(tkztList);
            }
        }
        Page<GiveBackVO> selectPageList = givebackDao.selectPageList(vo);

  		for (GiveBackVO result : selectPageList) {
            EntryAndExitOrderDO exitOrderDO = entryandexitorderMapper.selectByPrimaryKey(result.getWtbm());
            result.setLspzmc(exitOrderDO.getPzmc());
            GiveBackBailLetterDO giveBackBailLetterDO = giveBackBailLetterDao.selectByPrimaryKey(result.getWthbm());
            result.setTklx(giveBackBailLetterDO.getWtlx());
		}
        return selectPageList;
    }

	//保证金退款-列表全部数据
	@SuppressWarnings("unchecked")
    public ResponseWrapper selectGiveBackAll(GiveBackVO vo){
		List<GiveBackDO> givebackDOList=givebackDao.selectList(vo);
        List<GiveBackVO> voList=JsonUtils.parse(
            JsonUtils.serialize(givebackDOList),List.class);
        return ResponseWrapper.success(voList);
    }

	//保证金退款--查看--返回单条
    public ResponseWrapper selectGiveBackDetail(GiveBackVO vo){
		//GiveBackVO selectById = givebackDao.selectUnionDetail(vo);
        GiveBackDO selectById = givebackDao.selectByPrimaryKey(vo.getTkbm());
        GiveBackVO entity= JsonUtils.parse(
                JsonUtils.serialize(selectById),GiveBackVO.class);
      /*  if(selectById.getTkfl()==0){
            GiveBackBailLetterDO giveBackBailLetterDO = giveBackBailLetterDao.selectByPrimaryKey(entity.getWthbm());
            entity.setJsdw(giveBackBailLetterDO.getJsdw());
            entity.setDwmc(giveBackBailLetterDO.getJsdw());
        }else{
            TransactionSignUpDO transactionSignUpDO = transactionSignUpDao.selectByPrimaryKey(entity.getJybm());
            entity.setDwmc(transactionSignUpDO.getDwmc());
            entity.setJsdw(transactionSignUpDO.getDwmc());
        }*/
        return ResponseWrapper.success(entity);
    }

    public List<GiveBackVO> selectGiveBackList() {
        return givebackDao.selectGiveBackList();
    }

    public void updateGiveEntity(GiveBackVO giveBackVO) {
        GiveBackDO entity= JsonUtils.parse(
                JsonUtils.serialize(giveBackVO),GiveBackDO.class);
        givebackDao.updateByPrimaryKeySelective(entity);
    }

    public ResponseWrapper updateGiveBackPass(PassBackVO vo) {
       PassBackDO entity=JsonUtils.parse(
                JsonUtils.serialize(vo),PassBackDO.class);
        if(vo.getChilds()!=null&&vo.getChilds().length()>0) {
            List<GiveBackChildDO> voList = JsonUtils.parseList(JsonUtils.serialize(vo.getChilds()), GiveBackChildDO
                    .class);
            giveBackChildDao.deleteByTkbm(vo.getTkbm());
            for(GiveBackChildDO recordDO:voList){
                String pk= baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(GiveBackChildDO.class)
                        ,"gcbm", "GC", 8);
                recordDO.setTkbm(entity.getTkbm());
                recordDO.setGcbm(pk);
                giveBackChildDao.insertSelective(recordDO);
            }
        }
        int num = passBackDao.updateByPrimaryKeySelective(entity);
        if(num>0){
            //修改报名状态
            GiveBackVO giveBackVO = new GiveBackVO();
            giveBackVO.setCcbm(vo.getCcbm());
            giveBackVO.setTkfl(1);
            List<GiveBackDO> giveBackDOS = givebackDao.selectList(giveBackVO);
            for(GiveBackDO giveBackDO:giveBackDOS){
                TransactionSignUpDO transactionSignUpDO = transactionSignUpDao.selectByPrimaryKey(giveBackDO.getJybm());
                transactionSignUpDO.setShzt(GiveBackBailConstant.WYTK.getValue());
                transactionSignUpDO.setShztmc(GiveBackBailConstant.WYTK.getName());
                transactionSignUpDao.updateByPrimaryKeySelective(transactionSignUpDO);
            }
            //五步审核待办
            if(GiveBackBailConstant.JYSH.getValue().equals(vo.getTkzt())||GiveBackBailConstant.CWSP.getValue().equals
                    (vo.getTkzt())||GiveBackBailConstant.JSSP.getValue().equals(vo.getTkzt())||GiveBackBailConstant.CWQP.getValue().equals(vo.getTkzt())){
                System.out.println("*************五步审核进入创建待办************");
                BacklogAddVO record = new BacklogAddVO();
                record.buildAddVO(record);
                record.setItemQuery(vo.getItemQuery());
                record.setItemQueryHaveDone(vo.getItemQueryHaveDone());
                record.setItemUrlHaveDone(vo.getItemUrlHaveDone());
                if(GiveBackBailConstant.JYSH.getValue().equals(vo.getTkzt())){
                    record.setItemId(entity.getTkbm()+"-01");
                    record.setItemName(entity.getApcc() + "的未成交保证金待交易部负责人审核");
                }else if(GiveBackBailConstant.CWSP.getValue().equals(vo.getTkzt())){
                    record.setItemId(entity.getTkbm()+"-02");
                    record.setItemName(entity.getApcc() + "的未成交保证金待财务审批人员审核");
                }else if(GiveBackBailConstant.JSSP.getValue().equals(vo.getTkzt())){
                    record.setItemId(entity.getTkbm()+"-03");
                    record.setItemName(entity.getApcc() + "的未成交保证金待结算部负责人审核");
                }else {
                    record.setItemId(entity.getTkbm()+"-04");
                    record.setItemName(entity.getApcc() + "的未成交保证金待分管副总裁审核");
                }
                //record.setItemId(entity.getTkbm());
                //record.setItemName(entity.getApcc() + "的保证金待退款");
                record.setItemStatus(Integer.valueOf(vo.getTkzt()));
                record.setItemStatusName(vo.getTkztmc());
                record.setItemUrl(vo.getUrl());
                // 另起线程执行待办
                // ThreadUtil.startThread(record,vo.getUserList());
                new Thread(new Runnable() {
                    @Override
                    public void run() {
                        for (ReceiverCollectionVO userVO : vo.getUserList()) {
                            System.out.println("********************接收人*******************");
                            System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                            System.out.println("********************************************");
                            record.setReceiver(userVO.getUserName());
                            record.setReceiverId(userVO.getUserId());
                            // 需要将对象序列化成JSONObject
                            mqService.sendMsg(JSON.parseObject(com.unis.transaction.common.utils.JsonUtils.serialize(record)), "insert");
                        }
                    }
                }).start();
            }
            //五步审核已办   ---已办
            if(GiveBackBailConstant.WYTK.getValue().equals(vo.getTkzt())||GiveBackBailConstant.CWSP.getValue().equals(vo
                    .getTkzt())||GiveBackBailConstant.JSSP.getValue().equals(vo.getTkzt())||GiveBackBailConstant.CWQP.getValue().equals(vo.getTkzt())){
                BacklogUpdateVO updateVO = new BacklogUpdateVO();
                updateVO.buildUpdateVO(updateVO);
                if(GiveBackBailConstant.WYTK.getValue().equals(vo.getTkzt())){
                    updateVO.setItemId(entity.getTkbm()+"-04");
                    updateVO.setItemName(entity.getApcc() + "的未成交保证金在分管副总裁处已处理");
                }else if(GiveBackBailConstant.CWSP.getValue().equals(vo.getTkzt())){
                    updateVO.setItemId(entity.getTkbm()+"-01");
                    updateVO.setItemName(entity.getApcc() + "的未成交保证金在交易部负责人处已处理");
                }else if(GiveBackBailConstant.JSSP.getValue().equals(vo.getTkzt())){
                    updateVO.setItemId(entity.getTkbm()+"-02");
                    updateVO.setItemName(entity.getApcc() + "的未成交保证金在财务审批人员处已处理");
                }else if(GiveBackBailConstant.CWQP.getValue().equals(vo.getTkzt())){
                    updateVO.setItemId(entity.getTkbm()+"-03");
                    updateVO.setItemName(entity.getApcc() + "的未成交保证金在结算部负责人处已处理");
                }
                updateVO.setItemQueryHaveDone(vo.getItemQueryHaveDone());
                updateVO.setItemUrlHaveDone(vo.getItemUrlHaveDone());
                updateVO.setItemStatus(Integer.valueOf(vo.getTkzt()));
                updateVO.setItemStatusName(vo.getTkztmc());
                mqService.sendMsg(JSON.parseObject(com.unis.transaction.common.utils.JsonUtils.serialize(updateVO)), "update");
            }
            }
        return ResponseWrapper.choose(num);
    }

    public ResponseWrapper selectGiveBackPass(PassBackVO vo) {
        PassBackDO passBackDO = passBackDao.selectByPrimaryKey(vo.getTkbm());
        PassBackVO entity=JsonUtils.parse(
                JsonUtils.serialize(passBackDO),PassBackVO.class);
        List<GiveBackChildVO> giveBackChildDOS = giveBackChildDao.selectListByTkbm(vo.getTkbm());
        if(giveBackChildDOS.size()>0){
            entity.setChildVOS(giveBackChildDOS);
        }else{
            GiveBackVO giveBackVO = new GiveBackVO();
            giveBackVO.setCcbm(vo.getCcbm());
           List<GiveBackDO> list = givebackDao.selectList(giveBackVO);
            List<GiveBackChildVO> giveBackChildVOList = new ArrayList<>();
           for(GiveBackDO giveBackDO:list){
               GiveBackChildVO giveBackChildVO = new GiveBackChildVO();
               if(giveBackDO.getTkfl()==0){
                   giveBackChildVO.setCjje(giveBackDO.getJe());
                   giveBackChildVO.setCjsl(giveBackDO.getSl().toString());
                   giveBackChildVO.setDjje(giveBackDO.getSl().multiply(new BigDecimal("10")).toString());
                   giveBackChildVO.setQtje(giveBackDO.getJkje().subtract(giveBackDO.getSl().multiply(new BigDecimal
                           ("10"))).toString());
               }else{
                   giveBackChildVO.setCjje("0");
                   giveBackChildVO.setCjsl("0");
                   giveBackChildVO.setDjje("0");
                   giveBackChildVO.setQtje(giveBackDO.getJkje().toString());
               }
               giveBackChildVO.setDwmc(giveBackDO.getDwmc());
               giveBackChildVO.setDwbm(giveBackDO.getDwbm());
               giveBackChildVO.setJkje(giveBackDO.getJkje().toString());

               giveBackChildVO.setSxf(giveBackDO.getSxf());
               giveBackChildVOList.add(giveBackChildVO);
           }
            entity.setChildVOS(giveBackChildVOList);
        }
        return ResponseWrapper.success(entity);
    }

    public Page<PassBackVO> selectPassBackPageList(int pageNum, int pageSize, PassBackVO vo) {
        PageHelper.startPage(pageNum,pageSize);
        List<String> tkztList = new ArrayList<String>();
        if(vo.getTkzt()!=null){

        }else{
            switch (vo.getPageType()) {
                case 1:
                    tkztList.add(GiveBackBailConstant.JYJB.getValue());
                    tkztList.add(GiveBackBailConstant.JSSP.getValue());
                    tkztList.add(GiveBackBailConstant.JYSH.getValue());
                    tkztList.add(GiveBackBailConstant.CWQP.getValue());
                    tkztList.add(GiveBackBailConstant.CWSP.getValue());
                    tkztList.add(GiveBackBailConstant.WYTK.getValue());
                    break;
                case 2:
                    tkztList.add(GiveBackBailConstant.JSSP.getValue());
                    tkztList.add(GiveBackBailConstant.JYSH.getValue());
                    tkztList.add(GiveBackBailConstant.CWQP.getValue());
                    tkztList.add(GiveBackBailConstant.CWSP.getValue());
                    tkztList.add(GiveBackBailConstant.WYTK.getValue());
                    break;
                case 3:
                    tkztList.add(GiveBackBailConstant.JSSP.getValue());
                    tkztList.add(GiveBackBailConstant.CWQP.getValue());
                    tkztList.add(GiveBackBailConstant.CWSP.getValue());
                    tkztList.add(GiveBackBailConstant.WYTK.getValue());
                    break;
                case 4:
                    tkztList.add(GiveBackBailConstant.CWQP.getValue());
                    tkztList.add(GiveBackBailConstant.JSSP.getValue());
                    tkztList.add(GiveBackBailConstant.WYTK.getValue());
                    break;
                case 5:
                    tkztList.add(GiveBackBailConstant.CWQP.getValue());
                    tkztList.add(GiveBackBailConstant.WYTK.getValue());
                    break;
                default:
                    break;
            }
            if(tkztList.size()>0){
                vo.setTkztList(tkztList);
            }
        }
        Page<PassBackVO> selectPageList = passBackDao.selectPageList(vo);
        return selectPageList;
    }

    public ResponseWrapper selectPassBack(GiveBackVO vo) {
        List<GiveBackDO> selectDetails = givebackDao.selectDetails(vo);
        GiveBackDO giveBackDO = selectDetails.get(0);
        //GiveBackDO giveBackDO = givebackDao.selectDetail(vo);
        GiveBackChildVO giveBackChildVO = new GiveBackChildVO();
        if(giveBackDO.getTkfl()==0){
            giveBackChildVO.setCjje(giveBackDO.getJe());
            giveBackChildVO.setCjsl(giveBackDO.getSl().toString());
            giveBackChildVO.setDjje(giveBackDO.getSl().multiply(new BigDecimal("10")).toString());
            giveBackChildVO.setQtje(giveBackDO.getJkje().subtract(giveBackDO.getSl().multiply(new BigDecimal
                    ("10"))).toString());
        }else{
            giveBackChildVO.setCjje("0");
            giveBackChildVO.setCjsl("0");
            giveBackChildVO.setDjje("0");
            giveBackChildVO.setQtje(giveBackDO.getJkje().toString());
        }

        giveBackChildVO.setDwmc(giveBackDO.getDwmc());
        giveBackChildVO.setDwbm(giveBackDO.getDwbm());
        giveBackChildVO.setJkje(giveBackDO.getJkje().toString());
        giveBackChildVO.setSxf(giveBackDO.getSxf());
        return ResponseWrapper.success(giveBackChildVO);
    }

    public ResponseWrapper selectGivePassAll(GiveBackVO vo) {
        List<GiveBackDO> givebackDOList=givebackDao.selectGivePassAll(vo);
        List<GiveBackVO> voList=JsonUtils.parse(
                JsonUtils.serialize(givebackDOList),List.class);
        return ResponseWrapper.success(voList);
    }

    public List<GiveBackVO> selectGiveBackCjList(String gqsj) {
        return givebackDao.selectGiveBackCjList(gqsj);
    }

    public List<GiveBackVO> selectGiveBackByCcbm(String ccbm) {
        return givebackDao.selectGiveBackByCcbm(ccbm);
    }

    public List<GiveBackVO> selectGiveBackCjLists(String ccbm) {
        return givebackDao.selectGiveBackCjLists(ccbm);
    }
}
