package com.unis.transaction.server.domain.signuppay;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.constant.GiveBackBailConstant;
import com.unis.transaction.common.constant.RotatePlanStatusConstant;
import com.unis.transaction.common.utils.EntityUtil;
import com.unis.transaction.common.utils.JsonUtils;
import com.unis.transaction.common.utils.LocalDateUtils;
import com.unis.transaction.common.utils.WorkdayUtils;
import com.unis.transaction.common.vo.backlog.BacklogAddVO;
import com.unis.transaction.common.vo.backlog.BacklogUpdateVO;
import com.unis.transaction.common.vo.backlog.ReceiverCollectionVO;
import com.unis.transaction.common.vo.creditevaluate.TurnoverDataVO;
import com.unis.transaction.common.vo.givebackbail.GiveBackBailLetterVO;
import com.unis.transaction.common.vo.givebackbail.GiveBackVO;
import com.unis.transaction.common.vo.signuppay.SceneVO;
import com.unis.transaction.common.vo.signuppay.TransactionSignUpVO;
import com.unis.transaction.common.vo.tradeplan.EntryAndExitOrderGoodsDO;
import com.unis.transaction.common.vo.tradeplan.EntryAndExitOrderVO;
import com.unis.transaction.common.vo.tradeplan.SiteBacktVO;
import com.unis.transaction.common.vo.tradeplan.SiteVO;
import com.unis.transaction.server.dao.*;
import com.unis.transaction.server.entity.givebackbail.GiveBackDO;
import com.unis.transaction.server.entity.signuppay.TransactionSignUpDO;
import com.unis.transaction.server.entity.tradeplan.EntryAndExitOrderDO;
import com.unis.transaction.server.entity.tradeplan.SiteDO;
import com.unis.transaction.server.entity.tradeplan.TradeMarkDO;
import com.unis.transaction.server.entity.tradeplan.WarehousingArrangementDO;
import com.unis.transaction.server.service.BacklogMQService;
import com.unis.transaction.server.service.impl.BaseRepository;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import tk.mybatis.mapper.entity.Example;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 交易报名业务
 *
 * @author lidiaoquan at 2019-09-20
 */
@Component
@Transactional
public class TransactionSignUpDomain {

    @Autowired
    TransactionSignUpDao transactionsignupDao;

    @Autowired
    GiveBackDao giveBackDao;
    @Autowired
    GiveBackBailLetterDao giveBackBailLetterDao;

    @Autowired
    BaseRepository baseMapper;

    @Autowired
    SiteDao siteMapper;
    @Autowired
    TradeMarkDao tradeMarkDao;
    @Autowired
    TurnoverDataDao turnoverDataDao;
    @Autowired
    private BacklogMQService mqService;
    @Autowired
    EntryAndExitOrderDao entryandexitorderMapper;
    @Autowired
    WarehousingArrangementDao warehousingArrangementDao;

    @Autowired
    private EntryAndExitOrderGoodsDao goodsDao;

    /**
     * 通用的插入处理Calendar.getInstance().get(Calendar.YEAR)
     *
     * @param entity <交易报名>
     */
    private void buildInsertData(TransactionSignUpDO entity) {
        entity.buildInsertData();
        String pk = baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(TransactionSignUpDO.class) , "jybm", "JY", 8);
        entity.setJybm(pk);
    }

    /**
     * 通用的更新处理
     *
     * @param entity
     */
    private void buildUpdateData(TransactionSignUpDO entity) {
        entity.buildUpdateData();
    }

    /**
     * <交易报名>插入全部字段
     *
     * @author lidiaoquan
     */
    public int insertEntity(TransactionSignUpDO entity) {
        buildInsertData(entity);
        return transactionsignupDao.insertSelective(entity);
    }

    /**
     * <交易报名>非null的修改
     * @author lidiaoquan
     */
    public int updateEntity(TransactionSignUpDO entity) {
        buildUpdateData(entity);
        return transactionsignupDao.updateByPrimaryKeySelective(entity);
    }

    //交易报名-新增
    public ResponseWrapper insertTransactionSignUp(TransactionSignUpVO vo) {
        TransactionSignUpDO entity = JsonUtils.parse(JsonUtils.serialize(vo), TransactionSignUpDO.class);
        int num = insertEntity(entity);
        return ResponseWrapper.choose(num);
    }

    //交易报名-修改 注意：updateType非必填项 默认为null 代表业务更新 ，值为1时代表 单表更新
    public ResponseWrapper updateTransactionSignUp(TransactionSignUpVO vo, Integer updateType) {
        TransactionSignUpDO entity = JsonUtils.parse(JsonUtils.serialize(vo), TransactionSignUpDO.class);
        int num = 0;
        String wtfbm = "";
        if (vo.getWtbm() != null) {
            EntryAndExitOrderDO exitOrderDO = entryandexitorderMapper.selectByPrimaryKey(vo.getWtbm());
            wtfbm = exitOrderDO.getWtfbm();
            entity.setWtfbm(exitOrderDO.getWtfbm());
            //添加定时器执行时间
            try {
                Date gqsj = WorkdayUtils.getWorkDate(exitOrderDO.getJyrq());
                entity.setGqsj(gqsj);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        if (entity.getJybm() == null) {
            num = insertEntity(entity);
        } else {
            num = updateEntity(entity);
        }
        TransactionSignUpDO transactionSign = transactionsignupDao.selectByPrimaryKey(entity.getJybm());
        //处理退款业务
        SiteDO siteDO = siteMapper.selectByPrimaryKey(transactionSign.getCcbm());
        GiveBackVO gbVo = new GiveBackVO();
        gbVo.setJybm(entity.getJybm());
        GiveBackDO detail = giveBackDao.selectDetail(gbVo);

        GiveBackDO gbDo = new GiveBackDO();
        gbDo.setApcc(entity.getApcc());
        gbDo.setJybm(entity.getJybm());
        gbDo.setGqsj(transactionSign.getGqsj());
        gbDo.setCcbm(transactionSign.getCcbm());
        //gbDo.setSxf(siteDO.getSxf());
        //gbDo.setJe();
        if (transactionSign.getJkje() != null) {
            gbDo.setJkje(new BigDecimal(transactionSign.getJkje()));
        }
        gbDo.setDwbm(vo.getDwbm());
        gbDo.setDwmc(vo.getDwmc());
        List<TradeMarkDO> list = tradeMarkDao.selectListByCcbm(entity.getCcbm());
        gbDo.setBdsl(list.size());
        if (vo.getJyfx() != null) {
            gbDo.setJyfx(vo.getJyfx());
        }
        gbDo.setSjlx("0");
        gbDo.setWtbm(entity.getWtbm());
        gbDo.setWtfbm(wtfbm);
        if (detail == null) {
            gbDo.buildInsertData();
            String pk = baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(GiveBackDO.class), "tkbm", "TK", 8);
            gbDo.setTkbm(pk);
            giveBackDao.insertSelective(gbDo);
        }
        if (num > 0 && RotatePlanStatusConstant.DSH.getValue().equals(vo.getShzt()) || RotatePlanStatusConstant.FINISH.getValue().equals
                (vo.getShzt()) || RotatePlanStatusConstant.YBH.getValue().equals(vo.getShzt())
                || RotatePlanStatusConstant.WFK.getValue().equals(vo.getShzt())) {
            System.out.println("*************进入创建待办************");
            BacklogAddVO record = new BacklogAddVO();
            record.buildAddVO(record);
            record.setItemQuery(vo.getItemQuery());
            record.setItemQueryHaveDone(vo.getItemQueryHaveDone());
            record.setItemUrlHaveDone(vo.getItemUrlHaveDone());
            //record.setItemId(entity.getJybm());
            if (RotatePlanStatusConstant.DSH.getValue().equals(vo.getShzt())) {
                record.setItemId(entity.getJybm() + "-06");
                record.setItemName(transactionSign.getDwmc() + "的报名数据在报名审核中待审核");
            } else if (RotatePlanStatusConstant.FINISH.getValue().equals(vo.getShzt())) {
                record.setItemId(entity.getJybm() + "-07");
                record.setItemName(transactionSign.getDwmc() + "的报名数据在报名审核中已通过");
            } else if (RotatePlanStatusConstant.WFK.getValue().equals(vo.getShzt())) {
                record.setItemId(entity.getJybm() + "-11");
                record.setItemName(transactionSign.getDwmc() + "的报名数据在财务确认中未付款");
            } else {
                record.setItemId(entity.getJybm() + "-10");
                record.setItemName(transactionSign.getDwmc() + "的报名数据在报名审核中未通过");
            }
            record.setItemStatus(Integer.valueOf(vo.getShzt()));
            record.setItemStatusName(vo.getShztmc());
            record.setItemUrl(vo.getUrl());
            // 另起线程执行待办
            //List<ReceiverCollectionVO> userList =
            new Thread(new Runnable() {
                @Override
                public void run() {
                    for (ReceiverCollectionVO userVO : vo.getUserList()) {
                        System.out.println("********************接收人*******************");
                        System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                        System.out.println("********************************************");
                        record.setReceiver(userVO.getUserName());
                        record.setReceiverId(userVO.getUserId());
                        // 需要将对象序列化成JSONObject
                        mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
                    }
                }
            }).start();
        }
        //客户报名后-已办  业务部报名审核后（客户待付款状态提交）-已办
        if (num > 0 && RotatePlanStatusConstant.FINISH.getValue().equals
                (vo.getShzt()) || RotatePlanStatusConstant.YBH.getValue().equals(vo.getShzt())
                || RotatePlanStatusConstant.YFK.getValue().equals(vo.getShzt())) {
            BacklogUpdateVO updateVO = new BacklogUpdateVO();
            updateVO.buildUpdateVO(updateVO);
            if (RotatePlanStatusConstant.YFK.getValue().equals(vo.getShzt())) {
                updateVO.setItemId(vo.getJybm() + "-07");
                updateVO.setItemName("场次为（" + transactionSign.getApcc() + "）的报名数据在交易中心财务部中已付款");
            } else {
                updateVO.setItemId(vo.getJybm() + "-06");
                updateVO.setItemName("场次为（" + transactionSign.getApcc() + "）的报名数据在交易审核中已审核");
            }
            updateVO.setItemStatus(Integer.valueOf(vo.getShzt()));
            updateVO.setItemStatusName(vo.getShztmc());
            mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(updateVO)), "update");
        }
        //交易中心业务部驳回     交易中心财务部驳回   ---已办
        if (transactionSign != null) {
            if (RotatePlanStatusConstant.DSH.getValue().equals(vo.getShzt())) {
                BacklogUpdateVO updateVO = new BacklogUpdateVO();
                updateVO.buildUpdateVO(updateVO);
                if (RotatePlanStatusConstant.YBH.getValue().equals(transactionSign.getShzt())) {
                    updateVO.setItemId(vo.getJybm() + "-10");
                    updateVO.setItemName("场次为（" + transactionSign.getApcc() + "）的驳回的报名数据在交易报名中再次提交");
                } else {
                    updateVO.setItemId(vo.getJybm() + "-11");
                    updateVO.setItemName("场次为（" + transactionSign.getApcc() + "）的未付款的报名数据在交易报名中再次提交");
                }
                updateVO.setItemStatus(Integer.valueOf(vo.getShzt()));
                updateVO.setItemStatusName(vo.getShztmc());
                mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(updateVO)), "update");
            }
        }

        return ResponseWrapper.choose(num);
    }

    //交易报名-分页列表
    public Page<TransactionSignUpVO> selectTransactionSignUpPageList(int pageNum, int pageSize, TransactionSignUpVO vo) {
        PageHelper.startPage(pageNum, pageSize);
        List<String> shztList = new ArrayList<>();

        if (vo.getBmrqEnd() != null) {
            vo.setBmrqEnd(LocalDateUtils.localDateTime2Date(LocalDateUtils.getEndTime(vo.getBmrqEnd())));
        }
        if (vo.getShsjEnd() != null) {
            vo.setShsjEnd(LocalDateUtils.localDateTime2Date(LocalDateUtils.getEndTime(vo.getShsjEnd())));
        }
        if (vo.getShzt() == null) {
            shztList.add(RotatePlanStatusConstant.FINISH.getValue());
            switch (vo.getPageType()) {
                case 1:
                    shztList.add(RotatePlanStatusConstant.DTJ.getValue());
                    shztList.add(RotatePlanStatusConstant.DSH.getValue());
                    shztList.add(RotatePlanStatusConstant.YGQ.getValue());
                    shztList.add(RotatePlanStatusConstant.YBH.getValue());
                    shztList.add(RotatePlanStatusConstant.YFK.getValue());
                    shztList.add(RotatePlanStatusConstant.WFK.getValue());
                    shztList.add(RotatePlanStatusConstant.YCJ.getValue());
                    shztList.add(RotatePlanStatusConstant.WCJ.getValue());
                    break;
                case 2:
                    shztList.add(RotatePlanStatusConstant.YBH.getValue());
                    shztList.add(RotatePlanStatusConstant.DSH.getValue());
                    shztList.add(RotatePlanStatusConstant.DTJ.getValue());
                    shztList.add(RotatePlanStatusConstant.YBH.getValue());
                    shztList.add(RotatePlanStatusConstant.YFK.getValue());
                    shztList.add(RotatePlanStatusConstant.WFK.getValue());
                    break;
                case 3:
                    shztList.add(RotatePlanStatusConstant.YFK.getValue());
                    shztList.add(RotatePlanStatusConstant.WFK.getValue());
                    break;
                case 5:
                    shztList.add(RotatePlanStatusConstant.YBH.getValue());
                    shztList.add(RotatePlanStatusConstant.WTG.getValue());
                    break;
                default:
                    break;
            }
            if (vo.getPageType() == 5) {
                shztList.remove(RotatePlanStatusConstant.FINISH.getValue());
            }
            vo.setShztList(shztList);
        } else {
            if ("1".equals(vo.getShzt())) {
            } else if (RotatePlanStatusConstant.YGQ.getValue().equals(vo.getShzt())) {
            } else {
                if (vo.getShzt() != null && !"".equals(vo.getShzt())) {
                    shztList.add(vo.getShzt());
                }
            }
            if (vo.getPageType() == 5) {
                shztList.remove(RotatePlanStatusConstant.FINISH.getValue());
            }
            if (shztList.size() > 0) {
                vo.setShztList(shztList);
            }
        }


        Page<TransactionSignUpVO> selectPageList = null;
        if (vo.getPageType() == 1) {
            vo.setDwbm(CurrentUtil.getOrgId());
            selectPageList = transactionsignupDao.selectPageList(vo);
        } else {
            selectPageList = transactionsignupDao.selectPageLists(vo);
        }
        return selectPageList;
    }

    //交易报名-分页列表
    public Page<TransactionSignUpVO> selectTransactionSignPageList(int pageNum, int pageSize, TransactionSignUpVO vo) {
        PageHelper.startPage(pageNum, pageSize);
        List<String> shztList = new ArrayList<>();

        if (vo.getBmrqEnd() != null) {
            vo.setBmrqEnd(LocalDateUtils.localDateTime2Date(LocalDateUtils.getEndTime(vo.getBmrqEnd())));
        }
        if (vo.getShsjEnd() != null) {
            vo.setShsjEnd(LocalDateUtils.localDateTime2Date(LocalDateUtils.getEndTime(vo.getShsjEnd())));
        }
        if (vo.getShzt() == null || "".equals(vo.getShzt())) {
            //shztList.add(RotatePlanStatusConstant.FINISH.getValue());
            switch (vo.getPageType()) {
                case 1:
                /*    shztList.add(RotatePlanStatusConstant.DTJ.getValue());
                    shztList.add(RotatePlanStatusConstant.DSH.getValue());
                    shztList.add(RotatePlanStatusConstant.YGQ.getValue());
                    shztList.add(RotatePlanStatusConstant.YBH.getValue());
                    shztList.add(RotatePlanStatusConstant.YFK.getValue());
                    shztList.add(RotatePlanStatusConstant.WFK.getValue());
                    shztList.add(RotatePlanStatusConstant.YCJ.getValue());
                    shztList.add(RotatePlanStatusConstant.WCJ.getValue());
                    shztList.add(RotatePlanStatusConstant.YTK.getValue());
                    shztList.add(RotatePlanStatusConstant.WYTK.getValue());*/
                    break;
                case 2:
                    shztList.add(RotatePlanStatusConstant.YBH.getValue());
                    shztList.add(RotatePlanStatusConstant.DSH.getValue());
                    shztList.add(RotatePlanStatusConstant.DTJ.getValue());
                    shztList.add(RotatePlanStatusConstant.YBH.getValue());
                    shztList.add(RotatePlanStatusConstant.YFK.getValue());
                    shztList.add(RotatePlanStatusConstant.WFK.getValue());
                    shztList.add(RotatePlanStatusConstant.YCJ.getValue());
                    shztList.add(RotatePlanStatusConstant.WCJ.getValue());
                    shztList.add(RotatePlanStatusConstant.YTK.getValue());
                    shztList.add(RotatePlanStatusConstant.WYTK.getValue());
                    shztList.add(RotatePlanStatusConstant.FINISH.getValue());
                    break;
                case 3:
                    shztList.add(RotatePlanStatusConstant.YCJ.getValue());
                    shztList.add(RotatePlanStatusConstant.WCJ.getValue());
                    shztList.add(RotatePlanStatusConstant.YFK.getValue());
                    shztList.add(RotatePlanStatusConstant.WFK.getValue());
                    shztList.add(RotatePlanStatusConstant.YTK.getValue());
                    shztList.add(RotatePlanStatusConstant.WYTK.getValue());
                    shztList.add(RotatePlanStatusConstant.FINISH.getValue());
                    break;
                default:
                    break;
            }
            if (shztList.size() > 0) {
                vo.setShztList(shztList);
            }
        } else {
            if ("1".equals(vo.getShzt()) || RotatePlanStatusConstant.YGQ.getValue().equals(vo.getShzt())) {
            } else {
                if (vo.getShzt() != null && !"".equals(vo.getShzt())) {
                    shztList.add(vo.getShzt());
                }
            }
            if (shztList.size() > 0) {
                vo.setShztList(shztList);
            }
        }
        Page<TransactionSignUpVO> selectPageList;
        if (vo.getPageType() == 1) {
            vo.setDwbm(CurrentUtil.getOrgId());
            selectPageList = transactionsignupDao.selectTransactionSignPageList(vo);
        } else {
            selectPageList = transactionsignupDao.selectPageLists(vo);
        }
        if (selectPageList.size() > 0) {
            return updatePz(selectPageList);
        }
        return selectPageList;
    }


    //交易报名-列表全部数据
    @SuppressWarnings("unchecked")
    public ResponseWrapper selectTransactionSignUpAll(TransactionSignUpVO vo) {
        List<TransactionSignUpDO> transactionsignupDOList = null;
        //vo.setDwbm(CurrentUtil.getOrgId());
        if (vo.getPageType() == 4) {
            List<String> htList = new ArrayList<>();
            GiveBackBailLetterVO giveBackBailLettervo = new GiveBackBailLetterVO();
            giveBackBailLettervo.setZt(GiveBackBailConstant.ZC.getValue());
            giveBackBailLettervo.setWtfbm(CurrentUtil.getOrgId());
            List<GiveBackBailLetterVO> list = giveBackBailLetterDao.selectHt(giveBackBailLettervo);
            for (GiveBackBailLetterVO giveBackBailLetterDO : list) {
                String[] strings = giveBackBailLetterDO.getHtbm().split(",");
                htList.addAll(Arrays.asList(strings));
            }
            if (htList.size() > 0) {
                vo.setHtList(htList);
            }
            vo.setDwbm(CurrentUtil.getOrgId());
            transactionsignupDOList = transactionsignupDao.selectListNotInGiveBackBail(vo);
        } else if (vo.getPageType() == 6) {
            vo.setShzt(null);
            if (vo.getBdbm() != null) {
                TradeMarkDO tradeMarkDO = tradeMarkDao.selectByPrimaryKey(vo.getBdbm());
                EntryAndExitOrderDO exitOrderDO = entryandexitorderMapper.selectByPrimaryKey(tradeMarkDO.getWtbm());
                if ("1".equals(exitOrderDO.getJyfx())) {
                    transactionsignupDOList = transactionsignupDao.selectLists(vo);
                } else {
                    transactionsignupDOList = new ArrayList<>();
                    TransactionSignUpDO transactionSignUpDO = new TransactionSignUpDO();
                    transactionSignUpDO.setDwbm(exitOrderDO.getWtfbm());
                    transactionSignUpDO.setDwmc(exitOrderDO.getWtfmc());
                    transactionsignupDOList.add(transactionSignUpDO);
                }
            }

        } else {
            vo.setShzt(GiveBackBailConstant.YFS.getValue());
            transactionsignupDOList = transactionsignupDao.selectList(vo);
        }
        List<TransactionSignUpVO> voList = JsonUtils.parse(
                JsonUtils.serialize(transactionsignupDOList), List.class);
        return ResponseWrapper.success(voList);
    }

    public List<TransactionSignUpVO> selectTransactionSignUpAlls(TransactionSignUpVO vo) {
        List<TransactionSignUpDO> transactionsignupDOList = null;
        //vo.setDwbm(CurrentUtil.getOrgId());
        if (vo.getPageType() == 4) {
            List<String> htList = new ArrayList<>();
            GiveBackBailLetterVO giveBackBailLettervo = new GiveBackBailLetterVO();
            giveBackBailLettervo.setZt(GiveBackBailConstant.ZC.getValue());
            giveBackBailLettervo.setWtfbm(CurrentUtil.getOrgId());
            List<GiveBackBailLetterVO> list = giveBackBailLetterDao.selectHt(giveBackBailLettervo);
            for (GiveBackBailLetterVO giveBackBailLetterDO : list) {
                String[] strings = giveBackBailLetterDO.getHtbm().split(",");
                htList.addAll(Arrays.asList(strings));
            }
            if (htList.size() > 0) {
                vo.setHtList(htList);
            }
            vo.setDwbm(CurrentUtil.getOrgId());
            transactionsignupDOList = transactionsignupDao.selectListNotInGiveBackBail(vo);
        } else if (vo.getPageType() == 6) {
            vo.setShzt(null);
            transactionsignupDOList = transactionsignupDao.selectLists(vo);
        } else {
            vo.setShzt(GiveBackBailConstant.YFS.getValue());
            transactionsignupDOList = transactionsignupDao.selectList(vo);
        }
        List<TransactionSignUpVO> voList = JsonUtils.parse(
                JsonUtils.serialize(transactionsignupDOList), List.class);
        return voList;
    }

    //交易报名--查看--返回单条
    public ResponseWrapper selectTransactionSignUpDetail(TransactionSignUpVO vo) {
        SiteBacktVO siteBacktVO = new SiteBacktVO();
        SiteDO siteDO = siteMapper.selectByPrimaryKey(vo.getCcbm());
        SiteVO siteVO = JsonUtils.parse(JsonUtils.serialize(siteDO), SiteVO.class);
        siteBacktVO.setSiteVO(siteVO);
        EntryAndExitOrderDO exitOrderDO = entryandexitorderMapper.selectByPrimaryKey(siteDO.getWtbm());
        EntryAndExitOrderVO exitOrderVO = JsonUtils.parse(JsonUtils.serialize(exitOrderDO), EntryAndExitOrderVO.class);
        Example entryAndExitOrderExample = new Example(WarehousingArrangementDO.class, false, false).selectProperties("wtbm", "pzmc", "lssl");
        Example.Criteria entryAndExitOrderCriteria = entryAndExitOrderExample.createCriteria();
        entryAndExitOrderCriteria.andEqualTo("wtbm", exitOrderVO.getWtbm());
        List<EntryAndExitOrderGoodsDO> entryAndExitOrderList = goodsDao.selectByExample(entryAndExitOrderExample);
        String pzmc = entryAndExitOrderList.stream().map(EntryAndExitOrderGoodsDO::getPzmc).distinct().collect(Collectors.joining("、"));
        exitOrderVO.setPzmc(pzmc);
        siteBacktVO.setEntryAndExitOrderVO(exitOrderVO);

        TransactionSignUpVO signUpVO = new TransactionSignUpVO();
        if (StringUtils.isNotBlank(vo.getJybm())) {
            TransactionSignUpDO selectById = transactionsignupDao.selectByPrimaryKey(vo.getJybm());
            signUpVO = JsonUtils.parse(JsonUtils.serialize(selectById), TransactionSignUpVO.class);
        } else {
            signUpVO = transactionsignupDao.getSignUpBeforeDataCcbm(vo.getCcbm());
            signUpVO.setLspzmc(pzmc);
        }
        BigDecimal sl = entryAndExitOrderList.stream().map(EntryAndExitOrderGoodsDO::getLssl).reduce(BigDecimal.ZERO, BigDecimal::add);
        signUpVO.setSl(sl);
        siteBacktVO.setTransactionSignUpVO(signUpVO);
        return ResponseWrapper.success(siteBacktVO);
    }

    //交易报名--查看--返回单条
    public ResponseWrapper selectSceneList(TransactionSignUpVO vo) {
        List<SceneVO> selectById = transactionsignupDao.selectSceneList(null);
        return ResponseWrapper.success(selectById);
    }

    public List<TransactionSignUpVO> selectTransactionSignUpList() {
        return transactionsignupDao.selectTransactionSignUpList();
    }

    public ResponseWrapper valiTurn(String dwbm) {
        boolean result = false;
        TurnoverDataVO dataVO = new TurnoverDataVO();
        dataVO.setCjdwbm(dwbm);
        dataVO.setZtbm(RotatePlanStatusConstant.WG.getValue());
        List<TurnoverDataVO> turnoverDataVOS = turnoverDataDao.selectZtbmByDwbm(dataVO);
        if (turnoverDataVOS != null && turnoverDataVOS.size() > 0) {
        } else {
            result = true;
        }
        return ResponseWrapper.success(result);
    }

    public Page<TransactionSignUpVO> selectTranPageList(int pageNum, int pageSize, TransactionSignUpVO vo) {
        PageHelper.startPage(pageNum, pageSize);
        vo.setDwbm(CurrentUtil.getOrgId());
        Page<TransactionSignUpVO> selectPageList = transactionsignupDao.selectTranPageList(vo);
        if (selectPageList.size() > 0) {
            return updatePz(selectPageList);
        }
        return selectPageList;
    }

    Page<TransactionSignUpVO> updatePz(Page<TransactionSignUpVO> pageList) {
        List<String> wtbmList = pageList.stream().map(TransactionSignUpVO::getWtbm).collect(Collectors.toList());
        Example entryAndExitOrderExample = new Example(WarehousingArrangementDO.class, false, false).selectProperties("wtbm", "pzmc", "lssl");
        Example.Criteria entryAndExitOrderCriteria = entryAndExitOrderExample.createCriteria();
        entryAndExitOrderCriteria.andIn("wtbm", wtbmList);
        List<EntryAndExitOrderGoodsDO> entryAndExitOrderList = goodsDao.selectByExample(entryAndExitOrderExample);
        Map<String, String> pzmcCollect = entryAndExitOrderList.stream().collect(Collectors.toMap(EntryAndExitOrderGoodsDO::getWtbm, EntryAndExitOrderGoodsDO::getPzmc, (o, n) -> o.contains(n) ? o :  o + "、" + n));
        Map<String, BigDecimal> lsslCollect = entryAndExitOrderList.stream().collect(Collectors.toMap(EntryAndExitOrderGoodsDO::getWtbm, EntryAndExitOrderGoodsDO::getLssl, BigDecimal::add));
        for (TransactionSignUpVO item : pageList) {
            item.setLspzmc(pzmcCollect.get(item.getWtbm()));
            item.setSl(lsslCollect.get(item.getWtbm()));
        }
        return pageList;
    }


    public List<TransactionSignUpVO> selectTransactionSignUp(TransactionSignUpVO vo) {
        List<String> shztList = new ArrayList<String>();
        if (vo.getBmrqEnd() != null) {
            vo.setBmrqEnd(LocalDateUtils.localDateTime2Date(LocalDateUtils.getEndTime(vo.getBmrqEnd())));
        }
        if (vo.getShsjEnd() != null) {
            vo.setShsjEnd(LocalDateUtils.localDateTime2Date(LocalDateUtils.getEndTime(vo.getShsjEnd())));
        }
        if (vo.getShzt() == null || "".equals(vo.getShzt())) {
            switch (vo.getPageType()) {
                case 1:
                    break;
                case 2:
                    shztList.add(RotatePlanStatusConstant.YBH.getValue());
                    shztList.add(RotatePlanStatusConstant.DSH.getValue());
                    shztList.add(RotatePlanStatusConstant.DTJ.getValue());
                    shztList.add(RotatePlanStatusConstant.YBH.getValue());
                    shztList.add(RotatePlanStatusConstant.YFK.getValue());
                    shztList.add(RotatePlanStatusConstant.WFK.getValue());
                    shztList.add(RotatePlanStatusConstant.YCJ.getValue());
                    shztList.add(RotatePlanStatusConstant.WCJ.getValue());
                    shztList.add(RotatePlanStatusConstant.YTK.getValue());
                    shztList.add(RotatePlanStatusConstant.WYTK.getValue());
                    shztList.add(RotatePlanStatusConstant.FINISH.getValue());
                    break;
                case 3:
                    shztList.add(RotatePlanStatusConstant.YCJ.getValue());
                    shztList.add(RotatePlanStatusConstant.WCJ.getValue());
                    shztList.add(RotatePlanStatusConstant.YFK.getValue());
                    shztList.add(RotatePlanStatusConstant.WFK.getValue());
                    shztList.add(RotatePlanStatusConstant.YTK.getValue());
                    shztList.add(RotatePlanStatusConstant.WYTK.getValue());
                    shztList.add(RotatePlanStatusConstant.FINISH.getValue());
                    break;
                default:
                    break;
            }
            if (shztList.size() > 0) {
                vo.setShztList(shztList);
            }
        } else {
            if ("1".equals(vo.getShzt()) || RotatePlanStatusConstant.YGQ.getValue().equals(vo.getShzt())) {
            } else {
                if (vo.getShzt() != null && !"".equals(vo.getShzt())) {
                    shztList.add(vo.getShzt());
                }
            }
            if (shztList.size() > 0) {
                vo.setShztList(shztList);
            }
        }
        List<TransactionSignUpVO> selectPageList = null;
        if (vo.getPageType() == 1) {
            vo.setDwbm(CurrentUtil.getOrgId());
            selectPageList = transactionsignupDao.selectTransactionSignPageList(vo);
        } else {
            selectPageList = transactionsignupDao.selectPageLists(vo);
        }
        if (selectPageList.size() > 0) {
            Page<TransactionSignUpVO> objects = new Page<>();
            objects.addAll(selectPageList);
            return updatePz(objects);
        }
        return selectPageList;
    }

    public List<TransactionSignUpDO> listSignUpByCcbm(TransactionSignUpVO vo) {
        Example signUpExample = new Example(TransactionSignUpDO.class, false, false).selectProperties("jybm", "wtbm", "dwbm", "dwmc", "lxr", "lxdh");
        Example.Criteria signUpCriteria = signUpExample.createCriteria();
        String ccbm = vo.getCcbm();
        if (StringUtils.isBlank(ccbm)) {
            return new ArrayList<>();
        }
        signUpCriteria.andEqualTo("ccbm", ccbm)
                .andIn("shzt", Arrays.asList("91000003", "91000060"));
        List<TransactionSignUpDO> transactionSignUpList = transactionsignupDao.selectByExample(signUpExample);
        return transactionSignUpList;
    }
}
