package com.unis.transaction.server.domain.tradeplan;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.constant.RefundNoticeConstant;
import com.unis.transaction.common.dto.base.PageResult;
import com.unis.transaction.common.vo.tradeplan.RefundLetterVO;
import com.unis.transaction.common.vo.tradeplan.RefundNoticeContractVO;
import com.unis.transaction.common.vo.tradeplan.RefundNoticeQueryVO;
import com.unis.transaction.common.vo.tradeplan.RefundNoticeVO;
import com.unis.transaction.server.dao.RefundLetterDao;
import com.unis.transaction.server.dao.RefundNoticeDao;
import com.unis.transaction.server.entity.tradeplan.RefundLetterDO;
import com.unis.transaction.server.entity.tradeplan.RefundNoticeDO;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import java.util.Date;
import java.util.List;
import java.util.UUID;

@Component
public class RefundNoticeDomain {

    @Autowired
    private RefundNoticeDao refundNoticeDao;

    @Autowired
    private RefundLetterDao refundLetterDao;

    public Integer save(RefundNoticeVO vo) {
        RefundNoticeDO refundNoticeDO = JSONObject.parseObject(JSONObject.toJSONString(vo), RefundNoticeDO.class);
        if(refundNoticeDO != null){

            refundNoticeDO.setId(UUID.randomUUID().toString().toLowerCase().replace("-",""));
            refundNoticeDO.setZt(RefundNoticeConstant.DSC.getValue());
            refundNoticeDO.setZtName(RefundNoticeConstant.DSC.getName());
            refundNoticeDO.buildInsertData();

            RefundNoticeVO originNoticeVO = refundNoticeDao.selectByHtbm(refundNoticeDO.getHtbm());
            if(originNoticeVO != null && StringUtils.isNotEmpty(originNoticeVO.getId())){
                RefundNoticeDO originNoticeDO = JSONObject.parseObject(JSONObject.toJSONString(originNoticeVO), RefundNoticeDO.class);
                originNoticeDO.setStatus(0);
                refundNoticeDao.updateByPrimaryKey(originNoticeDO);
            }
            return refundNoticeDao.insert(refundNoticeDO);
        }
        return null;
    }

    public ResponseWrapper update(Integer type, RefundNoticeVO vo) {
        RefundNoticeDO refundNoticeDO = refundNoticeDao.selectByPrimaryKey(vo.getId());

        if(refundNoticeDO != null){
            int res = 0;
            //修改生成前数据
            if(type == 1 && (refundNoticeDO.getZt().equals(RefundNoticeConstant.DSC.getValue())
                || refundNoticeDO.getZt().equals(RefundNoticeConstant.GZBH.getValue()))
                || refundNoticeDO.getZt().equals(RefundNoticeConstant.YBH.getValue())){
                refundNoticeDO.setLysl(vo.getLysl());
                if(vo.getWysl() != null){
                    refundNoticeDO.setWysl(vo.getWysl());
                }
                refundNoticeDO.buildUpdateData();
                if(StringUtils.isNotEmpty(vo.getTzzw())){
                    refundNoticeDO.setTzzw(vo.getTzzw());
                }
                res = refundNoticeDao.updateByPrimaryKeySelective(refundNoticeDO);
            }
            //生成
            if(type == 2 && (refundNoticeDO.getZt().equals(RefundNoticeConstant.DSC.getValue())
                    || refundNoticeDO.getZt().equals(RefundNoticeConstant.GZBH.getValue()))
                    || refundNoticeDO.getZt().equals(RefundNoticeConstant.YBH.getValue())){

                refundNoticeDO.setZt(RefundNoticeConstant.DGZ.getValue());
                refundNoticeDO.setZtName(RefundNoticeConstant.DGZ.getName());
                if(vo.getLysl() != null){
                    refundNoticeDO.setLysl(vo.getLysl());
                }
                if(vo.getWysl() != null){
                    refundNoticeDO.setWysl(vo.getWysl());
                }
                if(StringUtils.isNotEmpty(vo.getTzzw())){
                    refundNoticeDO.setTzzw(vo.getTzzw());
                }
                res = refundNoticeDao.updateByPrimaryKeySelective(refundNoticeDO);
                refundNoticeDao.updateHtRefundStatusByHtbm(refundNoticeDO.getHtbm(),1);
            }
            //盖章
            if(type == 3 && (refundNoticeDO.getZt().equals(RefundNoticeConstant.DGZ.getValue())
                    || refundNoticeDO.getZt().equals(RefundNoticeConstant.YBH.getValue())) ){

                refundNoticeDO.setGz(vo.getGz());
                refundNoticeDO.setGzr(CurrentUtil.getUserName());
                refundNoticeDO.setGzrbh(CurrentUtil.getUserId());
                refundNoticeDO.setGzrq(new Date());
                refundNoticeDO.setZt(RefundNoticeConstant.DJS.getValue());
                refundNoticeDO.setZtName(RefundNoticeConstant.DJS.getName());
                res = refundNoticeDao.updateByPrimaryKeySelective(refundNoticeDO);

            }
            //管理端接收or不接收
            if(type == 4 && refundNoticeDO.getZt().equals(RefundNoticeConstant.DJS.getValue())){
                //是否接收
                if(vo.getSfjs() == 1){
                    refundNoticeDO.setZt(RefundNoticeConstant.YJS.getValue());
                    refundNoticeDO.setZtName(RefundNoticeConstant.YJS.getName());
                }else if(vo.getSfjs() == 0){
                    refundNoticeDO.setZt(RefundNoticeConstant.YBH.getValue());
                    refundNoticeDO.setZtName(RefundNoticeConstant.YBH.getName());
                }else{
                    ResponseWrapper.error("参数错误，请确认后重试！");
                }
                refundNoticeDO.setSfjs(vo.getSfjs());
                refundNoticeDO.setJsyj(vo.getJsyj());
                refundNoticeDO.setJsr(CurrentUtil.getUserName());
                refundNoticeDO.setJsrbh(CurrentUtil.getUserId());
                refundNoticeDO.setJsrq(vo.getJsrq());
                res = refundNoticeDao.updateByPrimaryKeySelective(refundNoticeDO);
            }

            //盖章驳回
            if(type == 5 && (refundNoticeDO.getZt().equals(RefundNoticeConstant.DGZ.getValue())
                    || refundNoticeDO.getZt().equals(RefundNoticeConstant.YBH.getValue()) )) {

                refundNoticeDO.setZt(RefundNoticeConstant.GZBH.getValue());
                refundNoticeDO.setZtName(RefundNoticeConstant.GZBH.getName());
                res = refundNoticeDao.updateByPrimaryKeySelective(refundNoticeDO);

            }

            if(res > 0){
                return ResponseWrapper.success();
            }else{
                return ResponseWrapper.error("参数错误，请确认后重试！");
            }
        }
        return ResponseWrapper.error("没有该保证金（退还）通知，请确认后重试！");
    }

    public PageResult<RefundNoticeVO> getPage(Integer pageNum, Integer pageSize, RefundNoticeQueryVO queryVO) {
        queryVO.setOrgCode(CurrentUtil.getOrgId());
        PageHelper.startPage(pageNum,pageSize);
        List<RefundNoticeVO> list = refundNoticeDao.selectList(queryVO);
        Page<RefundNoticeVO> page = (Page<RefundNoticeVO>) list;
        if(list != null && list.size() > 0){
            for(RefundNoticeVO vo : list){
                RefundLetterVO refundLetterVO = refundLetterDao.selectByHtbm(vo.getHtbm());
                if(refundLetterVO != null){
                    vo.setRefundLetterVO(refundLetterVO);
                }
            }
        }
        return new PageResult<>(page.getTotal(), page.getPages(), pageNum, list);
    }

    public PageResult<RefundNoticeContractVO> getContractPage(Integer pageNum, Integer pageSize, RefundNoticeQueryVO queryVO) {
        queryVO.setOrgCode(CurrentUtil.getOrgId());
        PageHelper.startPage(pageNum,pageSize);
        List<RefundNoticeContractVO> list = refundNoticeDao.selectContractList(queryVO);
        Page<RefundNoticeContractVO> page = (Page<RefundNoticeContractVO>) list;
        return new PageResult<>(page.getTotal(), page.getPages(), pageNum, list);
    }

    public Integer saveLetter(RefundLetterVO vo) {

        RefundLetterDO refundLetterDO = JSONObject.parseObject(JSONObject.toJSONString(vo), RefundLetterDO.class);
        if(refundLetterDO != null ){
            refundLetterDO.setId(UUID.randomUUID().toString().toLowerCase().replace("-",""));
            refundLetterDO.setZt(RefundNoticeConstant.DSC.getValue());
            refundLetterDO.setZtName(RefundNoticeConstant.DSC.getName());
            refundLetterDO.buildInsertData();
            RefundLetterVO originLetterVO = refundLetterDao.selectByHtbm(refundLetterDO.getHtbm());
            if(originLetterVO != null && StringUtils.isNotEmpty(originLetterVO.getId())){
                RefundLetterDO originLetterDO = JSONObject.parseObject(JSONObject.toJSONString(originLetterVO), RefundLetterDO.class);
                originLetterDO.setStatus(0);
                refundLetterDao.updateByPrimaryKey(originLetterDO);
            }
            return refundLetterDao.insert(refundLetterDO);
        }
        return null;
    }

    public ResponseWrapper updateLetter(Integer type, RefundLetterVO vo) {

        RefundLetterDO refundLetterDO = refundLetterDao.selectByPrimaryKey(vo.getId());

        if(refundLetterDO != null){
            int res = 0;
            //修改生成前数据
            if(type == 1 && (refundLetterDO.getZt().equals(RefundNoticeConstant.DSC.getValue())
                    || refundLetterDO.getZt().equals(RefundNoticeConstant.GZBH.getValue()))
                    || refundLetterDO.getZt().equals(RefundNoticeConstant.YBH.getValue())){
                if(StringUtils.isNotEmpty(vo.getTzzw())){
                    refundLetterDO.setTzzw(vo.getTzzw());
                }
                refundLetterDO.buildUpdateData();
                res = refundLetterDao.updateByPrimaryKeySelective(refundLetterDO);
            }
            //生成
            if(type == 2 && (refundLetterDO.getZt().equals(RefundNoticeConstant.DSC.getValue())
                    || refundLetterDO.getZt().equals(RefundNoticeConstant.GZBH.getValue()))
                    || refundLetterDO.getZt().equals(RefundNoticeConstant.YBH.getValue())){

                if(StringUtils.isNotEmpty(vo.getTzzw())){
                    refundLetterDO.setTzzw(vo.getTzzw());
                }
                refundLetterDO.setZt(RefundNoticeConstant.DGZ.getValue());
                refundLetterDO.setZtName(RefundNoticeConstant.DGZ.getName());
                res = refundLetterDao.updateByPrimaryKeySelective(refundLetterDO);
            }
            //盖章
            if(type == 3 && (refundLetterDO.getZt().equals(RefundNoticeConstant.DGZ.getValue())
                    ||refundLetterDO.getZt().equals(RefundNoticeConstant.YBH.getValue()))) {

                refundLetterDO.setGz(vo.getGz());
                refundLetterDO.setGzr(CurrentUtil.getUserName());
                refundLetterDO.setGzrbh(CurrentUtil.getUserId());
                refundLetterDO.setGzrq(new Date());
                refundLetterDO.setZt(RefundNoticeConstant.DJS.getValue());
                refundLetterDO.setZtName(RefundNoticeConstant.DJS.getName());
                res = refundLetterDao.updateByPrimaryKeySelective(refundLetterDO);

            }
            //管理端接收or不接收
            if(type == 4 && refundLetterDO.getZt().equals(RefundNoticeConstant.DJS.getValue())){
                //是否接收
                if(vo.getSfjs() == 1){
                    refundLetterDO.setZt(RefundNoticeConstant.YJS.getValue());
                    refundLetterDO.setZtName(RefundNoticeConstant.YJS.getName());
                }else if(vo.getSfjs() == 0){
                    refundLetterDO.setZt(RefundNoticeConstant.YBH.getValue());
                    refundLetterDO.setZtName(RefundNoticeConstant.YBH.getName());
                }
                refundLetterDO.setSfjs(vo.getSfjs());
                refundLetterDO.setJsyj(vo.getJsyj());
                refundLetterDO.setJsr(CurrentUtil.getUserName());
                refundLetterDO.setJsrbh(CurrentUtil.getUserId());
                refundLetterDO.setJsrq(vo.getJsrq());
                res = refundLetterDao.updateByPrimaryKeySelective(refundLetterDO);
            }
            //盖章驳回
            if(type == 5 && ( refundLetterDO.getZt().equals(RefundNoticeConstant.DGZ.getValue()) || refundLetterDO.getZt().equals(RefundNoticeConstant.YBH.getValue()))){

                refundLetterDO.setZt(RefundNoticeConstant.GZBH.getValue());
                refundLetterDO.setZtName(RefundNoticeConstant.GZBH.getName());
                res = refundLetterDao.updateByPrimaryKeySelective(refundLetterDO);

            }

            if(res > 0){
                return ResponseWrapper.success();
            }else{
                return ResponseWrapper.error("参数错误，请确认后重试！");
            }
        }
        return ResponseWrapper.error("没有该保证金（退还）通知，请确认后重试！");
    }

    public RefundNoticeVO getInfoByHtbm(String htbm) {

        RefundNoticeVO vo = refundNoticeDao.selectByHtbm(htbm);
        if(vo != null){
            RefundLetterVO refundLetterVO = refundLetterDao.selectByHtbm(htbm);
            if(refundLetterVO != null){
                vo.setRefundLetterVO(refundLetterVO);
            }
        }
        return vo;
    }
}
