package com.unis.transaction.server.domain.tradeplan;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.utils.EntityUtil;
import com.unis.transaction.common.utils.JsonUtils;
import com.unis.transaction.common.vo.tradeplan.TradeRuleVO;
import com.unis.transaction.server.dao.TradeRuleDao;
import com.unis.transaction.server.entity.tradeplan.TradeRuleDO;
import com.unis.transaction.server.service.impl.BaseRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 交易细则业务
 * @author lidiaoquan at 2019-09-19
 */
@Component
public class TradeRuleDomain{

    @Autowired
    TradeRuleDao traderuleDao;
    
    @Autowired
    BaseRepository baseMapper;
        
	/**
   	  * 通用的插入处理
     * @param entity <交易细则>
     */
    private void buildInsertData(TradeRuleDO entity){
        entity.buildInsertData();
        String pk= baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(TradeRuleDO.class)
        ,"xzbm", "XZ", 8);
        entity.setXzbm(pk);
    }
    
   /**
       * 通用的更新处理
    * @param entity
    */
    private void buildUpdateData(TradeRuleDO entity){
        entity.buildUpdateData();
    }
    
    /**
     * <交易细则>插入全部字段
     * @author lidiaoquan
     */
    public int insertEntity(TradeRuleDO entity) {
        buildInsertData(entity);
        return traderuleDao.insertSelective(entity);
    }
    
    /**
     * <交易细则>非null的修改
     * @author lidiaoquan
     */
    public int updateEntity(TradeRuleDO entity) {
        buildUpdateData(entity);
        return traderuleDao.updateByPrimaryKeySelective(entity);
    }
    
	//交易细则-新增
    public ResponseWrapper insertTradeRule(TradeRuleVO vo){
        TradeRuleDO entity=JsonUtils.parse(
            JsonUtils.serialize(vo),TradeRuleDO.class);
        int num= insertEntity(entity);
        return ResponseWrapper.choose(num);		 
    }

	//交易细则-修改 注意：updateType非必填项 默认为null 代表业务更新 ，值为1时代表 单表更新
    public ResponseWrapper updateTradeRule(TradeRuleVO vo,java.lang.Integer updateType){
        TradeRuleDO entity=JsonUtils.parse(
            JsonUtils.serialize(vo),TradeRuleDO.class);
   		int num = updateEntity(entity);
        return ResponseWrapper.choose(num);
	}
	
	//交易细则-分页列表
    public Page<TradeRuleVO> selectTradeRulePageList(int pageNum, int pageSize, TradeRuleVO vo){
 		PageHelper.startPage(pageNum,pageSize);
  		Page<TradeRuleVO> selectPageList = traderuleDao.selectPageList(vo);
        return selectPageList;		
    }

	//交易细则-列表全部数据
	@SuppressWarnings("unchecked")
    public ResponseWrapper selectTradeRuleAll(TradeRuleVO vo){
		List<TradeRuleDO> traderuleDOList=traderuleDao.selectList(vo);
        List<TradeRuleVO> voList=JsonUtils.parse(
            JsonUtils.serialize(traderuleDOList),List.class);
        return ResponseWrapper.success(voList);
    }

	//交易细则--查看--返回单条
    public ResponseWrapper selectTradeRuleDetail(TradeRuleVO vo){
		TradeRuleVO selectById = traderuleDao.selectDetail(vo);
        return ResponseWrapper.success(selectById);   
    }

}
