package com.unis.transaction.server.service;

import com.unis.common.utils.DateUtil;
import com.unis.transaction.common.constant.GiveBackBailConstant;
import com.unis.transaction.common.constant.RotatePlanStatusConstant;
import com.unis.transaction.common.vo.givebackbail.GiveBackVO;
import com.unis.transaction.common.vo.tradeplan.ContractVO;
import com.unis.transaction.common.vo.tradeplan.EntryAndExitOrderVO;
import com.unis.transaction.server.dao.TradeMarkDao;
import com.unis.transaction.server.dao.TransactionSignUpDao;
import com.unis.transaction.server.entity.signuppay.TransactionSignUpDO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;


/**
 * 合同对接国家交易平台定时器
 */
@Component
@Slf4j
@Lazy(false)
public class ContractTimer {

	@Autowired
	private TradeMarkDao tradeMarkDao;
	@Autowired
	private TradeMarkService tradeMarkService;
	@Autowired
	private GiveBackService giveBackService;
	@Autowired
	private TransactionSignUpDao transactionSignUpDao;

	@Autowired
	private EntryAndExitOrderService entryAndExitOrderService;

	@Scheduled(cron = "0 0 1 * * ?")//每天晚上1点执行一次
	public  void dowork(){
		String sign= DateUtil.getCurrentStringDate();
		log.info("------报名状态轮询开始",sign);
		try {
			execute(sign);
		} catch (Exception e) {
			e.printStackTrace();
		}
		log.info("---报名状态轮询结束",sign);

	}

	public void execute(String sign) throws Exception{
		log.info("===================================定时修改状态轮询开始======================================================================");
		List<GiveBackVO> list = giveBackService.selectGiveBackList();
		DateFormat df = new SimpleDateFormat("yyyy-MM-dd hh:mm");
		for(GiveBackVO giveBackVO:list){
			EntryAndExitOrderVO exitOrderDO = entryAndExitOrderService.getEntryAndExitOrderDetail(giveBackVO.getWtbm());
			TransactionSignUpDO transactionSignUpDO = transactionSignUpDao.selectByPrimaryKey(giveBackVO.getJybm());
			Date dt1 = df.parse(df.format(exitOrderDO.getJyrq()));
			Date dt2 = df.parse(df.format(new Date()));
			if(dt1.getTime() < dt2.getTime()){
				//判断合同中是否存在该记录
				List<ContractVO> contractVOList = tradeMarkDao.selectContractList(transactionSignUpDO.getCcbm(),
						transactionSignUpDO.getDwbm());
				if(contractVOList!=null&&contractVOList.size()>0){
					giveBackVO.setTkzt(GiveBackBailConstant.SBKTK.getValue());
					giveBackVO.setTkztmc(GiveBackBailConstant.SBKTK.getName());
					giveBackVO.setTkfl(0);
					transactionSignUpDO.setShztmc(RotatePlanStatusConstant.YCJ.getName());
					transactionSignUpDO.setShzt(RotatePlanStatusConstant.YCJ.getValue());
				}else{
					transactionSignUpDO.setShztmc(RotatePlanStatusConstant.WCJ.getName());
					transactionSignUpDO.setShzt(RotatePlanStatusConstant.WCJ.getValue());
				}
				giveBackService.updateGiveEntity(giveBackVO);
				transactionSignUpDao.updateByPrimaryKeySelective(transactionSignUpDO);

			}
		}
		log.info("===================================定时修改状态轮询结束======================================================================");
	}
}
