package com.unis.transaction.server.service;

import com.unis.common.utils.DateUtil;
import com.unis.transaction.common.constant.GiveBackBailConstant;
import com.unis.transaction.common.constant.RotatePlanStatusConstant;
import com.unis.transaction.common.utils.EntityUtil;
import com.unis.transaction.common.vo.givebackbail.GiveBackVO;
import com.unis.transaction.common.vo.givebackbail.PassBackVO;
import com.unis.transaction.common.vo.tradeplan.ContractVO;
import com.unis.transaction.common.vo.tradeplan.EntryAndExitOrderVO;
import com.unis.transaction.common.vo.tradeplan.SiteVO;
import com.unis.transaction.server.dao.PassBackDao;
import com.unis.transaction.server.dao.SiteDao;
import com.unis.transaction.server.dao.TradeMarkDao;
import com.unis.transaction.server.dao.TransactionSignUpDao;
import com.unis.transaction.server.entity.creditevaluate.TurnoverEndDO;
import com.unis.transaction.server.entity.givebackbail.PassBackDO;
import com.unis.transaction.server.entity.signuppay.TransactionSignUpDO;
import com.unis.transaction.server.entity.tradeplan.SiteDO;
import com.unis.transaction.server.entity.tradeplan.TradeMarkDO;
import com.unis.transaction.server.service.impl.BaseRepository;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 对报名数据进行成交和未成交操作
 */
@Component
@Slf4j
@Lazy(false)
public class SignUpTimer {

	@Autowired
	private TransactionSignUpDao transactionSignUpDao;
	@Autowired
	private TradeMarkDao tradeMarkDao;
	@Autowired
	private PassBackDao passBackDao;
	@Autowired
	private SiteDao siteDao;
	@Autowired
	BaseRepository baseMapper;
	@Autowired
	TurnoverEndService turnoverEndService;
	@Autowired
	private TradeMarkService tradeMarkService;
	@Autowired
	private GiveBackService giveBackService;

	@Autowired
	private EntryAndExitOrderService entryAndExitOrderService;

	@Scheduled(cron = "0 30 0 * * ?")//每天晚上12点05执行
	//@Scheduled(cron = "0 58 16 * * ?")
	public  void dowork(){
		String sign= DateUtil.getCurrentStringDate();
		log.info("------未成交状态轮询开始",sign);
		try {
			execute(sign);
		} catch (Exception e) {
			e.printStackTrace();
		}
		log.info("---未成交状态轮询结束",sign);

	}

	public void execute(String sign) throws Exception{
		log.info("===================================定时修改未成交状态轮询开始======================================================================");
		List<GiveBackVO> list = giveBackService.selectGiveBackList();
		DateFormat df = new SimpleDateFormat("yyyy-MM-dd");
        for (GiveBackVO giveBackVO : list) {
            EntryAndExitOrderVO exitOrderDO = entryAndExitOrderService.getEntryAndExitOrderDetail(giveBackVO.getWtbm());
            TransactionSignUpDO transactionSignUpDO = transactionSignUpDao.selectByPrimaryKey(giveBackVO.getJybm());
            String dt1 = df.format(transactionSignUpDO.getGqsj());
            String dt2 = df.format(new Date());
            if (dt1.equals(dt2)) {
                //判断合同中是否存在该记录
                List<ContractVO> contractVOList = tradeMarkDao.selectContractList(transactionSignUpDO.getCcbm(), transactionSignUpDO.getDwbm());
                if (contractVOList != null && contractVOList.size() > 0) {
                    transactionSignUpDO.setShztmc(RotatePlanStatusConstant.YCJ.getName());
                    transactionSignUpDO.setShzt(RotatePlanStatusConstant.YCJ.getValue());
                } else {
                    giveBackVO.setTkzt(GiveBackBailConstant.JYJB.getValue());
                    giveBackVO.setTkztmc(GiveBackBailConstant.JYJB.getName());
                    giveBackVO.setTkfl(1);
                    transactionSignUpDO.setShztmc(RotatePlanStatusConstant.WCJ.getName());
                    transactionSignUpDO.setShzt(RotatePlanStatusConstant.WCJ.getValue());
                    giveBackService.updateGiveEntity(giveBackVO);
                    transactionSignUpDao.updateByPrimaryKeySelective(transactionSignUpDO);
                    PassBackVO PassBackVO = new PassBackVO();
                    PassBackVO.setCcbm(transactionSignUpDO.getCcbm());
                    PassBackDO pass = passBackDao.selectDetail(PassBackVO);
                    if (pass != null) {

					} else {
						SiteDO vo = siteDao.selectByPrimaryKey(transactionSignUpDO.getCcbm());
						PassBackDO passBackDO = new PassBackDO();
						passBackDO.setApcc(vo.getApcc());
						List<TradeMarkDO> lists = tradeMarkDao.selectListByCcbm(vo.getCcbm());
						passBackDO.setBdsl(lists.size());
						passBackDO.setCcbm(vo.getCcbm());
						passBackDO.setJylx(giveBackVO.getJylx());
						passBackDO.setPzmc(exitOrderDO.getPzmc());
						passBackDO.setJyrq(vo.getJyrq());
						passBackDO.setJybzj(vo.getJybzj());
						passBackDO.setLybzj(vo.getLybzj());
						passBackDO.setSl(new BigDecimal(vo.getSl()));
						passBackDO.setTkbm(giveBackVO.getTkbm());
						passBackDO.setTksj(new Date());
						passBackDO.setTkzt(GiveBackBailConstant.JYJB.getValue());
						passBackDO.setTkztmc(GiveBackBailConstant.JYJB.getName());
						passBackDO.setWtbm(transactionSignUpDO.getWtbm());
						passBackDO.setWtfbm(transactionSignUpDO.getWtfbm());
						passBackDao.insertSelective(passBackDO);
					}
				}
			/*	TurnoverEndDO is = turnoverEndService.selectTurnoverEndByCcbm(transactionSignUpDO.getCcbm());
				if(is!=null){
				}else{
					TurnoverEndDO turnoverEndDO = new TurnoverEndDO();
					String pk= baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(TurnoverEndDO.class)
							,"jgbm", "JG", 8);
					turnoverEndDO.setJgbm(pk);
					SiteDO siteDO = siteDao.selectByPrimaryKey(transactionSignUpDO.getCcbm());
					turnoverEndDO.setApcc(transactionSignUpDO.getApcc());
					turnoverEndDO.setCcbm(transactionSignUpDO.getCcbm());
					turnoverEndDO.setWtfmc(exitOrderDO.getWtfmc());
					turnoverEndDO.setJylx(exitOrderDO.getJylx());
					turnoverEndDO.setJylxmc(exitOrderDO.getJylxmc());
					turnoverEndDO.setJyxz(Integer.valueOf(siteDO.getJyxz()));
					turnoverEndDO.setJyrq(exitOrderDO.getJyrq());
					turnoverEndDO.setJgrq(exitOrderDO.getJgrq());
					turnoverEndDO.setPzmc(exitOrderDO.getPzmc());
					turnoverEndDO.setPzbm(exitOrderDO.getPzbm());
					turnoverEndDO.setLsxzbm(exitOrderDO.getLsxzbm());
					turnoverEndDO.setLsxzmc(exitOrderDO.getLsxzmc());
					turnoverEndDO.setFbzt("0");
					turnoverEndDO.setFbztmc("待发布");
					//底价  每个标的的起报价 取最低的
					Float dj = tradeMarkService.getDj(siteDO.getCcbm());
					turnoverEndDO.setDj(String.valueOf(dj));
					//交易数量
					turnoverEndDO.setJysl(siteDO.getSl());
					//成交数量  所有合同的成交数量
					List<TradeMarkDO> tradeMarkDOS = tradeMarkDao.selectListByCcbm(siteDO.getCcbm());
					List<String> bdjh = new ArrayList<>();
					for(TradeMarkDO tradeMarkDO:tradeMarkDOS){
						bdjh.add(tradeMarkDO.getBdbm());
					}
					//最低和最高成交价 合同里面的价格
					SiteVO siteVO = new SiteVO();
					siteVO.setHtList(bdjh);
					String cjsl = tradeMarkDao.getCjsl(siteVO);
					turnoverEndDO.setCjsl(cjsl);
					String zdcjj = tradeMarkDao.getZdcjj(siteVO);
					turnoverEndDO.setZdcjj(zdcjj);
					String zgcjj = tradeMarkDao.getZgcjj(siteVO);
					turnoverEndDO.setZgcjj(zgcjj);
					String cjje = tradeMarkDao.getCjje(siteVO);
					turnoverEndDO.setJj(new BigDecimal(cjje).divide(new BigDecimal(cjsl)).toString());
					turnoverEndDO.setSxfl(siteDO.getSxfl());
					turnoverEndDO.setSxflx(siteDO.getSxfType());
					int num = turnoverEndService.insert(turnoverEndDO);
				}*/
			}
		}
		//添加交易结果
		//判断交易结果中是否存在
		List<GiveBackVO> cjList = giveBackService.selectGiveBackCjList(DateUtil.DateToStr(new Date(),"yyyy-MM-dd"));
		for(GiveBackVO giveBackVO:cjList){
			EntryAndExitOrderVO exitOrderDO = entryAndExitOrderService.getEntryAndExitOrderDetail(giveBackVO.getWtbm());
			TransactionSignUpDO transactionSignUp = transactionSignUpDao.selectByPrimaryKey(giveBackVO.getJybm());
				TurnoverEndDO is = turnoverEndService.selectTurnoverEndByCcbm(transactionSignUp.getCcbm());
				if(is!=null){
				}else{
					TurnoverEndDO turnoverEndDO = new TurnoverEndDO();
					String pk= baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(TurnoverEndDO.class)
							,"jgbm", "JG", 8);
					turnoverEndDO.setJgbm(pk);
					SiteDO siteDO = siteDao.selectByPrimaryKey(transactionSignUp.getCcbm());
					turnoverEndDO.setApcc(transactionSignUp.getApcc());
					turnoverEndDO.setCcbm(transactionSignUp.getCcbm());
					turnoverEndDO.setWtfmc(exitOrderDO.getWtfmc());
					turnoverEndDO.setJylx(exitOrderDO.getJyfs());
					turnoverEndDO.setJylxmc(exitOrderDO.getJyfsmc());
					turnoverEndDO.setJyxz(Integer.valueOf(siteDO.getJyxz()));
					turnoverEndDO.setJyrq(exitOrderDO.getJyrq());
					turnoverEndDO.setJgrq(exitOrderDO.getJgrq());
					turnoverEndDO.setPzmc(exitOrderDO.getPzmc());
					turnoverEndDO.setPzbm(exitOrderDO.getPzbm());
					turnoverEndDO.setLsxzbm(exitOrderDO.getLsxzbm());
					turnoverEndDO.setLsxzmc(exitOrderDO.getLsxzmc());
					turnoverEndDO.setFbzt("0");
					turnoverEndDO.setFbztmc("待发布");
					//底价  每个标的的起报价 取最低的
					Double dj = tradeMarkService.getDj(siteDO.getCcbm());
					turnoverEndDO.setDj(String.valueOf(dj));
					//交易数量
					turnoverEndDO.setJysl(siteDO.getSl());
					//成交数量  所有合同的成交数量
					List<TradeMarkDO> tradeMarkDOS = tradeMarkDao.selectListByCcbm(siteDO.getCcbm());
					List<String> bdjh = new ArrayList<>();
					for(TradeMarkDO tradeMarkDO:tradeMarkDOS){
						bdjh.add(tradeMarkDO.getBdbm());
					}
					//最低和最高成交价 合同里面的价格
					SiteVO siteVO = new SiteVO();
					siteVO.setHtList(bdjh);
					String cjsl = tradeMarkDao.getCjsl(siteVO);
					turnoverEndDO.setCjsl(cjsl);
					String zdcjj = tradeMarkDao.getZdcjj(siteVO);
					turnoverEndDO.setZdcjj(zdcjj);
					String zgcjj = tradeMarkDao.getZgcjj(siteVO);
					turnoverEndDO.setZgcjj(zgcjj);
					String cjje = tradeMarkDao.getCjje(siteVO);
					turnoverEndDO.setJj(new BigDecimal(cjje).divide(new BigDecimal(cjsl),2, RoundingMode.HALF_UP).toString());
					turnoverEndDO.setSxfl(siteDO.getSxfl());
					turnoverEndDO.setSxflx(siteDO.getSxfType());
					turnoverEndDO.setCjl(new BigDecimal(cjsl).divide(new BigDecimal(siteDO.getSl()),2, BigDecimal
							.ROUND_HALF_UP).multiply(new BigDecimal("100")).toString());
					int num = turnoverEndService.insert(turnoverEndDO);
			}
		}
		log.info("===================================定时修改未成交状态轮询结束======================================================================");
	}
}
