/*
 * GiveBackBailLetterServiceImpl.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-09-20 21:04:21 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.transaction.server.service.impl;

import com.github.pagehelper.Page;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.dto.base.PageResult;
import com.unis.transaction.common.vo.givebackbail.GiveBackBailLetterListVO;
import com.unis.transaction.common.vo.givebackbail.GiveBackBailLetterShowVO;
import com.unis.transaction.common.vo.givebackbail.GiveBackBailLetterVO;
import com.unis.transaction.server.domain.givebackbail.GiveBackBailLetterDomain;
import com.unis.transaction.server.entity.givebackbail.GiveBackBailLetterDO;
import com.unis.transaction.server.service.GiveBackBailLetterService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * TY_JYTKWTH-退保证金委托函
 * @author lipenghe at 2019-09-20 21:04:21
 */
@Component
@Transactional
public class GiveBackBailLetterServiceImpl implements GiveBackBailLetterService {

    @Autowired
    GiveBackBailLetterDomain giveBackBailLetterDomain;

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 插入全部字段
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntityResult(GiveBackBailLetterVO bailLetterVO) {
        return giveBackBailLetterDomain.insertEntity(bailLetterVO);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 插入全部字段
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntitySelectiveResult(GiveBackBailLetterVO bailLetterVO) {
        return giveBackBailLetterDomain.insertEntitySelective(bailLetterVO);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 更改状态
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateStatusByEntityResult(GiveBackBailLetterVO bailLetterVO, String limit) {
        return giveBackBailLetterDomain.updateStatusByEntity(bailLetterVO);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 根据实体更新单条或者多条数据
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntityResult(GiveBackBailLetterVO bailLetterVO, String limit) {
        return giveBackBailLetterDomain.updateByEntity(bailLetterVO);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 根据实体选择性更新
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(GiveBackBailLetterVO bailLetterVO, String limit) {
        return giveBackBailLetterDomain.updateByEntitySelective(bailLetterVO);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 根据实体选择性更新,只更新主表,不更新子表
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateSingleByEntitySelectiveResult(GiveBackBailLetterVO bailLetterVO, String limit) {
        GiveBackBailLetterDO entity= JsonUtils.parse(
            JsonUtils.serialize(bailLetterVO), GiveBackBailLetterDO.class);
        int num=  giveBackBailLetterDomain.updateByEntitySelective(entity);
        return ResponseWrapper.choose(num);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 根据实体选择性更新
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(GiveBackBailLetterDO entity, String limit) {
        int num= giveBackBailLetterDomain.updateByEntitySelective(entity);
        return ResponseWrapper.choose(num);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 根据实体单条或者批量删除
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper deleteByEntityResult(GiveBackBailLetterVO bailLetterVO, String limit) {
        return giveBackBailLetterDomain.deleteShamByEntity(bailLetterVO);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 根据实体(唯一标示)查询一条数据
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByIdResult(GiveBackBailLetterDO entity) {
        GiveBackBailLetterVO bailLetterVO=giveBackBailLetterDomain.selectById(entity);
        if(bailLetterVO!=null){
            GiveBackBailLetterShowVO bailLetterShowVO= JsonUtils.parse(
                JsonUtils.serialize(bailLetterVO),GiveBackBailLetterShowVO.class);
            return ResponseWrapper.success(bailLetterShowVO);
        }
        return ResponseWrapper.notFound();
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 根据实体(唯一标示)查询一条数据
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByIdResult(GiveBackBailLetterVO bailLetterVO) {
        GiveBackBailLetterVO bailLetterVODb=giveBackBailLetterDomain.selectById(bailLetterVO);
        if(bailLetterVODb!=null){
           /* GiveBackBailLetterShowVO bailLetterShowVO= JsonUtils.parse(
                JsonUtils.serialize(bailLetterVODb),GiveBackBailLetterShowVO.class);*/
            return ResponseWrapper.success(bailLetterVODb);
        }
        return ResponseWrapper.notFound();
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 根据实体查询分页列表
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectPageByEntityResult(int pageNo, int pageSize
        , GiveBackBailLetterVO bailLetterVO, String order) {
        if("LS001020".equals(CurrentUtil.getOrgId())){
        }else{
            bailLetterVO.setWtfbm(CurrentUtil.getOrgId());
        }
        Page<GiveBackBailLetterVO> bailLetterVOPage=giveBackBailLetterDomain.selectPageByEntity(pageNo,pageSize,bailLetterVO,order);
        PageResult<GiveBackBailLetterVO> bailLetterVOPageResult=new PageResult<>(bailLetterVOPage);
        PageResult<GiveBackBailLetterListVO> bailLetterListVOPageResult= JsonUtils.parse(
            JsonUtils.serialize(bailLetterVOPageResult), PageResult.class);
        return ResponseWrapper.success(bailLetterListVOPageResult);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 根据实体查询列表
     * @param entity    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByEntityResult(GiveBackBailLetterDO entity) {
        List<GiveBackBailLetterVO> bailLetterVOList=giveBackBailLetterDomain.selectByEntity(entity);
        List<GiveBackBailLetterListVO> bailLetterListVOList= JsonUtils.parseList(
            JsonUtils.serialize(bailLetterVOList),GiveBackBailLetterListVO.class);
        return ResponseWrapper.success(bailLetterListVOList);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 根据实体查询列表
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByEntityResult(GiveBackBailLetterVO bailLetterVO) {
        List<GiveBackBailLetterVO> bailLetterVOList=giveBackBailLetterDomain.selectByEntity(bailLetterVO);
        List<GiveBackBailLetterListVO> bailLetterListVOList= JsonUtils.parseList(
            JsonUtils.serialize(bailLetterVOList),GiveBackBailLetterListVO.class);
        return ResponseWrapper.success(bailLetterListVOList);
    }

    /**
     * <TY_JYTKWTH-退保证金委托函>
     * 根据实体查询初始化数据
     * @param bailLetterVO    <退保证金委托函>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectInitDataResult(GiveBackBailLetterVO bailLetterVO) {
        return ResponseWrapper.success(bailLetterVO);
    }

    @Override
    public ResponseWrapper selectTkdwList() {
        return ResponseWrapper.success(giveBackBailLetterDomain.selectTkdwList());
    }

    @Override
    public ResponseWrapper selectTkdwHtList(String dwbm) {
        return ResponseWrapper.success(giveBackBailLetterDomain.selectTkdwHtList(dwbm));
    }

}
