package com.unis.transaction.server.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.RequestUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.constant.BacklogConstant;
import com.unis.transaction.common.dto.base.PageResult;
import com.unis.transaction.common.vo.tradeplan.ContractVO;
import com.unis.transaction.server.dao.TyHtlytxDao;
import com.unis.transaction.server.dao.TyHttxsjDao;
import com.unis.transaction.server.entity.tradeplan.*;
import com.unis.transaction.server.service.BacklogMQService;
import com.unis.transaction.server.service.TradeMarkService;
import com.unis.transaction.server.service.TyHttxsjService;
import com.unis.transaction.server.service.user.UserService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.amqp.core.AmqpTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.locks.ReentrantLock;
import java.util.stream.Collectors;

/**
 * @Classname TyHttxsjServiceImpl
 * @Description 合同提醒时间ServiceImpl
 * @Date 2023/8/2 10:15
 * @Created by rising123sun
 */
@Service
@Transactional(rollbackFor = Exception.class)
@Slf4j
public class TyHttxsjServiceImpl implements TyHttxsjService {

    @Resource
    private TyHttxsjDao tyHttxsjDao;

    @Resource
    private TyHtlytxDao tyHtlytxDao;

    @Resource
    private TradeMarkService trademarkService;
    @Resource
    private UserService userService;

    @Resource
    private BacklogMQService mqService;

    @Resource
    private AmqpTemplate amqpTemplate;

    private final ReentrantLock lock = new ReentrantLock();

    // 新增合同提醒时间
    @Override
    public String htsjtxsz(Integer sj) {
        try {
            // 根据szsj查询是否已经设置过
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            TyHttxsj ifSzsj = new TyHttxsj();
            Date date = sdf.parse(sdf.format(new Date()));
            ifSzsj.setSzsj(date);
            if (tyHttxsjDao.selectOne(ifSzsj) != null) {
                // 已经设置过了,删除
                tyHttxsjDao.delete(ifSzsj);
            }
            TyHttxsj tyHttxsj = new TyHttxsj();
            tyHttxsj.setSj(sj);
            // szsj设置为当前日期的yyyy-MM-dd的格式
            tyHttxsj.setSzsj(date);
            tyHttxsjDao.insert(tyHttxsj);
            return "设置成功";
        } catch (ParseException e) {
            e.printStackTrace();
            return "设置失败";
        }

    }

    @Override
    @Scheduled(cron = "0 0 0 * * ?")
    public String tjhtlytx() {
        // 查询所有的合同提醒时间，然后获取最新的合同提醒时间
        List<TyHttxsj> select = tyHttxsjDao.select(null);
        if (select != null && select.size() > 0) {
            // 获取最新的合同提醒时间
            TyHttxsj tyHttxsj = select.stream().sorted((o1, o2) -> {
                if (o1.getSzsj().getTime() < o2.getSzsj().getTime()) {
                    return 1;
                } else if (o1.getSzsj().getTime() > o2.getSzsj().getTime()) {
                    return -1;
                } else {
                    return 0;
                }
            }).collect(Collectors.toList()).get(0);
            // 获取所有合同信息
            List<TyHtlytx> tyHttxsjs = tyHtlytxDao.getAllHt();

            // 获取当前时间
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            Date date = null;
            try {
                date = sdf.parse(sdf.format(new Date()));
            } catch (ParseException e) {
                e.printStackTrace();
            }

            // 过滤出当前时间加上合同提醒时间为合同信息的计划完成日期的合同信息
            Date finalDate = date;
            List<TyHtlytx> collect = tyHttxsjs.stream().filter(tyHttxsj1 -> {
                if (tyHttxsj1.getJhwcrq() == null) {
                    return false;
                }
                // 计划完成日期
                Date jhwcrq = tyHttxsj1.getJhwcrq();
                try {
                    jhwcrq = sdf.parse(sdf.format(jhwcrq));
                } catch (ParseException e) {
                    throw new RuntimeException(e);
                }
                // 计划完成日期减去当前日期
                long l = jhwcrq.getTime() - finalDate.getTime();
                // 计算出来的天数
                long day = l / (24 * 60 * 60 * 1000);
                // 如果天数等于合同提醒时间，则返回true
                if (day == tyHttxsj.getSj()) {
                    return true;
                } else {
                    return false;
                }
            }).collect(Collectors.toList());

            // 过滤掉collet当中hth不在allLytx当中的数据
            List<TyHtlytx> allLytx = tyHtlytxDao.selectAll();
            // 获取allLytx中所有的hth值
            List<String> allHth = allLytx.stream().map(TyHtlytx::getHth).collect(Collectors.toList());

            // 过滤collect中的元素，只保留hth值在allLytx中存在的元素
            collect = collect.stream()
                    .filter(item -> !allHth.contains(item.getHth()))
                    .collect(Collectors.toList());

            // 保存记录
            if (collect != null && collect.size() > 0) {
                // 保存相关代办事项
                Date finalDate1 = date;
                collect.forEach(tyHtlytx -> {
                    // 保存相关代办事项
                    tyHtlytx.setId(UUID.randomUUID().toString().replace("-", ""));
                    tyHtlytx.setFqdw("中国天津粮油批发交易市场交易部");
                    tyHtlytx.setFqr("交易部");
                    tyHtlytx.setTxrq(finalDate1);
                    tyHtlytx.setHfzt("0");
                    tyHtlytx.setRwmc("回复敦促履约函");
                    tyHtlytx.setSclyhzt("0");
                    if (StringUtils.isNotBlank(tyHtlytx.getCcqybm())) {
                        tyHtlytx.setOrgCode(tyHtlytx.getCcqybm());
                        //todo 保存相关代办事项
                        List<ReceiverCollectionVO> receiverCollectionVOS = userService.addUserList(null, "R0000341", tyHtlytx.getOrgCode());
                        if (receiverCollectionVOS != null && receiverCollectionVOS.size() > 0) {
                            //if(TransferDepotConstant.TO_BE_REVIEW.equals(vo.getShzt())){
                            //				mqService.addInfoCheckNeedToDeals(entity.getBabh(), show.getCcdwmc()+"提交的仓储单位备案信息待审核!", vo.getShzt(),
                            //						vo.getShztmc(), vo.getItemUrl(), vo.getItemQuery(), vo.getItemQueryHaveDone(), vo.getItemUrlHaveDone(), vo.getUserList());
                            //			}
                            // 转成json
                            JSONObject itemQuery = new JSONObject();
                            itemQuery.put("id", tyHtlytx.getId());

                            addInfoCheckNeedToDeals(tyHtlytx.getId(),
                                    tyHtlytx.getRwmc() + "提交的合同履约提醒信息待回复", "0", "未回复", "/transaction/TradeAlert/detail", JSON.toJSONString(itemQuery), "null", "null", receiverCollectionVOS);
                        }
                    }
                    // 保存
                    tyHtlytxDao.insert(tyHtlytx);
                });


                return "定时任务合同履约提醒成功";
            } else {
                return "没有需要提醒的合同";
            }

        } else {
            return "未设置提醒时间，请先设置提醒时间";
        }
    }

    @Override
    public JSONObject sccsdclyh(String hth) {
        try {
            // 根据合同号查询合同信息
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy年MM月dd日");
            SimpleDateFormat sdf1 = new SimpleDateFormat("yyyy-MM-dd");
            TyHtlytx tyHtlytx = new TyHtlytx();
            tyHtlytx.setHth(hth);
            TyHtlytx htxx = tyHtlytxDao.selectOne(tyHtlytx);
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("hth", hth);
            jsonObject.put("bzr", CurrentUtil.getUserName());
            jsonObject.put("bzrq", sdf.format(new Date()));
            ResponseWrapper responseWrapper = trademarkService.selectContractDetail(htxx.getHtbm());
            if (responseWrapper.isSuccess()) {
                ContractVO contractVO = JSONObject.parseObject(JSONObject.toJSONString(responseWrapper.getData()), ContractVO.class);
                if (contractVO.getJylx() != null) {
                    if (contractVO.getJylx() == 0) {
                        jsonObject.put("cjdw", contractVO.getCmmc());
                    } else if (contractVO.getJylx() == 1) {
                        jsonObject.put("cjdw", contractVO.getSgmc());
                    } else {
                        jsonObject.put("cjdw", contractVO.getCmmc());
                    }
                }
                if (StringUtils.isNotBlank(contractVO.getCjrq())) {
                    // 将yyyy-MM-dd格式的字符串转换成yyyy年MM月dd日格式的日期
                    Date cjsj = sdf1.parse(contractVO.getCjrq());
                    jsonObject.put("cjsj", sdf.format(cjsj));
                }
            }
            // 截至日期
            jsonObject.put("jzrq", sdf.format(new Date()));
            // 生成日期
            jsonObject.put("scsj", sdf.format(new Date()));
            return jsonObject;
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    @Override
    public PageResult<TyHtlytx> queryPageList(int pageNum, int pageSize, TyHtlytxVO tyHtlytx) {
        PageHelper.startPage(pageNum, pageSize);

        String headerToken = RequestUtils.getHeaderToken();
        if (StringUtils.isEmpty(headerToken)) {
        } else {
            String orgId = CurrentUtil.getOrgId();
            if (!"LS001020".equals(CurrentUtil.getOrgId())) {
                // 不是交易中心
                tyHtlytx.setOrgCode(orgId);
            }
        }
        Page<TyHtlytx> page = tyHtlytxDao.selectList(tyHtlytx);
        if (page.getResult().size() > 0) {
            List<TyHtlytx> result = page.getResult();
            for (TyHtlytx htlytx : result) {
                // 如果apcc为空，从合同信息里面查询
                if (StringUtils.isBlank(htlytx.getApcc())) {
                    // 根据合同号查询合同信息
                    ResponseWrapper responseWrapper = trademarkService.selectContractDetail(htlytx.getHtbm());
                    if (responseWrapper.isSuccess()) {
                        ContractVO contractVO = JSONObject.parseObject(JSONObject.toJSONString(responseWrapper.getData()), ContractVO.class);
                        if (StringUtils.isNotBlank(contractVO.getApcc())) {
                            htlytx.setApcc(contractVO.getApcc());
                        }
                    }
                }
            }
        }
        return new PageResult<>(page.getTotal(), page.getPages(), pageNum, page.getResult());
    }

    @Override
    public String hfhtlytx(TyHtlytx tyHtlytx) {
        // 多个人同时回复需要通过version来判断，加锁
        lock.lock();
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            if (StringUtils.isBlank(tyHtlytx.getId())) {
                return "回复失败，id不能为空";
            }
            // 根据id查询合同履约提醒信息
            TyHtlytx htlytx = tyHtlytxDao.selectByPrimaryKey(tyHtlytx.getId());
            // 如果回复状态为已回复，则不允许再次回复
            if ("1".equals(htlytx.getHfzt())) {
                return "该合同履约提醒已回复，请勿重复回复";
            }
            // 如果回复状态为未回复，则允许回复
            // 设置回复状态为已回复
            htlytx.setHfzt("1");
            // 设置回复时间
            if (tyHtlytx.getHfsj() == null) {
                htlytx.setHfsj(sdf.parse(sdf.format(new Date())));
            } else {
                htlytx.setHfsj(sdf.parse(sdf.format(tyHtlytx.getHfsj())));
            }

            if (StringUtils.isNotBlank(tyHtlytx.getSm())) {
                htlytx.setSm(tyHtlytx.getSm());
            }
            htlytx.setCcqyhf(tyHtlytx.getCcqyhf());
            // 更新
            tyHtlytxDao.updateByPrimaryKey(htlytx);

            // 将该承储企业下面的代办人员的该条代办事项变为已办
            List<ReceiverCollectionVO> receiverCollectionVOS = userService.addUserList(null, "R0000341", htlytx.getOrgCode());
            //			if(TransferDepotConstant.REFUSED.equals(vo.getShzt())||TransferDepotConstant.REVIEWED.equals(vo.getShzt())){
            //				mqService.addInfoCheckDeals(entity.getBabh(), show.getCcdwmc()+"提交的仓储单位备案信息已审核!", vo.getShzt(), vo
            //						.getShztmc());
            if (receiverCollectionVOS != null && receiverCollectionVOS.size() > 0) {
                for (ReceiverCollectionVO receiverCollectionVO : receiverCollectionVOS) {
                    //					mqService.addInfoCheckDeals(entity.getBabh(), show.getCcdwmc()+"提交的仓储单位备案信息已审核!", vo.getShzt(), vo
                    //							.getShztmc());
                    String itemUrlHaveDone = "/transaction/TradeAlert/detail";
                    // 转成json
                    JSONObject itemQueryHaveDone = new JSONObject();
                    itemQueryHaveDone.put("id", tyHtlytx.getId());
                    addInfoCheckDeals(htlytx.getId(), htlytx.getRwmc() + "提交的合同履约提醒信息已回复!", "1", "已回复", JSON.toJSONString(itemQueryHaveDone), itemUrlHaveDone);
                }
            }

            return "回复成功";

        } catch (Exception e) {
            e.printStackTrace();
            return e.getMessage();
        } finally {
            lock.unlock();
        }
    }

    @Override
    public String xgbcDclyh(String lytxid, String dclyhbzr, String dclyh, String dclyhbzrq, String sclyhzt) {
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy年MM月dd日");
            // 根据id查询合同履约提醒信息
            TyHtlytx htlytx = tyHtlytxDao.selectByPrimaryKey(lytxid);
            htlytx.setDclyhbzr(dclyhbzr);
            htlytx.setDcllh(dclyh);
            htlytx.setDclyhbzrq(sdf.parse(dclyhbzrq));
            htlytx.setSclyhzt(sclyhzt);
            // 更新
            tyHtlytxDao.updateByPrimaryKey(htlytx);
            return "操作成功";
        } catch (Exception e) {
            e.printStackTrace();
            return e.getMessage();
        }
    }

    @Override
    public TyHtlytx queryDclyhById(String id) {
        try {
            return tyHtlytxDao.selectByPrimaryKey(id);
        } catch (Exception e) {
            log.error("根据id查询合同履约提醒信息失败", e);
            return null;
        }
    }

    @Override
    public TyHttxsj htsjtxcx() {
        List<TyHttxsj> select = tyHttxsjDao.select(null);
        if (select != null && select.size() > 0) {
            // 获取最新的合同提醒时间
            TyHttxsj tyHttxsj = select.stream().sorted((o1, o2) -> {
                if (o1.getSzsj().getTime() < o2.getSzsj().getTime()) {
                    return 1;
                } else if (o1.getSzsj().getTime() > o2.getSzsj().getTime()) {
                    return -1;
                } else {
                    return 0;
                }
            }).collect(Collectors.toList()).get(0);
            return tyHttxsj;
        }
        return null;
    }

    /**
     * @param id
     * @param title
     * @param status
     * @param statusName
     * @param itemUrl
     * @param itemQuery
     * @param itemQueryHaveDone
     * @param itemUrlHaveDone
     * @param userList
     * @Author Rising123Sun
     * @Description 加代办
     * @Date 2023/8/7 11:18
     */
    public void addInfoCheckNeedToDeals(String id, String title, String status, String statusName, String itemUrl, String itemQuery,
                                        String itemQueryHaveDone,
                                        String itemUrlHaveDone,
                                        List<ReceiverCollectionVO> userList) {
        System.out.println("*************进入创建待办************");
        BacklogAddVO record = new BacklogAddVO();
        record.buildInfoCheckAddVO(record);
        record.setItemId(id);
        record.setItemName(title);
        record.setItemStatus(Integer.valueOf(status));
        record.setItemStatusName(statusName);
        record.setItemUrl(itemUrl);
        record.setItemQuery(itemQuery);
        record.setItemQueryHaveDone(itemQueryHaveDone);
        record.setItemUrlHaveDone(itemUrlHaveDone);
        // 另起线程执行待办
        try {
            new Thread(new Runnable() {
                @Override
                public void run() {
                    for (ReceiverCollectionVO userVO : userList) {
                        System.out.println("********************接收人*******************");
                        System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                        System.out.println("********************************************");
                        record.setReceiver(userVO.getUserName());
                        record.setReceiverId(userVO.getUserId());
                        // 需要将对象序列化成JSONObject
                        mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
                    }
                }
            }).start();
        } catch (Exception e) {
            System.out.println("待办添加异常" + e.getMessage());
        }
    }

    public void sendMsg(Object obj, String type) {
        try {
            this.amqpTemplate.convertAndSend(BacklogConstant.BACKLOG_EXCHANGE, "backlog." + type, obj);
        } catch (Exception e) {
            log.error("{}待办消息发送异常,待办实体{}", type, obj, e);
        }
    }

    /**
     * @param itemId
     * @param itemName
     * @param status
     * @param statusName
     * @Author Rising123Sun
     * @Description 加已办
     * @Date 2023/8/7 11:19
     */
    public void addInfoCheckDeals(String itemId, String itemName, String status, String statusName, String itemQueryHaveDone,
                                  String itemUrlHaveDone) {
        System.out.println("*************进入创建已办************");
        BacklogUpdateVO updateVO = new BacklogUpdateVO();
        updateVO.buildInfoCheckUpdateVO(updateVO);
        updateVO.setItemId(itemId);
        updateVO.setItemName(itemName);
        updateVO.setItemStatus(Integer.valueOf(status));
        updateVO.setItemStatusName(statusName);
        updateVO.setItemQueryHaveDone(itemQueryHaveDone);
        updateVO.setItemUrlHaveDone(itemUrlHaveDone);
        mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(updateVO)), "update");
    }
}
