package com.unis.transaction.server.service.impl;

import com.alibaba.excel.EasyExcel;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.dto.base.PageResult;
import com.unis.transaction.common.vo.tradeplan.SiteBacktVO;
import com.unis.transaction.common.vo.tradeplan.SiteVO;
import com.unis.transaction.server.dao.TyJyccKhxxDao;
import com.unis.transaction.server.entity.tradeplan.TyBmkhxxtj;
import com.unis.transaction.server.entity.tradeplan.TyJyccKhxx;
import com.unis.transaction.server.entity.tradeplan.TyJyccKhxxVO;
import com.unis.transaction.server.entity.tradeplan.TyJytjbb;
import com.unis.transaction.server.listener.DataListener;
import com.unis.transaction.server.service.TradeMarkService;
import com.unis.transaction.server.service.TyJyccKhxxService;
import lombok.val;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * @Classname TyJyccKhxxServiceImpl
 * @Description 交易场次_报名客户Service实现类
 * @Date 2023/7/27 15:26
 * @Created by rising123sun
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class TyJyccKhxxServiceImpl implements TyJyccKhxxService {

    @Resource
    private TyJyccKhxxDao tyJyccKhxxDao;

    @Resource
    private TradeMarkService tradeMarkService;

    @Override
    public ResponseWrapper importExcel(TyJyccKhxxVO tyJyccKhxxVO) {
        try {
            // 删除旧数据
            TyJyccKhxx selectOne = new TyJyccKhxx();
            if (StringUtils.isNotBlank(tyJyccKhxxVO.getWtbm())) {
                selectOne.setWtbh(tyJyccKhxxVO.getWtbm());
                List<TyJyccKhxx> select = tyJyccKhxxDao.select(selectOne);
                if (select != null && select.size() > 0) {
                    for (TyJyccKhxx jyccKhxx : select) {
                        tyJyccKhxxDao.delete(jyccKhxx);
                    }
                }
            }

            AtomicInteger i = new AtomicInteger();
            if (tyJyccKhxxVO.getTyJyccKhxxList() != null && tyJyccKhxxVO.getTyJyccKhxxList().size() > 0) {
                tyJyccKhxxVO.getTyJyccKhxxList().forEach(tyJyccKhxx -> {
                    if (StringUtils.isNotBlank(tyJyccKhxx.getWtbh())) {
                        tyJyccKhxx.setWtbh(tyJyccKhxxVO.getWtbm());
                        tyJyccKhxx.setId(UUID.randomUUID().toString().replace("-", ""));
                        tyJyccKhxxDao.insert(tyJyccKhxx);
                        i.getAndIncrement();
                    }
                });
            }
            return ResponseWrapper.success(i.get());
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }

    }

    @Override
    public TyJyccKhxxVO selectKhxxByWtbh(String ccId) {
        TyJyccKhxxVO tyJyccKhxxVO = new TyJyccKhxxVO();
        SiteBacktVO siteBacktVO = tradeMarkService.selectCC(ccId);
        if (siteBacktVO != null && siteBacktVO.getSiteVO() != null) {
            SiteVO siteVO = siteBacktVO.getSiteVO();
            if (StringUtils.isNotBlank(siteVO.getApcc())) {
                tyJyccKhxxVO.setApcc(siteVO.getApcc());
            }
            if (siteVO.getJyrq() != null) {
                tyJyccKhxxVO.setJyrq(siteVO.getJyrq());
            }
            if (StringUtils.isNotBlank(siteVO.getWtbm())) {
                tyJyccKhxxVO.setTyJyccKhxxList(tyJyccKhxxDao.selectKhxxByWtbh(siteVO.getWtbm()));
            }
            return tyJyccKhxxVO;
        } else {
            return null;
        }
    }

    @Override
    public List<TyJyccKhxx> selectKhxx(String wtbm) {
        TyJyccKhxx tyJyccKhxx = new TyJyccKhxx();
        tyJyccKhxx.setWtbh(wtbm);
        return tyJyccKhxxDao.select(tyJyccKhxx);
    }

    @Override
    public Integer addKhxx(List<TyJyccKhxx> tyJyccKhxxList) {
        if (tyJyccKhxxList != null && tyJyccKhxxList.size() > 0) {
            AtomicInteger i = new AtomicInteger();
            tyJyccKhxxList.forEach(tyJyccKhxx -> {
                tyJyccKhxx.setId(UUID.randomUUID().toString().replace("-", ""));
                tyJyccKhxxDao.insert(tyJyccKhxx);
                i.getAndIncrement();
            });
            return i.get();
        }
        return 0;
    }

    @Override
    public Integer deleteKhxx(List<TyJyccKhxx> tyJyccKhxxList) {
        if (tyJyccKhxxList != null && tyJyccKhxxList.size() > 0) {
            AtomicInteger i = new AtomicInteger();
            tyJyccKhxxList.forEach(tyJyccKhxx -> {
                tyJyccKhxxDao.delete(tyJyccKhxx);
                i.getAndIncrement();
            });
            return i.get();
        }
        return 0;
    }

    @Override
    public PageResult<TyBmkhxxtj> selectKhxxTj(int pageNum, int pageSize, TyBmkhxxtj tyBmkhxxtj) {
        PageHelper.startPage(pageNum, pageSize);
        Page<TyBmkhxxtj> page = tyJyccKhxxDao.selectKhxxTj(tyBmkhxxtj);
        List<TyBmkhxxtj> result = page.getResult();
        if (result != null && result.size() > 0) {
            result.forEach(tyBmkhxxtj1 -> {
                if (StringUtils.isNotBlank(tyBmkhxxtj1.getLsxzbm())) {
                    // 粮食性质<br/> 1·市储<br/> 2·区储<br/> 3·市自
                    if ("1".equals(tyBmkhxxtj1.getLsxzbm())) {
                        tyBmkhxxtj1.setLsxzmc("市储");
                    } else if ("2".equals(tyBmkhxxtj1.getLsxzbm())) {
                        tyBmkhxxtj1.setLsxzmc("区储");
                    } else if ("3".equals(tyBmkhxxtj1.getLsxzbm())) {
                        tyBmkhxxtj1.setLsxzmc("市自");
                    }
                }
                if (StringUtils.isNotBlank(tyBmkhxxtj1.getCjqk())) {
                    if (Integer.valueOf(tyBmkhxxtj1.getCjqk()) > 0) {
                        tyBmkhxxtj1.setCjqk("已成交");
                    } else {
                        tyBmkhxxtj1.setCjqk("未成交");
                    }
                }
            });
        }
        return new PageResult<>(page.getTotal(), page.getPages(), pageNum, page.getResult());
    }

    @Override
    public List<TyBmkhxxtj> exportKhxxTj(TyBmkhxxtj tyBmkhxxtj) {
        List<TyBmkhxxtj> tyBmkhxxtjs = tyJyccKhxxDao.exportKhxxTj(tyBmkhxxtj);
        if (tyBmkhxxtjs != null && tyBmkhxxtjs.size() > 0) {
            tyBmkhxxtjs.forEach(tyBmkhxxtj1 -> {
                if (StringUtils.isNotBlank(tyBmkhxxtj1.getLsxzbm())) {
                    // 粮食性质<br/> 1·市储<br/> 2·区储<br/> 3·市自
                    if ("1".equals(tyBmkhxxtj1.getLsxzbm())) {
                        tyBmkhxxtj1.setLsxzmc("市储");
                    } else if ("2".equals(tyBmkhxxtj1.getLsxzbm())) {
                        tyBmkhxxtj1.setLsxzmc("区储");
                    } else if ("3".equals(tyBmkhxxtj1.getLsxzbm())) {
                        tyBmkhxxtj1.setLsxzmc("市自");
                    }
                }
                if (StringUtils.isNotBlank(tyBmkhxxtj1.getCjqk())) {
                    if (Integer.valueOf(tyBmkhxxtj1.getCjqk()) > 0) {
                        tyBmkhxxtj1.setCjqk("已成交");
                    } else {
                        tyBmkhxxtj1.setCjqk("未成交");
                    }
                }
            });
        }
        return tyBmkhxxtjs;
    }
}
