package com.unis.transaction.server.service.impl;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.alibaba.excel.write.metadata.style.WriteCellStyle;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.RequestUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.transaction.common.dto.base.PageResult;
import com.unis.transaction.common.vo.tradeplan.SiteBacktVO;
import com.unis.transaction.common.vo.tradeplan.SiteVO;
import com.unis.transaction.common.vo.tradeplan.SxfVO;
import com.unis.transaction.common.vo.tradeplan.WarehousingArrangementVO;
import com.unis.transaction.server.config.MergeStrategy;
import com.unis.transaction.server.dao.*;
import com.unis.transaction.server.domain.tradeplan.EntryAndExitOrderDomain;
import com.unis.transaction.server.entity.creditevaluate.TurnoverEndDO;
import com.unis.transaction.server.entity.signuppay.TransactionSignUpDO;
import com.unis.transaction.server.entity.tradeplan.*;
import com.unis.transaction.server.service.TyJytjbbService;
import lombok.var;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.text.StrBuilder;
import org.apache.poi.xwpf.usermodel.*;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.InputStreamResource;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.FileOutputStream;
import java.lang.reflect.Field;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.net.URLEncoder;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.*;
import java.util.stream.Collectors;

/**
 * @Classname TyJytjbbServiceImpl
 * @Description 交易统计报表Service实现类
 * @Date 2023/7/28 09:48
 * @Created by rising123sun
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class TyJytjbbServiceImpl implements TyJytjbbService {

    @Resource
    private TyJytjbbDao tyJytjbbDao;

    @Resource
    private EntryAndExitOrderDomain entryAndExitOrderDomain;

    @Resource
    TradeMarkDao tradeMarkDao;

    @Resource
    WarehousingArrangementDao warehousingArrangementDao;

    @Resource
    ContractDao contractDao;

    @Override
    public PageResult<TyJytjbb> selectContractPage(int pageNum, int pageSize, TyJytjbb vo) {
        PageHelper.startPage(pageNum, pageSize);
        String headerToken = RequestUtils.getHeaderToken();
        if (StringUtils.isEmpty(headerToken)) {
        } else {
            String orgId = CurrentUtil.getOrgId();
            vo.setWtfbm(orgId);
            if ("LS001020".equals(CurrentUtil.getOrgId())) {
                // 交易中心
            } else {
            }
        }
        Page<TyJytjbb> page = tyJytjbbDao.selectPageList(vo);
        return new PageResult<>(page.getTotal(), page.getPages(), pageNum, page.getResult());
    }

    @Override
    public List<TyJytjbbScbcj> sjcbcj(String apcc) {
        List<TyJytjbbScbcj> dataList = tyJytjbbDao.sjcbcj(apcc);
        if (dataList != null && dataList.size() > 0) {
            for (TyJytjbbScbcj tyJytjbbScbcj : dataList) {
                if (StringUtils.isNotBlank(tyJytjbbScbcj.getJe())) {
                    tyJytjbbScbcj.setJe(formatJeNumber(new BigDecimal(tyJytjbbScbcj.getJe())).toString());
                }
                if (StringUtils.isNotBlank(tyJytjbbScbcj.getQpdj())) {
                    tyJytjbbScbcj.setQpdj(formatJeNumber(new BigDecimal(tyJytjbbScbcj.getQpdj())).toString());
                }
            }
        }
        return dataList;
    }

    @Override
    public ResponseWrapper sjcbcjExport(String apcc) {
        try {
            List<TyJytjbbScbcj> dataList = tyJytjbbDao.sjcbcj(apcc);
            if (dataList != null && dataList.size() > 0) {
                for (TyJytjbbScbcj tyJytjbbScbcj : dataList) {
                    if (StringUtils.isNotBlank(tyJytjbbScbcj.getJe())) {
                        tyJytjbbScbcj.setJe(formatJeNumber(new BigDecimal(tyJytjbbScbcj.getJe())).toString());
                    }
                    if (StringUtils.isNotBlank(tyJytjbbScbcj.getQpdj())) {
                        tyJytjbbScbcj.setQpdj(formatJeNumber(new BigDecimal(tyJytjbbScbcj.getQpdj())).toString());
                    }
                }
            }

            return ResponseWrapper.success(dataList);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }

    }

    @Override
    public TyJytjbbSxftjVO sxfTj(String apcc) {
        List<TyJytjbbSxftj> list = tyJytjbbDao.sxfTj(apcc);
        TyJytjbbSxftjVO vo = new TyJytjbbSxftjVO();
        if (list != null && list.size() > 0) {
            // 将结果先按照cjdw生序排序，再按照合同编号排序
            list.sort(Comparator.comparing(TyJytjbbSxftj::getCjdw).thenComparing(TyJytjbbSxftj::getHtbh));
            for (TyJytjbbSxftj tyJytjbbSxftj : list) {
                if (StringUtils.isNotBlank(tyJytjbbSxftj.getJe())) {
                    tyJytjbbSxftj.setJe(formatJeNumber(new BigDecimal(tyJytjbbSxftj.getJe())).toString());
                } else {
                    tyJytjbbSxftj.setJe("0");
                }
            }
            // 判断list的元素中jyfx是否包含0,1
            List<TyJytjbbSxftj> collect = list.stream().filter(item -> StringUtils.isNotBlank(item.getJyfs())
                    && "2".equals(item.getJyfs())).collect(Collectors.toList());
            if (collect.size() > 0) {
                List<TyJytjbbSxftj> cgList = list.stream().filter(item -> StringUtils.isNotBlank(item.getJylx())
                        && "0".equals(item.getJylx())).collect(Collectors.toList());
                extracted(cgList);
                vo.setList(cgList);
                List<TyJytjbbSxftj> xsList = list.stream().filter(item -> StringUtils.isNotBlank(item.getJylx())
                        && "1".equals(item.getJylx())).collect(Collectors.toList());

                extracted(xsList);
                vo.setListForGxsx(xsList);
            } else {
                extracted(list);
                vo.setList(list);
            }
        }
        return vo;
    }

    private static void extracted(List<TyJytjbbSxftj> list) {
        for (TyJytjbbSxftj tyJytjbbSxftj : list) {
            // 非购销双向
            // 成交额(元)*手续费率 手续费要求：四舍五入，保留2位小数
            BigDecimal je = new BigDecimal(tyJytjbbSxftj.getJe());
            // 手续费率转换成千分之
            BigDecimal sxfl = new BigDecimal(tyJytjbbSxftj.getSxfl()).divide(new BigDecimal(100)).setScale(4, RoundingMode.HALF_UP);
            BigDecimal multiply = formatJeNumber(je.multiply(sxfl));
            tyJytjbbSxftj.setSxf(multiply.toString());
//            if (StringUtils.isNotEmpty(tyJytjbbSxftj.getCjrq())) {
//                String cjrq = tyJytjbbSxftj.getCjrq();
//                try {
//                    tyJytjbbSxftj.setCjrq(new SimpleDateFormat("yyyy-MM-dd").format(new SimpleDateFormat("yyyy-MM-dd").parse(cjrq)));
//                } catch (ParseException e) {
//                    e.printStackTrace();
//                }
//            }
            // 冻结交易保证金(元)	交易保证金(元/吨)*成交数量
            if (StringUtils.isNotEmpty(tyJytjbbSxftj.getCjsl())) {
                // 成交数量保留2位小数
                BigDecimal cjsl = formatSlNumber(new BigDecimal(tyJytjbbSxftj.getCjsl()).setScale(2, RoundingMode.HALF_UP));
                tyJytjbbSxftj.setCjsl(cjsl.toString());

                BigDecimal jybzj = new BigDecimal(tyJytjbbSxftj.getJybzj()).setScale(2, RoundingMode.HALF_UP);


                BigDecimal multiply1 = formatJeNumber(jybzj.multiply(cjsl));
                tyJytjbbSxftj.setDjjybzj(multiply1.toString());
                // 冻结履约保证金(元)	履约保证金(元/吨)*成交数量
                BigDecimal lybzj = new BigDecimal(tyJytjbbSxftj.getLybzj()).setScale(2, RoundingMode.HALF_UP);
                BigDecimal multiply2 = formatJeNumber(lybzj.multiply(cjsl));
                tyJytjbbSxftj.setDjlybzj(multiply2.toString());
                // 可清退金额（元）	实际交款额（元）-冻结交易保证金-冻结履约保证金
                if (StringUtils.isNotEmpty(tyJytjbbSxftj.getSjjke())) {
                    BigDecimal sjjke = formatJeNumber(new BigDecimal(tyJytjbbSxftj.getSjjke()).setScale(2, RoundingMode.HALF_UP));
                    tyJytjbbSxftj.setSjjke(sjjke.toString());
                    BigDecimal subtract = formatJeNumber(sjjke.subtract(multiply1).subtract(multiply2));
                    tyJytjbbSxftj.setKqtje(subtract.toString());
                }

            }
        }
        // 合计统计
        TyJytjbbSxftj hj = new TyJytjbbSxftj();
        hj.setHtbh("合计");
        // 成交数量为list中所有成交数量之和
        hj.setCjsl(list.stream().map(TyJytjbbSxftj::getCjsl).reduce(String.valueOf(BigDecimal.ZERO), (a, b) -> {
            if (StringUtils.isNotEmpty(a) && StringUtils.isNotEmpty(b)) {
                return String.valueOf(formatSlNumber(new BigDecimal(a).add(new BigDecimal(b))));
            } else if (StringUtils.isNotEmpty(a)) {
                return String.valueOf(formatSlNumber(new BigDecimal(a)));
            } else if (StringUtils.isNotEmpty(b)) {
                return String.valueOf(formatSlNumber(new BigDecimal(b)));
            } else {
                return String.valueOf(BigDecimal.ZERO);
            }
        }));
        // 成交额为list中所有成交额之和
        hj.setJe(list.stream().map(TyJytjbbSxftj::getJe).reduce(String.valueOf(BigDecimal.ZERO), (a, b) -> {
            if (StringUtils.isNotEmpty(a) && StringUtils.isNotEmpty(b)) {
                return String.valueOf(formatJeNumber(new BigDecimal(a).add(new BigDecimal(b))));
            } else if (StringUtils.isNotEmpty(a)) {
                return String.valueOf(formatJeNumber(new BigDecimal(a)));
            } else if (StringUtils.isNotEmpty(b)) {
                return String.valueOf(formatJeNumber(new BigDecimal(b)));
            } else {
                return String.valueOf(BigDecimal.ZERO);
            }
        }));
        // 手续费为list中所有手续费之和
        hj.setSxf(list.stream().map(TyJytjbbSxftj::getSxf).reduce(String.valueOf(BigDecimal.ZERO), (a, b) -> {
            if (StringUtils.isNotEmpty(a) && StringUtils.isNotEmpty(b)) {
                return String.valueOf(formatJeNumber(new BigDecimal(a).add(new BigDecimal(b))));
            } else if (StringUtils.isNotEmpty(a)) {
                return String.valueOf(formatJeNumber(new BigDecimal(a)));
            } else if (StringUtils.isNotEmpty(b)) {
                return String.valueOf(formatJeNumber(new BigDecimal(b)));
            } else {
                return String.valueOf(BigDecimal.ZERO);
            }
        }));
        list.add(0, hj);

        // 财政收入
        TyJytjbbSxftj czsr = new TyJytjbbSxftj();
        if (StringUtils.isNotEmpty(list.get(1).getLsxzbm()) && "2".equals(list.get(1).getLsxzbm())) {
            czsr.setHtbh(list.get(1).getWtfmc());
        } else {
            czsr.setHtbh("财政");
        }

        // 财政收入手续费为成交额(元)合计*手续费率
        BigDecimal hjJe = new BigDecimal(hj.getJe()).setScale(2, RoundingMode.HALF_UP);
        BigDecimal sxfl = new BigDecimal(list.get(1).getSxfl()).divide(new BigDecimal(100)).setScale(4, RoundingMode.HALF_UP);
        BigDecimal czsxf = formatJeNumber(hjJe.multiply(sxfl));
        czsr.setSxf("¥" + czsxf);
        list.add(czsr);
    }

    private static void extractedGxsx(List<TyJytjbbSxftj> list) {
        for (TyJytjbbSxftj tyJytjbbSxftj : list) {
            tyJytjbbSxftj.setDjjybzj(null);
            tyJytjbbSxftj.setDjlybzj(null);
            tyJytjbbSxftj.setKqtje(null);
            tyJytjbbSxftj.setSjjke(null);
        }
    }

    // 将成交单位相同的行，进行实际成交额以及可清退金额列进行单元格合并，数据为之前的和，其他列不合并
    private static List<TyJytjbbSxftj> dyghb(List<TyJytjbbSxftj> data) {
        List<TyJytjbbSxftj> result = new ArrayList<>();
        Map<String, TyJytjbbSxftj> map = new HashMap<>();
        for (TyJytjbbSxftj item : data) {
            String key = item.getSjjke();
            if (map.containsKey(key)) {
                item.setSjjke(null);
                item.setKqtje(null);
            } else {
                map.put(key, item);
            }
            result.add(item);
        }
        return result;
    }

    @Override
    public ResponseWrapper sxfExport(String apcc) {
        try {
            // 查询数据
            List<TyJytjbbSxftj> list = tyJytjbbDao.sxfTj(apcc);
            if (list != null && list.size() > 0) {
                // 将结果先按照cjdw生序排序，再按照合同编号排序
                list.sort(Comparator.comparing(TyJytjbbSxftj::getCjdw).thenComparing(TyJytjbbSxftj::getHtbh));
                for (TyJytjbbSxftj tyJytjbbSxftj : list) {
                    if (StringUtils.isNotBlank(tyJytjbbSxftj.getJe())) {
                        tyJytjbbSxftj.setJe(formatJeNumber(new BigDecimal(tyJytjbbSxftj.getJe())).toString());
                    } else {
                        tyJytjbbSxftj.setJe("0");
                    }
                }
            }
            return ResponseWrapper.success(list);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }


    }

    @Override
    public PageResult<TyJytjbbJyjghz> jyjghz(int pageNum, int pageSize, String cjrqks, String cjrqjs) {
        String headerToken = RequestUtils.getHeaderToken();
//        PageHelper.startPage(pageNum, pageSize);
//        Page<TyJytjbbJyjghz> page = tyJytjbbDao.jyjghz(cjrqks, cjrqjs);
//        List<TyJytjbbJyjghz> result = page.getResult();
        List<TyJytjbbJyjghz> jyjghzlist = tyJytjbbDao.jyjghzlist(cjrqks, cjrqjs);
        List<TyJytjbbJyjghz> collect = extracted1(jyjghzlist);
        // 将collect进行分页，并返回
        List<TyJytjbbJyjghz> collect1 = collect.stream().skip((pageNum - 1) * pageSize).limit(pageSize).collect(Collectors.toList());
        // 将collect1的bdbm用逗号分隔，然后去重，再转成list
        return new PageResult<>(Long.valueOf(collect.size()), collect.size() / pageSize + 1, pageNum, collect1);
//        return new PageResult<>(page.getTotal(), page.getPages(), pageNum, page.getResult());
    }


    private List<TyJytjbbJyjghz> extracted1(List<TyJytjbbJyjghz> result) {
        if (result != null && result.size() > 0) {
            List<ContractDO> contractDOList = contractDao.selectAll();
            // 过滤掉result当中bdbm用逗号转成集合去重后数量大于1的result
//            List<TyJytjbbJyjghz> collect = result.stream().filter(item -> {
//                List<String> list = Arrays.asList(item.getBdbm().split(","));
//                return list.stream().distinct().count() > 1;
//            }).collect(Collectors.toList());
            result.forEach(tyJytjbbJyjghz -> {
                // 成交数量
                // 从 contractDOList过滤出bdbm在bdbm这个集合里面的结果
                List<String> list = Arrays.asList(tyJytjbbJyjghz.getBdbm().split(","));
                List<ContractDO> collect2 = contractDOList.stream().filter(item -> list.contains(item.getBdbm())).collect(Collectors.toList());
                // 成交数量为collect2当中的lssl相加
                BigDecimal cjsl = new BigDecimal(0);
                for (ContractDO contractDO : collect2) {
                    if (contractDO.getLssl() != null) {
                        cjsl = cjsl.add(contractDO.getLssl());
                    }
                }
                // 成交数量
                tyJytjbbJyjghz.setCjsl(formatSlNumber(cjsl).toString());
                // 最低成交价为collect2当中的dj不为空的最小值
                Optional<BigDecimal> min = collect2.stream().filter(item -> item.getCjdj() != null)
                        .map(ContractDO::getCjdj).min(BigDecimal::compareTo);
                if (min.isPresent()) {
                    tyJytjbbJyjghz.setZdcjj(formatJeNumber(min.get()).toString());
                }
                // 最低成交价为collect2当中的dj不为空的最小值
                Optional<BigDecimal> max = collect2.stream().filter(item -> item.getCjdj() != null)
                        .map(ContractDO::getCjdj).max(BigDecimal::compareTo);
                if (max.isPresent()) {
                    tyJytjbbJyjghz.setZgcjj(formatJeNumber(max.get()).toString());
                }
                // 成交金额为collect2当中je不为空之和
                BigDecimal cjje = new BigDecimal(0);
                for (ContractDO contractDO : collect2) {
                    if (contractDO.getJe() != null) {
                        cjje = cjje.add(contractDO.getJe());
                    }
                }
                tyJytjbbJyjghz.setJye(formatJeNumber(cjje).toString());
                // 均价=cjje/cjsl
                if (cjje != null && cjsl != null && cjsl.compareTo(BigDecimal.ZERO) != 0 && cjje.compareTo(BigDecimal.ZERO) != 0) {
                    tyJytjbbJyjghz.setJj(formatJeNumber(cjje.divide(cjsl, 2, BigDecimal.ROUND_HALF_UP)).toString());
                }

                //pzmc小麦类型的，显示小麦，其他显示小品种
                String pzmc = collect2.stream().map(ContractDO::getPzmc).distinct().collect(Collectors.joining(","));
                tyJytjbbJyjghz.setPzmc(pzmc);
                if (StringUtils.isNotEmpty(tyJytjbbJyjghz.getPzmc())) {
                    String[] split = tyJytjbbJyjghz.getPzmc().split(",");
                    if (split.length == 1) {
                        if (tyJytjbbJyjghz.getPzmc().contains("小麦")) {
                            tyJytjbbJyjghz.setPzmc("小麦");
                        }
                    } else {
                        StringBuilder sb = new StringBuilder();
                        // 将含有小麦的元素替换为小麦，其他的不变,最后汇总返回
                        for (String s : split) {
                            if (s.contains("小麦")) {
                                sb.append("小麦").append(",");
                            } else {
                                sb.append(s).append(",");
                            }
                        }
                        tyJytjbbJyjghz.setPzmc(sb.toString().substring(0, sb.toString().length() - 1));
                    }
                }
                // 委托书中【产地】如果选择1个，则获取显示。如果选择多个，则显示【国产】或者【进口】
                if (StringUtils.isNotEmpty(tyJytjbbJyjghz.getCd())) {
                    if (tyJytjbbJyjghz.getCd().contains(",")) {
                        String[] split = tyJytjbbJyjghz.getCd().split(",");
                        // 不止包含进口，则显示进口和国产
                        if (Arrays.asList(split).contains("进口") && Arrays.asList(split).stream().anyMatch(s -> !s.equals("进口"))) {
                            tyJytjbbJyjghz.setCd("进口/国产");
                        } else if (Arrays.stream(split).filter("进口"::equals).count() == split.length) {
                            tyJytjbbJyjghz.setCd("进口");
                        } else {
                            tyJytjbbJyjghz.setCd("国产");
                        }
                    }
                }
            });
            return result;
        }
        return null;
    }

    @Override
    public ResponseWrapper jyjgExport(String cjrqks, String cjrqjs) {

        try {
            List<TyJytjbbJyjghz> jyjghzlist = tyJytjbbDao.jyjghzlist(cjrqks, cjrqjs);
            List<TyJytjbbJyjghz> collect = extracted1(jyjghzlist);
            return ResponseWrapper.success(collect);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
    }

    @Override
    public PageResult<TyDcsjjl> selectDcjlPage(int pageNum, int pageSize, TyDcsjjl vo) {
        PageHelper.startPage(pageNum, pageSize);
        if (StringUtils.isNotBlank(vo.getNd()) && StringUtils.isBlank(vo.getJyrqStart()) && StringUtils.isBlank(vo.getJyrqEnd())) {
            vo.setJyrqStart(vo.getNd() + "-01-01");
            vo.setJyrqEnd(vo.getNd() + "-12-31");
        }
        Page<TyDcsjjl> page = tyJytjbbDao.selectDcjlPage(vo);
        // 数据处理
        List<TyDcsjjl> result = page.getResult();
        if (result.size() > 0) {
            List<Dcjybzxx> dcjybzxxList = tyJytjbbDao.selectDcjybzxx();
            for (TyDcsjjl tyDcsjjl : result) {
                // 过滤掉dcjybzxxList当中bdbm,htbh 和tyDcsjjl当中的bdbm,htbh相同的元素
                List<Dcjybzxx> collect = dcjybzxxList.stream()
                        .filter(item -> StringUtils.isNotBlank(item.getBdh())
                                && StringUtils.isNotBlank(item.getHtbh())
                                && item.getBdh().equals(tyDcsjjl.getBdh())
                                && item.getHtbh().equals(tyDcsjjl.getHth())).collect(Collectors.toList());
                if (collect.size() > 0) {
                    Dcjybzxx dcjybzxx = collect.get(0);
                    tyDcsjjl.setDcjybzxx(collect.get(0));
                    if (StringUtils.isNotBlank(dcjybzxx.getTsbz())) {
                        tyDcsjjl.setTsbz(dcjybzxx.getTsbz());
                    }
                    if (StringUtils.isNotBlank(dcjybzxx.getYy())) {
                        tyDcsjjl.setYy(dcjybzxx.getYy());
                    }
                }
            }
        }
        extracted2(result);
        return new PageResult<>(page.getTotal(), page.getPages(), pageNum, page.getResult());
    }

    @Override
    public ResponseWrapper dcjlExport(TyDcsjjl vo) {
        try {
            if (StringUtils.isNotBlank(vo.getNd()) && StringUtils.isBlank(vo.getJyrqStart()) && StringUtils.isBlank(vo.getJyrqEnd())) {
                vo.setJyrqStart(vo.getNd() + "-01-01");
                vo.setJyrqEnd(vo.getNd() + "-12-31");
            }
            List<TyDcsjjl> result = tyJytjbbDao.dcjlExport(vo);
            if (result.size() > 0) {
                List<Dcjybzxx> dcjybzxxList = tyJytjbbDao.selectDcjybzxx();
                for (TyDcsjjl tyDcsjjl : result) {
                    // 过滤掉dcjybzxxList当中bdbm,htbh 和tyDcsjjl当中的bdbm,htbh相同的元素
                    List<Dcjybzxx> collect = dcjybzxxList.stream()
                            .filter(item -> StringUtils.isNotBlank(item.getBdh())
                                    && StringUtils.isNotBlank(item.getHtbh())
                                    && item.getBdh().equals(tyDcsjjl.getBdh())
                                    && item.getHtbh().equals(tyDcsjjl.getHth())).collect(Collectors.toList());
                    if (collect.size() > 0) {
                        Dcjybzxx dcjybzxx = collect.get(0);
                        tyDcsjjl.setDcjybzxx(collect.get(0));
                        if (StringUtils.isNotBlank(dcjybzxx.getTsbz())) {
                            tyDcsjjl.setTsbz(dcjybzxx.getTsbz());
                        }
                        if (StringUtils.isNotBlank(dcjybzxx.getYy())) {
                            tyDcsjjl.setYy(dcjybzxx.getYy());
                        }
                    }
                }
            }
            extracted2(result);
            return ResponseWrapper.success(result);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
    }

    @Override
    public PageResult<DcJyHzzb> selectDcjyhzPage(int pageNum, int pageSize, DcJyHzzb vo) {
        PageHelper.startPage(pageNum, pageSize);
        if (StringUtils.isNotBlank(vo.getNd()) && StringUtils.isBlank(vo.getJyrqStart()) && StringUtils.isBlank(vo.getJyrqEnd())) {
            vo.setJyrqStart(vo.getNd() + "-01-01");
            vo.setJyrqEnd(vo.getNd() + "-12-31");
        }
        Page<DcJyHzzb> page = tyJytjbbDao.selectDcjyhzPage(vo);
        // 数据处理
        List<DcJyHzzb> result = page.getResult();
        extracted3(result);
        return new PageResult<>(page.getTotal(), page.getPages(), pageNum, page.getResult());
    }

    private void extracted3(List<DcJyHzzb> result) {
        if (result != null && result.size() > 0) {
            result.forEach(dcJyHzzb -> {

                // 粮食性质 1·市储<br/> 2·区储<br/> 3·市自"
                if (StringUtils.isNotBlank(dcJyHzzb.getJyjb())) {
                    if ("1".equals(dcJyHzzb.getJyjb())) {
                        dcJyHzzb.setJyjb("市储");
                    } else if ("2".equals(dcJyHzzb.getJyjb())) {
                        dcJyHzzb.setJyjb("区储");
                    } else if ("3".equals(dcJyHzzb.getJyjb())) {
                        dcJyHzzb.setJyjb("市自");
                    }
                }

                // 交易日期
                if (StringUtils.isNotEmpty(dcJyHzzb.getJyrq())) {
                    try {
                        dcJyHzzb.setJyrq(new SimpleDateFormat("yyyy-MM-dd").format(new SimpleDateFormat("yyyy-MM-dd").parse(dcJyHzzb.getJyrq())));
                    } catch (ParseException e) {
                        e.printStackTrace();
                    }
                }

                // 标的数量
                if (StringUtils.isNotEmpty(dcJyHzzb.getBdsl())) {
                    BigDecimal bdsl = new BigDecimal(dcJyHzzb.getBdsl()).setScale(2, RoundingMode.HALF_UP);
                    dcJyHzzb.setBdsl(formatSlNumber(bdsl).toString());
                } else {
                    dcJyHzzb.setBdsl("0");
                }
                // 合同数量
                if (StringUtils.isNotEmpty(dcJyHzzb.getHtsl())) {
                    BigDecimal htsl = new BigDecimal(dcJyHzzb.getHtsl()).setScale(2, RoundingMode.HALF_UP);
                    dcJyHzzb.setHtsl(formatSlNumber(htsl).toString());
                } else {
                    dcJyHzzb.setHtsl("0");
                }

                // 履约数量
                if (StringUtils.isNotEmpty(dcJyHzzb.getLysl())) {
                    BigDecimal lysl = new BigDecimal(dcJyHzzb.getLysl()).setScale(2, RoundingMode.HALF_UP);
                    dcJyHzzb.setLysl(formatSlNumber(lysl).toString());
                } else {
                    dcJyHzzb.setLysl("0");
                }

                // 违约数量
                if (StringUtils.isNotEmpty(dcJyHzzb.getWysl())) {
                    BigDecimal wysl = new BigDecimal(dcJyHzzb.getWysl()).setScale(2, RoundingMode.HALF_UP);
                    dcJyHzzb.setWysl(formatSlNumber(wysl).toString());
                } else {
                    dcJyHzzb.setWysl("0");
                }

                // 合同金额
                if (StringUtils.isNotEmpty(dcJyHzzb.getHtje())) {
                    BigDecimal htje = new BigDecimal(dcJyHzzb.getHtje()).setScale(2, RoundingMode.HALF_UP);
                    dcJyHzzb.setHtje(formatJeNumber(htje).toString());
//                    dcJyHzzb.setHtje("¥" + dcJyHzzb.getHtje());
                } else {
//                    dcJyHzzb.setHtje("¥0");
                    dcJyHzzb.setHtje("0");
                }

                // 手续费金额
                if (StringUtils.isNotEmpty(dcJyHzzb.getSxfje())) {
                    BigDecimal sxfje = new BigDecimal(dcJyHzzb.getSxfje()).setScale(2, RoundingMode.HALF_UP);
                    dcJyHzzb.setSxfje(formatJeNumber(sxfje).toString());
//                    dcJyHzzb.setSxfje("¥" + dcJyHzzb.getSxfje());
                } else {
//                    dcJyHzzb.setSxfje("¥0");
                    dcJyHzzb.setSxfje("0");
                }

                // 履约金额
                if (StringUtils.isNotEmpty(dcJyHzzb.getLyje())) {
                    BigDecimal lyje = new BigDecimal(dcJyHzzb.getLyje()).setScale(2, RoundingMode.HALF_UP);
                    dcJyHzzb.setLyje(formatJeNumber(lyje).toString());
//                    dcJyHzzb.setLyje("¥" + dcJyHzzb.getLyje());
                } else {
//                    dcJyHzzb.setLyje("¥0");
                    dcJyHzzb.setLyje("0");
                }
            });
        }
    }

    @Override
    public ResponseWrapper dcjyhzExport(DcJyHzzb vo) {
        try {
            if (StringUtils.isNotBlank(vo.getNd()) && StringUtils.isBlank(vo.getJyrqStart()) && StringUtils.isBlank(vo.getJyrqEnd())) {
                vo.setJyrqStart(vo.getNd() + "-01-01");
                vo.setJyrqEnd(vo.getNd() + "-12-31");
            }
            List<DcJyHzzb> result = tyJytjbbDao.dcjyhzExport(vo);
            extracted3(result);
            return ResponseWrapper.success(result);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
    }

    @Override
    public String saveOrUpdateDcjybzxx(Dcjybzxx vo) {
        if (StringUtils.isBlank(vo.getId())) {
            // 新增
            vo.setId(UUID.randomUUID().toString().replace("-", ""));
            int i = tyJytjbbDao.insertDcjybzxx(vo);
            if (i > 0) {
                return "新增成功";
            } else {
                return "新增失败";
            }
        } else {
            // 修改
            int i = tyJytjbbDao.updateDcjybzxx(vo);
            if (i > 0) {
                return "修改成功";
            } else {
                return "修改失败";
            }
        }
    }

    private void extracted2(List<TyDcsjjl> result) {
        if (result != null && result.size() > 0) {
            result.forEach(tyDcsjjl -> {
                // 场次编号 ，场次编号为年度_场次编号_s(q).， 比如2023_223_172_1， 说明是2023年第223场市级储备粮，最后带-1(2)说明是购销双向，1为采购，2为销售。
                if (StringUtils.isNotBlank(tyDcsjjl.getCcbh())) {
                    StrBuilder ccbh = new StrBuilder();
                    String nd = "";
                    if (StringUtils.isNotBlank(tyDcsjjl.getJyrq())) {
                        nd = tyDcsjjl.getJyrq().substring(0, 4);
                        ccbh.append(nd);
                    }
                    String cc = "";
                    if (StringUtils.isNotBlank(tyDcsjjl.getCc())) {
                        cc = tyDcsjjl.getCc().replace("第", "")
                                .replace("场", "")
                                .replace("期", "")
                                .replace(" ", "");
                        ccbh.append("_").append(cc);
                    }
                    ccbh.append("_").append(tyDcsjjl.getCcbh());
                    if (StringUtils.isNotBlank(tyDcsjjl.getJyfs()) && "2".equals(tyDcsjjl.getJyfs())) {
                        if (StringUtils.isNotBlank(tyDcsjjl.getJylx())) {
                            if ("0".equals(tyDcsjjl.getJylx())) {
                                ccbh.append("_").append("1");
                            } else if ("1".equals(tyDcsjjl.getJylx())) {
                                ccbh.append("_").append("2");
                            }
                        }

                    }
                    tyDcsjjl.setCcbh(ccbh.toString());

                }
                // 当前日期大于jyrq+2，并且hth为空，则为流拍，当前日期小于等于jyrq+2，并且hth为空，则为待维护
                if (StringUtils.isNotBlank(tyDcsjjl.getJyrq()) && StringUtils.isBlank(tyDcsjjl.getHth())) {
                    try {
                        Date jyrq = new SimpleDateFormat("yyyy-MM-dd").parse(tyDcsjjl.getJyrq());
                        Calendar calendar = Calendar.getInstance();
                        calendar.setTime(jyrq);
                        calendar.add(Calendar.DAY_OF_MONTH, 2);
                        Date time = calendar.getTime();
                        if (new Date().after(time)) {
                            tyDcsjjl.setJyjg("流拍");
                        } else {
                            tyDcsjjl.setJyjg("待维护");
                        }
                    } catch (ParseException e) {
                        e.printStackTrace();
                    }
                }
                if (StringUtils.isNotBlank(tyDcsjjl.getHth())) {
                    tyDcsjjl.setJyjg("成交");
                }
                if (StringUtils.isNotBlank(tyDcsjjl.getJyrq())) {
                    // 格式化日期
                    try {
                        tyDcsjjl.setJyrq(new SimpleDateFormat("yyyy-MM-dd").format(new SimpleDateFormat("yyyy-MM-dd").parse(tyDcsjjl.getJyrq())));
                    } catch (ParseException e) {
                        e.printStackTrace();
                    }
                }
                // 粮食性质 1·市储<br/> 2·区储<br/> 3·市自"
                if (StringUtils.isNotBlank(tyDcsjjl.getJyjb())) {
                    if ("1".equals(tyDcsjjl.getJyjb())) {
                        tyDcsjjl.setJyjb("市储");
                    } else if ("2".equals(tyDcsjjl.getJyjb())) {
                        tyDcsjjl.setJyjb("区储");
                    } else if ("3".equals(tyDcsjjl.getJyjb())) {
                        tyDcsjjl.setJyjb("市自");
                    }
                }
                // 履约金额 = 履约数量 * 成交单价
                if (StringUtils.isNotEmpty(tyDcsjjl.getLysl()) && StringUtils.isNotEmpty(tyDcsjjl.getCjj())) {
                    BigDecimal lysl = new BigDecimal(tyDcsjjl.getLysl()).setScale(2, RoundingMode.HALF_UP);
                    BigDecimal cjdj = new BigDecimal(tyDcsjjl.getCjj()).setScale(2, RoundingMode.HALF_UP);
                    BigDecimal lyje = formatJeNumber(lysl.multiply(cjdj).setScale(2, RoundingMode.HALF_UP));
                    tyDcsjjl.setLyje(lyje.toString());
//                    tyDcsjjl.setLyje("¥" + tyDcsjjl.getLyje());
                } else {
                    tyDcsjjl.setLyje("0");
                }

                // 标的数量
                if (StringUtils.isNotEmpty(tyDcsjjl.getBdsl())) {
                    BigDecimal bdsl = new BigDecimal(tyDcsjjl.getBdsl()).setScale(2, RoundingMode.HALF_UP);
                    tyDcsjjl.setBdsl(formatSlNumber(bdsl).toString());
                } else {
                    tyDcsjjl.setBdsl("0");
                }

                // 合同数量
                if (StringUtils.isNotEmpty(tyDcsjjl.getHtsl())) {
                    BigDecimal htsl = new BigDecimal(tyDcsjjl.getHtsl()).setScale(2, RoundingMode.HALF_UP);
                    tyDcsjjl.setHtsl(formatSlNumber(htsl).toString());
                } else {
                    tyDcsjjl.setHtsl("0");
                }

                if (StringUtils.isBlank(tyDcsjjl.getLysl())) {
                    tyDcsjjl.setLysl(formatSlNumber(new BigDecimal("0").setScale(2, RoundingMode.HALF_UP)).toString());
                } else {
                    tyDcsjjl.setLysl(formatSlNumber(new BigDecimal(tyDcsjjl.getLysl()).setScale(2, RoundingMode.HALF_UP)).toString());
                }
                if (StringUtils.isBlank(tyDcsjjl.getWysl())) {
                    tyDcsjjl.setWysl(formatSlNumber(new BigDecimal("0").setScale(2, RoundingMode.HALF_UP)).toString());
                } else {
                    tyDcsjjl.setWysl(formatSlNumber(new BigDecimal(tyDcsjjl.getWysl()).setScale(2, RoundingMode.HALF_UP)).toString());
                }

                // 手续费率 为%形式,也就是加个%，保留两位小数
                if (StringUtils.isNotEmpty(tyDcsjjl.getKhsxfl())) {
                    BigDecimal khsxfl = formatJeNumber(new BigDecimal(tyDcsjjl.getKhsxfl()).setScale(2, RoundingMode.HALF_UP));
                    tyDcsjjl.setWtfsxfl(khsxfl + "%");
                    tyDcsjjl.setKhsxfl(khsxfl + "%");
                    // 成交额 = 成交额*委托方手续费率*2
                    if (StringUtils.isNotEmpty(tyDcsjjl.getHtje())) {
                        BigDecimal cje = new BigDecimal(tyDcsjjl.getHtje()).setScale(2, RoundingMode.HALF_UP);
                        // 手续费率为wtfsxfl/100
                        BigDecimal wtfsxfl1 = khsxfl.divide(new BigDecimal(100)).setScale(4, RoundingMode.HALF_UP);
                        BigDecimal multiply = cje.multiply(wtfsxfl1);
                        tyDcsjjl.setSxfje(formatJeNumber(multiply).toString());
//                        tyDcsjjl.setSxfje("¥" + tyDcsjjl.getSxfje());
                    } else {
                        tyDcsjjl.setSxfje("0");
                    }

                }

                // 履约保证金
                if (StringUtils.isNotEmpty(tyDcsjjl.getLybzj())) {
                    BigDecimal lybzj = new BigDecimal(tyDcsjjl.getLybzj()).setScale(2, RoundingMode.HALF_UP);
                    tyDcsjjl.setLybzj(formatJeNumber(lybzj).toString());
//                    tyDcsjjl.setLybzj("¥" + tyDcsjjl.getLybzj());
                } else {
                    tyDcsjjl.setLybzj("0");
                }

                // 交易保证金
                if (StringUtils.isNotEmpty(tyDcsjjl.getJybzj())) {
                    BigDecimal jybzj = new BigDecimal(tyDcsjjl.getJybzj()).setScale(2, RoundingMode.HALF_UP);
                    tyDcsjjl.setJybzj(formatJeNumber(jybzj).toString());
//                    tyDcsjjl.setJybzj("¥" + tyDcsjjl.getJybzj());
                } else {
                    tyDcsjjl.setJybzj("0");
                }
                // 起拍价
                if (StringUtils.isNotEmpty(tyDcsjjl.getQpj())) {
                    BigDecimal qpj = new BigDecimal(tyDcsjjl.getQpj()).setScale(2, RoundingMode.HALF_UP);
                    tyDcsjjl.setQpj(formatJeNumber(qpj).toString());
//                    tyDcsjjl.setQpj("¥" + tyDcsjjl.getQpj());
                } else {
                    tyDcsjjl.setQpj("0");
                }
                // 成交价
                if (StringUtils.isNotEmpty(tyDcsjjl.getCjj())) {
                    BigDecimal cjj = new BigDecimal(tyDcsjjl.getCjj()).setScale(2, RoundingMode.HALF_UP);
                    tyDcsjjl.setCjj(formatJeNumber(cjj).toString());
//                    tyDcsjjl.setCjj("¥" + tyDcsjjl.getCjj());
                } else {
                    tyDcsjjl.setCjj("0");
                }
                // 合同金额
                if (StringUtils.isNotEmpty(tyDcsjjl.getHtje())) {
                    BigDecimal htje = new BigDecimal(tyDcsjjl.getHtje()).setScale(2, RoundingMode.HALF_UP);
                    tyDcsjjl.setHtje(formatJeNumber(htje).toString());
//                    tyDcsjjl.setHtje("¥" + tyDcsjjl.getHtje());
                } else {
                    tyDcsjjl.setHtje("0");
                }


                //pzmc小麦类型的，显示小麦，其他显示小品种
//                if (StringUtils.isNotEmpty(tyDcsjjl.getPzmc())) {
//                    if (tyDcsjjl.getPzmc().contains("小麦")) {
//                        tyDcsjjl.setPzmc("小麦");
//                    }
//                }
            });
        }
    }

    public static BigDecimal formatJeNumber(BigDecimal number) {
        if (number.scale() > 0 && number.stripTrailingZeros().scale() > 0) {
            return number.setScale(2, RoundingMode.HALF_UP);
        } else {
            return number.setScale(0, RoundingMode.HALF_UP);
        }
    }

    public static BigDecimal formatSlNumber(BigDecimal number) {
        if (number.scale() > 0 && number.stripTrailingZeros().scale() > 0) {
            return number.setScale(3, RoundingMode.HALF_UP);
        } else {
            return number.setScale(0, RoundingMode.HALF_UP);
        }
    }
}
